! =================================================================================================================================
! MODULE       : constantes_mtc
!
! CONTACT      : orchidee-help _at_ ipsl.jussieu.fr
!
! LICENCE      : IPSL (2011)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF         This module contains the standard values of the parameters for the 13 metaclasses of vegetation used by ORCHIDEE.
!!
!!\n DESCRIPTION: None
!!
!! RECENT CHANGE(S): Didier Solyga : replace default values for humscte at 2 meters soil depth by default values for humcste
!!                   at 4 meters (used for the CMIP simulations). The standard values for 2 meters soil depth are :
!!                   REAL(r_std), PARAMETER, DIMENSION(nvmc) :: humcste_mtc  =  &
!!                   & (/ 5.0,   0.8,   0.8,   1.0,   0.8,   0.8,   1.0,  &
!!                   &    1.0,   0.8,   4.0,   4.0,   4.0,   4.0  /)
!!
!! REFERENCE(S)	:
!! - Kuppel, S. (2012): Doctoral Thesis, Assimilation de mesures de flux turbulents d'eau et de carbone dans un modèle de la biosphère 
!! continentale 
!! - McDowell, N., Barnard, H., Bond, B.J., Hinckley, T., Hubbard, R.M., Ishii, H., Köstner, B., 
!! Magnani, F. Marshall, J.D., Meinzer, F.C., Phillips, N., Ryan, M.G., Whitehead D. 2002. The 
!! relationship between tree height and leaf area: sapwood area ratio. Oecologia, 132:12–20 
!! - Kuppel, S., Peylin, P., Chevallier, F., Bacour, C., Maignan, F., and Richardson, A. D. (2012). Constraining a global ecosystem
!! model with multi-site eddy-covariance data, Biogeosciences, 9, 3757-3776, DOI 10.5194/bg-9-3757-2012.
!! - Wohlfahrt, G., M. Bahn, E. Haubner, I. Horak, W. Michaeler, K.Rottmar, U. Tappeiner, and A. Cemusca, 1999: Inter-specific 
!! variation of the biochemical limitation to photosynthesis and related leaf traits of 30 species from mountain grassland 
!! ecosystems under different land use. Plant Cell Environ., 22, 12811296.
!! - Malhi, Y., Doughty, C., and Galbraith, D. (2011). The allocation of ecosystem net primary productivity in tropical forests, 
!! Philosophical Transactions of the Royal Society B-Biological Sciences, 366, 3225-3245, DOI 10.1098/rstb.2011.0062.
!! - Earles, J. M., Yeh, S., and Skog, K. E. (2012). Timing of carbon emissions from global forest clearance, Nature Climate Change, 2, 
!! 682-685, Doi 10.1038/Nclimate1535.
!! - Piao, S. L., Luyssaert, S., Ciais, P., Janssens, I. A., Chen, A. P., Cao, C., Fang, J. Y., Friedlingstein, P., Luo, Y. Q., and 
!! Wang, S. P. (2010). Forest annual carbon cost: A global-scale analysis of autotrophic respiration, Ecology, 91, 652-661, 
!! Doi 10.1890/08-2176.1.
!! - Verbeeck, H., Peylin, P., Bacour, C., Bonal, D., Steppe, K., and Ciais, P. (2011). Seasonal patterns of co2 fluxes in amazon 
!! forests: Fusion of eddy covariance data and the orchidee model, Journal of Geophysical Research-Biogeosciences, 116, 
!! Artn G02018, Doi 10.1029/2010jg001544.
!!
!! SVN          :
!! $HeadURL: $
!! $Date: 2015-02-22 16:18:16 +0100 (Sun, 22 Feb 2015) $
!! $Revision: 2555 $
!! \n
!_ ================================================================================================================================

MODULE constantes_mtc

  USE defprec
  USE constantes

  IMPLICIT NONE

  !
  ! METACLASSES CHARACTERISTICS
  !

  INTEGER(i_std), PARAMETER :: nvmc = 13                               !! Number of MTCS fixed in the code (unitless)

  CHARACTER(len=34), PARAMETER, DIMENSION(nvmc) :: MTC_name = &        !! description of the MTC (unitless)
  & (/ 'bare ground                       ', &          !  1
  &    'tropical  broad-leaved evergreen  ', &          !  2
  &    'tropical  broad-leaved raingreen  ', &          !  3
  &    'temperate needleleaf   evergreen  ', &          !  4
  &    'temperate broad-leaved evergreen  ', &          !  5
  &    'temperate broad-leaved summergreen', &          !  6
  &    'boreal    needleleaf   evergreen  ', &          !  7
  &    'boreal    broad-leaved summergreen', &          !  8
  &    'boreal    needleleaf   summergreen', &          !  9
  &    '          C3           grass      ', &          ! 10
  &    '          C4           grass      ', &          ! 11
  &    '          C3           agriculture', &          ! 12
  &    '          C4           agriculture'  /)         ! 13


  !
  ! VEGETATION STRUCTURE
  !
  INTEGER(i_std),PARAMETER, DIMENSION(nvmc) :: leaf_tab_mtc  =  &       !! leaf type (1-4, unitless)
  & (/  4,   1,   1,   2,   1,   1,   2,   &                            !! 1=broad leaved tree, 2=needle leaved tree
  &     1,   2,   3,   3,   3,   3   /)                                 !! 3=grass 4=bare ground

  CHARACTER(len=6), PARAMETER, DIMENSION(nvmc) :: pheno_model_mtc  =  & !! which phenology model is used? (tabulated) 
  & (/  'none  ',   'none  ',   'moi   ',   'none  ',   'none  ',  &
  &     'ncdgdd',   'none  ',   'ncdgdd',   'ngd   ',   'moigdd',  &
  &     'moigdd',   'moigdd',   'moigdd'  /) 

  LOGICAL, PARAMETER, DIMENSION(nvmc) :: is_tropical_mtc  =  &          !! Is PFT tropical ? (true/false)
  & (/ .FALSE.,   .TRUE.,    .TRUE.,    .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,  &
  &    .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE. /)    

  LOGICAL, PARAMETER, DIMENSION(nvmc) :: is_temperate_mtc  =  &         !! Is PFT temperate ? (true/false)
  & (/ .FALSE.,   .FALSE.,   .FALSE.,   .TRUE.,    .TRUE.,    .TRUE.,   .FALSE.,  &
  &    .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE. /)

  LOGICAL, PARAMETER, DIMENSION(nvmc) :: is_boreal_mtc = &              !! Is PFT boreal ? (true/false)
  & (/ .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .TRUE.,  &
  &    .TRUE.,   .TRUE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE. /)
    

  CHARACTER(LEN=5), PARAMETER, DIMENSION(nvmc) :: type_of_lai_mtc  =  & !! Type of behaviour of the LAI evolution algorithm
  & (/ 'inter', 'inter', 'inter', 'inter', 'inter',  &                  !! for each vegetation type. (unitless)
  &    'inter', 'inter', 'inter', 'inter', 'inter',  &                  !! Value of type_of_lai : mean or interp
  &    'inter', 'inter', 'inter' /)

  LOGICAL, PARAMETER, DIMENSION(nvmc) :: natural_mtc =  &               !! natural?  (true/false)
  & (/ .TRUE.,   .TRUE.,   .TRUE.,   .TRUE.,   .TRUE.,    .TRUE.,   .TRUE.,  &
  &    .TRUE.,   .TRUE.,   .TRUE.,   .TRUE.,   .FALSE.,   .FALSE.  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: veget_ori_fixed_mtc  =  &  !! Value for veget_ori for tests in
  & (/ 0.2,   0.0,   0.0,   0.0,   0.0,   0.0,   0.0,  &                !! 0-dim simulations (0-1, unitless)
  &    0.0,   0.0,   0.8,   0.0,   0.0,   0.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: llaimax_mtc  =  &          !! laimax for maximum
  & (/ undef,   8.0,   8.0,   4.0,   4.5,   4.5,   4.0,  &              !! See also type of lai interpolation
  &      4.5,   4.0,   2.0,   2.0,   2.0,   2.0  /)                     !! @tex $(m^2.m^{-2})$ @endtex

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: llaimin_mtc  = &           !! laimin for minimum lai
  & (/ undef,   8.0,   0.0,   4.0,   4.5,   0.0,   4.0,  &              !! See also type of lai interpolation (m^2.m^{-2})
  &      0.0,   0.0,   0.0,   0.0,   0.0,   0.0  /)                     !! @tex $(m^2.m^{-2})$ @endtex

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: height_presc_mtc  =  &     !! prescribed height of vegetation (m) ONLY used without
  & (/  0.0,   30.0,   30.0,   20.0,   20.0,   20.0,   15.0,  &         !! stomate. Value for height_presc : one for each vegetation 
  &    15.0,   15.0,    0.5,    0.6,    1.0,    1.0  /)                 !! type

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: rveg_mtc  =  &             !! Potentiometer to set vegetation resistance (unitless)
  & (/ 1.0,   1.0,   1.0,   1.0,   1.0,   1.0,   1.0,  &                !! Nathalie on March 28th, 2006 - from Fred Hourdin,
  &    1.0,   1.0,   1.0,   1.0,   1.0,   1.0   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: sla_mtc  =  &              !! specif leaf area @tex $(m^2.gC^{-1})$ @endtex
  & (/ 1.5E-2,   1.53E-2,   2.6E-2,   9.26E-3,     2E-2,   2.6E-2,   9.26E-3,  &
  &    2.6E-2,    1.9E-2,   2.6E-2,    2.6E-2,   2.6E-2,   2.6E-2  /) 


  !
  ! EVAPOTRANSPIRATION (sechiba)
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: rstruct_const_mtc  =  &    !! Structural resistance.
  & (/ 0.0,   25.0,   25.0,   25.0,   25.0,   25.0,   25.0,  &          !! @tex $(s.m^{-1})$ @endtex
  &   25.0,   25.0,    2.5,    2.0,    2.0,    2.0   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: kzero_mtc  =  &                  !! A vegetation dependent constant used in the 
  & (/    0.0,   12.E-5,   12.E-5,   12.E-5,   12.E-5,   25.E-5,   12.E-5,  & !! calculation  of the surface resistance. 
  &    25.E-5,   25.E-5,   30.E-5,   30.E-5,   30.E-5,   30.E-5  /)           !! @tex $(kg.m^2.s^{-1})$ @endtex


  !
  ! WATER (sechiba)
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: wmax_veg_mtc  =  &        !! Volumetric available soil water capacity in each PFT
  & (/ 150.0,   150.0,   150.0,   150.0,   150.0,   150.0,   150.0,  & !! @tex $(kg.m^{-3} of soil)$ @endtex
  &    150.0,   150.0,   150.0,   150.0,   150.0,   150.0  /)         
                                                                      

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: humcste_mtc  =  &         !! Root profile description for the different 
  & (/ 5.0,   0.4,   0.4,   1.0,   0.8,   0.8,   1.0,  &               !! vegetations types. @tex $(m^{-1})$ @endtex
  &    1.0,   0.8,   4.0,   1.0,   4.0,   1.0  /)                      !! These are the factor in the exponential which gets       
                                                                       !! the root density as a function of depth
                                                                       !! Values for zmaxh = 4.0  
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: humcste_cwrr  =  &        !! Root profile description for the different
  & (/ 5.0,   0.8,   0.8,   1.0,   0.8,   0.8,   1.0,  &               !! vegetations types.  @tex $(m^{-1})$ @endtex
  &    1.0,   0.8,   4.0,   4.0,   4.0,   4.0  /)                      !! These are the factor in the exponential which gets       
                                                                        !! the root density as a function of depth
                                                                        !! Values for zmaxh = 2.0
                                                                        !! (used by using 11 layers hydrology) 


  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: throughfall_by_mtc  =  &  !! Fraction of rain intercepted by the canopy
  & (/ 30.0,   30.0,   30.0,   30.0,   30.0,   30.0,   30.0,  &        !! (0-100, unitless)
  &    30.0,   30.0,   30.0,   30.0,   30.0,   30.0  /)


  !
  ! ALBEDO (sechiba)
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: snowa_aged_mtc  =  &    !! Minimum snow albedo value for each vegetation type
  & (/ 0.35,    0.0,    0.0,   0.14,   0.14,   0.14,   0.14,  &      !! after aging (dirty old snow) (unitless)
  &    0.14,   0.14,   0.18,   0.18,   0.18,   0.18  /)              !! Source : Values are from the Thesis of S. Chalita (1992)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: snowa_dec_mtc  =  &     !! Decay rate of snow albedo value for each vegetation type
  & (/ 0.45,    0.0,    0.0,   0.06,   0.06,   0.11,   0.06,  &      !! as it will be used in condveg_snow (unitless)
  &    0.11,   0.11,   0.52,   0.52,   0.52,   0.52  /)              !! Source : Values are from the Thesis of S. Chalita (1992)
  !
  ! albedo values for albedo type 'standard'
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alb_leaf_vis_mtc  =  &  !! leaf albedo of vegetation type, visible albedo 
  & (/ 0.00,   0.04,   0.06,   0.06,   0.06,   0.06,   0.06,  &      !! (unitless)
  &    0.06,   0.06,   0.10,   0.10,   0.10,   0.10  /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alb_leaf_nir_mtc  =  &  !! leaf albedo of vegetation type, near infrared albedo
  & (/ 0.00,   0.10,   0.22,   0.22,   0.22,   0.22,   0.22,  &      !! (unitless)
  &    0.22,   0.22,   0.30,   0.30,   0.30,   0.30  /)

  !
  ! albedo values for albedo type 'pinty'
  ! these next values were determined by fitting to global MODIS data and using the inversion scheme of
  ! Pinty et al (see Pinty B,Andredakis I, Clerici M, et al. (2011) ! 'Exploiting the MODIS albedos 
  ! with the Two-stream Inversion Package (JRC-TIP): 1. Effective leaf area index,
  ! vegetation, and soil properties'. Journal of Geophysical Research.
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: leaf_ssa_vis_mtc  =  &           !! leaf single scattering albedo, visible light (unitless)
  (/ 0.17192, 0.12560, 0.16230, 0.13838, 0.13202, 0.14720,  &
     0.14680, 0.14415, 0.15485, 0.17544, 0.17384, 0.17302, 0.17116 /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: leaf_ssa_nir_mtc  =  &           !! leaf single scattering albedo, near infrared (unitless)
  (/ 0.70253, 0.68189, 0.69684, 0.68778, 0.68356, 0.69533, &
     0.69520, 0.69195, 0.69180, 0.71236, 0.71904, 0.71220, 0.71190 /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: leaf_psd_vis_mtc  =  &           !! leaf preferred scattering direction, visible light (unitless)
  (/ 1.00170, 0.96776, 0.99250, 0.97170, 0.97119, 0.98077, &
     0.97672, 0.97810, 0.98605, 1.00490, 1.00360, 1.00320, 1.00130 /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: leaf_psd_nir_mtc  =  &           !! leaf preferred scattering direction, NIR light (unitless)
  (/ 2.00520, 1.95120, 1.98990, 1.97020, 1.95900, 1.98190, &
     1.98890, 1.97400, 1.97780, 2.02430, 2.03350, 2.02070, 2.02150 /)
    
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: bgd_reflectance_vis_mtc  =  &    !! background reflectance, visible light (unitless)
  (/ 0.13796, 0.08311, 0.08784, 0.04339, 0.07228, 0.06460, &
     0.03170, 0.06029, 0.06403, 0.12459, 0.14366, 0.11012, 0.12245 /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: bgd_reflectance_nir_mtc  =  &    !! background reflectance, NIR light (unitless)
  (/ 0.26520, 0.14605, 0.14937, 0.06608, 0.12334, 0.10534, &
     0.04443, 0.09455, 0.09770, 0.23034, 0.29221, 0.20508, 0.23339 /)
     
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tune_coupled_mtc  =  &           !! tune factors for LAI coupled LAI,  (unitless)
  (/ un,   un,   un,   un,   un,   un,   un,  &  
     un,   un,   un,   un,   un,   un /)    
     
     

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: leaf_to_shoot_clumping_mtc  =  & !! The clumping factor for leaves to shoots in the 
  (/ un,   un,   un,   un,   un,   un,   un,  &                               !! effective LAI calculation...notice this should be
     un,   un,   un,   un,   un,   un /)                                      !! equal to unity for grasslands/croplands

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: lai_correction_factor_mtc  =  &  !! see the note about this variable in pft_parameters
  (/ un,   un,   un,   un,   un,   un,   un,  &  
     un,   un,   un,   un,   un,   un /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: min_level_sep_mtc  =  &          !! The minimum level thickness for photosynthesis [m]
  (/ un,   0.1,   0.1,   0.1,   0.1,   0.1,   0.1,  &                         !! This number is arbitrary at the moment.  The idea
     0.1,   0.1,   0.1,   0.1,   0.1,   0.1 /)                                !! is to have a small number to make as many levels
                                                                              !! as possible in the canopies, but not too small which
                                                                              !! results in too little LAI in all the levels.  If all your
                                                                              !! levels have less than 0.1 LAI in them, that's probably 
                                                                              !! too small.

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: lai_top_mtc = &                  !! Diffuco.f90 calculates the stomatal conductance of the
  (/ un,   0.1,   0.1,   0.1,   0.1,   0.1,   0.1,  &                         !! top layer of the canopy. Because the top layer can contain
     0.1,   0.1,   0.1,   0.1,   0.1,   0.1 /)                                !! diiferent amounts of LAI depending on the crown diameter
                                                                              !! we had to define top layer in terms of the LAI it contains.
                                                                              !! stomatal conductance in the top layer contributes to the 
                                                                              !! transpiration (m2 m-2). Arbitrary values.
  !
  ! SOIL - VEGETATION
  !
  INTEGER(i_std), PARAMETER, DIMENSION(nvmc) :: pref_soil_veg_mtc  =  &       !! The soil tile number for each vegetation
  & (/ 1,   2,   2,   2,   2,   2,   2,  &                                    
  &    2,   2,   3,   3,   3,   3  /)                                         

  !
  ! VEGETATION - AGE CLASSES
  !
  INTEGER(i_std), PARAMETER, DIMENSION(nvmc) :: agec_group_mtc  =  &       !! The age class group that each PFT belongs to.
       (/ 1,   2,   3,   4,   5,   6,   7,  &                                    
       8,   9,   10,   11,   12,   13  /)                                         


  !
  ! PHOTOSYNTHESIS
  !
  !-
  ! 1 .CO2
  !-
 LOGICAL, PARAMETER, DIMENSION(nvmc) :: is_c4_mtc  =  &                            !! flag for C4 vegetation types (true/false)
  & (/ .FALSE.,  .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,   .FALSE.,  &
  &    .FALSE.,  .FALSE.,   .FALSE.,   .TRUE.,    .FALSE.,   .TRUE.  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: vcmax_fix_mtc  =  &     !! values used for vcmax when STOMATE is not
  & (/  0.0,   40.0,   50.0,   30.0,   35.0,   40.0,   30.0,  &      !! activated @tex $(\mu mol.m^{-2}.s^{-1})$ @endtex
  &    40.0,   35.0,   60.0,   60.0,   70.0,   70.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: E_KmC_mtc  = &            !! Energy of activation for KmC (J mol-1)
  & (/undef,  79430.,  79430.,  79430.,  79430.,  79430.,  79430.,  &  !! See Medlyn et al. (2002) 
  &  79430.,  79430.,  79430.,  79430.,  79430.,  79430.  /)           !! from Bernacchi al. (2001)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: E_KmO_mtc  = &            !! Energy of activation for KmO (J mol-1)
  & (/undef,  36380.,  36380.,  36380.,  36380.,  36380.,  36380.,  &  !! See Medlyn et al. (2002) 
  &  36380.,  36380.,  36380.,  36380.,  36380.,  36380.  /)           !! from Bernacchi al. (2001)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: E_gamma_star_mtc  = &     !! Energy of activation for gamma_star (J mol-1)
  & (/undef,  37830.,  37830.,  37830.,  37830.,  37830.,  37830.,  &  !! See Medlyn et al. (2002) from Bernacchi al. (2001) 
  &  37830.,  37830.,  37830.,  37830.,  37830.,  37830.  /)           !! for C3 plants - We use the same values for C4 plants

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: E_Vcmax_mtc  = &          !! Energy of activation for Vcmax (J mol-1)
  & (/undef,  71513.,  71513.,  71513.,  71513.,  71513.,  71513.,  &  !! See Table 2 of Yin et al. (2009) for C4 plants
  &  71513.,  71513.,  71513.,  67300.,  71513.,  67300.  /)           !! and Kattge & Knorr (2007) for C3 plants (table 3)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: E_Jmax_mtc  = &            !! Energy of activation for Jmax (J mol-1)
  & (/undef,  49884.,  49884.,  49884.,  49884.,  49884.,  49884.,  &   !! See Table 2 of Yin et al. (2009) for C4 plants
  &  49884.,  49884.,  49884.,  77900.,  49884.,  77900.  /)            !! and Kattge & Knorr (2007) for C3 plants (table 3)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: aSV_mtc     = &            !! a coefficient of the linear regression (a+bT) defining   
  & (/undef,  668.39,  668.39,  668.39,  668.39,  668.39,  668.39,  &   !! the Entropy term for Vcmax (J K-1 mol-1) See Table 3 of 
  &  668.39,  668.39,  668.39,  641.64,  668.39,  641.64  /)            !! Kattge & Knorr (2007). For C4 plants, we assume that 
                                                                        !! there is no acclimation and that at for a temperature 
                                                                        !! of 25°C, aSV is the same for both C4 and C3 plants 
                                                                        !! (no strong jusitification - need further parametrization)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: bSV_mtc     = &            !! b coefficient of the linear regression (a+bT) defining 
  & (/undef,   -1.07,   -1.07,   -1.07,   -1.07,   -1.07,   -1.07,  &   !! the Entropy term for Vcmax (J K-1 mol-1 °C-1) See Table 3 
  &   -1.07,   -1.07,   -1.07,      0.,   -1.07,      0.  /)            !! of Kattge & Knorr (2007). We assume No acclimation term for C4 plants

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tphoto_min_mtc  =  &       !! minimum photosynthesis temperature (deg C) 
  & (/  undef,   -4.0,    -4.0,   -4.0,   -4.0,   -4.0,   -4.0,  & 
  &      -4.0,   -4.0,    -4.0,   -4.0,   -4.0,   -4.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tphoto_max_mtc  =  &       !! maximum photosynthesis temperature (deg C) 
  & (/  undef,   55.0,    55.0,   55.0,   55.0,   55.0,   55.0,  & 
  &      55.0,   55.0,    55.0,   55.0,   55.0,   55.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: aSJ_mtc     = &            !! a coefficient of the linear regression (a+bT) defining the 
  & (/undef,  659.70,  659.70,  659.70,  659.70,  659.70,  659.70,  &   !! Entropy term for Jmax (J K-1 mol-1) See Table 3 of 
  &  659.70,  659.70,  659.70,    630.,  659.70,    630.  /)            !! Kattge & Knorr (2007) and Table 2 of Yin et al. (2009) for C4 plants

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: bSJ_mtc     = &            !! b coefficient of the linear regression (a+bT) defining the 
  & (/undef,   -0.75,   -0.75,   -0.75,   -0.75,   -0.75,   -0.75,  &   !! Entropy term for Jmax (J K-1 mol-1 °C-1). See Table 3 of 
  &   -0.75,   -0.75,   -0.75,      0.,   -0.75,      0.  /)            !! Kattge & Knorr (2007) We assume no acclimation term for C4 plants

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: D_Vcmax_mtc  = &           !! Energy of deactivation for Vcmax (J mol-1)
  & (/undef, 200000., 200000., 200000., 200000., 200000., 200000.,  &   !! Medlyn et al. (2002) also uses 200000. for C3 plants (same value than D_Jmax)
  & 200000., 200000., 200000., 192000., 200000., 192000.  /)            !! 'Consequently', we use the value of D_Jmax for C4 plants

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: D_Jmax_mtc  = &            !! Energy of deactivation for Jmax (J mol-1)
  & (/undef, 200000., 200000., 200000., 200000., 200000., 200000.,  &   !! See Table 2 of Yin et al. (2009)
  & 200000., 200000., 200000., 192000., 200000., 192000.  /)            !! Medlyn et al. (2002) also uses 200000. for C3 plants

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: E_Rd_mtc  = &              !! Energy of activation for Rd (J mol-1)
  & (/undef,  46390.,  46390.,  46390.,  46390.,  46390.,  46390.,  &   !! See Table 2 of Yin et al. (2009)
  &  46390.,  46390.,  46390.,  46390.,  46390.,  46390.  /)           

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: Vcmax25_mtc  =  &          !! Maximum rate of Rubisco activity-limited carboxylation at 25°C
  & (/ undef,   65.0,    65.0,    35.0,   45.0,   55.0,   35.0,  &      !! @tex $(\mu mol.m^{-2}.s^{-1})$ @endtex
  &     45.0,   35.0,    70.0,    70.0,   70.0,   70.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: arJV_mtc    = &            !! a coefficient of the linear regression (a+bT) defining the 
  & (/undef,    2.59,    2.59,    2.59,    2.59,    2.59,    2.59,  &   !! Jmax25/Vcmax25 ratio (mu mol e- (mu mol CO2)-1) See Table 3 of 
  &    2.59,    2.59,    2.59,   1.715,    2.59,   1.715  /)            !! Kattge & Knorr (2007). For C4 plants, we assume that there is no
                                                                        !! acclimation and that for a temperature of 25°C, aSV is the same 
                                                                        !! for both C4 and C3 plants (no strong jusitification - need further 
                                                                        !! parametrization)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: brJV_mtc    = &            !! b coefficient of the linear regression (a+bT) defining the 
  & (/undef,  -0.035,  -0.035,  -0.035,  -0.035,  -0.035,  -0.035,  &   !! Jmax25/Vcmax25 ratio ((mu mol e- (mu mol CO2)-1) (°C)-1) See 
  &  -0.035,  -0.035,  -0.035,      0.,  -0.035,      0.  /)            !! Table 3 of Kattge & Knorr (2007). We assume No acclimation term for C4 plants

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: KmC25_mtc  = &             !! Michaelis–Menten constant of Rubisco for CO2 at 25°C (ubar)
  & (/undef,   404.9,   404.9,   404.9,   404.9,  404.9,   404.9,  &    !! See Table 2 of Yin et al. (2009) for C4
  &   404.9,   404.9,   404.9,    650.,   404.9,   650.  /)             !! and Medlyn et al (2002) for C3

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: KmO25_mtc  = &             !! Michaelis–Menten constant of Rubisco for O2 at 25°C (ubar)
  & (/undef, 278400., 278400., 278400., 278400., 278400., 278400.,  &   !! See Table 2 of Yin et al. (2009) for C4 plants and Medlyn et al. (2002) for C3
  & 278400., 278400., 278400., 450000., 278400., 450000.  /)           

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: gamma_star25_mtc  = &      !! Ci-based CO2 compensation point in the absence of Rd at 25°C (ubar)
  & (/undef,   42.75,   42.75,   42.75,   42.75,   42.75,   42.75,  &   !! See Medlyn et al. (2002) for C3 plants - For C4 plants, we use the 
  &   42.75,   42.75,   42.75,   42.75,   42.75,   42.75  /)            !! same value (probably uncorrect)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: a1_mtc  = &                !! Empirical factor involved in the calculation of fvpd (-)
  & (/undef,    0.85,    0.85,    0.85,    0.85,    0.85,  0.85,  &     !! See Table 2 of Yin et al. (2009)
  &    0.85,    0.85,    0.85,    0.85,    0.85,    0.85  /)           

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: b1_mtc  = &                !! Empirical factor involved in the calculation of fvpd (-)
  & (/undef,    0.14,    0.14,    0.14,    0.14,    0.14,  0.14,  &     !! See Table 2 of Yin et al. (2009)
  &    0.14,    0.14,    0.14,    0.20,    0.14,    0.20  /)           

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: g0_mtc  = &                !! Residual stomatal conductance when irradiance approaches 
  & (/undef, 0.00625, 0.00625, 0.00625, 0.00625, 0.00625, 0.00625,  &   !! zero (mol CO2 m−2 s−1 bar−1). Value from ORCHIDEE - No other reference.
  & 0.00625, 0.00625, 0.00625, 0.01875, 0.00625, 0.01875  /)            !! modofy to account for the conversion for conductance to H2O to CO2 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: h_protons_mtc  = &         !! Number of protons required to produce one ATP (mol mol-1)
  & (/undef,      4.,      4.,      4.,      4.,      4.,    4.,  &     !! See Table 2 of Yin et al. (2009) - h parameter
  &      4.,      4.,      4.,      4.,      4.,      4.  /)           

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fpsir_mtc = &              !! Fraction of PSII e− transport rate 
  & (/undef,   undef,   undef,   undef,   undef,  undef,  undef,  &     !! partitioned to the C4 cycle (-)
  &   undef,   undef,   undef,     0.4,   undef,    0.4  /)             !! See Table 2 of Yin et al. (2009) - x parameter        
 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fQ_mtc = &                 !! Fraction of electrons at reduced plastoquinone 
  & (/undef,   undef,   undef,   undef,   undef,  undef,  undef,  &     !! that follow the Q-cycle (-) - Values for C3 platns are not used
  &   undef,   undef,   undef,      1.,   undef,     1.  /)             !! See Table 2 of Yin et al. (2009)          

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fpseudo_mtc = &            !! Fraction of electrons at PSI that follow 
  & (/undef,   undef,   undef,   undef,   undef,  undef,  undef,  &     !! pseudocyclic transport (-) - Values for C3 platns are not used
  &   undef,   undef,   undef,     0.1,   undef,    0.1  /)             !! See Table 2 of Yin et al. (2009)    

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: kp_mtc = &                 !! Initial carboxylation efficiency of the PEP carboxylase (mol m−2 s−1 bar−1) 
  & (/undef,   undef,   undef,   undef,   undef,  undef,  undef,  &     !! See Table 2 of Yin et al. (2009)
  &   undef,   undef,   undef,     0.7,   undef,    0.7  /)                 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alpha_mtc = &              !! Fraction of PSII activity in the bundle sheath (-)
  & (/undef,   undef,   undef,   undef,   undef,  undef,  undef,  &     !! See legend of Figure 6 of Yin et al. (2009)
  &   undef,   undef,   undef,     0.1,   undef,    0.1  /)                 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: gbs_mtc = &                !! Bundle-sheath conductance (mol m−2 s−1 bar−1)
  & (/undef,   undef,   undef,   undef,   undef,  undef,  undef,  &     !! See legend of Figure 6 of Yin et al. (2009)
  &   undef,   undef,   undef,   0.003,   undef,  0.003  /)    

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: theta_mtc = &              !! Convexity factor for response of J to irradiance (-)
  & (/undef,     0.7,     0.7,     0.7,     0.7,    0.7,    0.7,  &     !! See Table 2 of Yin et al. (2009) 
  &     0.7,     0.7,     0.7,     0.7,     0.7,    0.7  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alpha_LL_mtc = &           !! Conversion efficiency of absorbed light into J at strictly 
  & (/undef,     0.3,     0.3,     0.3,     0.3,    0.3,    0.3,  &     !! limiting light (mol e− (mol photon)−1). See comment from 
  &     0.3,     0.3,     0.3,     0.3,     0.3,    0.3  /)             !! Yin et al. (2009) after eq. 4. alpha value from Medlyn et al. (2002)
                                                                        !! This is rather low, Yin et al. proposes 0.43 (text above eq.11)


  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: downregulation_co2_coeff_mtc  =  &  !! coefficient for CO2 downregulation 
  & (/  0.0,   0.38,   0.38,   0.28,   0.28,   0.28,   0.22,  &
  &     0.22,  0.22,   0.26,   0.26,   0.26,   0.26 /)
  !-
  ! 2 .Stomate
  !-
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: ext_coeff_mtc  =  &     !! extinction coefficient of the Monsi&Saeki
  & (/ 0.5,   0.5,   0.5,   0.5,   0.5,   0.5,   0.5,  &             !! relationship (1953) (unitless)
  &    0.5,   0.5,   0.5,   0.5,   0.5,   0.5  /)
    
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: vcmax_opt_fun_all_mtc = & !! Maximum rate of carboxylation
  & (/ undef,   65.,    65.,    35.,    40.,    55.,    35., &         !! @tex $(\mu mol.m^{-2}.s^{-1})$ @endtex
  &      45.,   35.,    70.,    70.,    70.,    70.     /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: vjmax_opt_fun_all_mtc = & !! Maximum rate of RUbp regeneration
  & vcmax_opt_fun_all_mtc(:)*2.                                        !! @tex $(\mu mol.m^{-2}.s^{-1})$ @endtex
      
  !
  ! ALLOCATION (stomate)
  ! 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: S0_mtc = &              !! Default sapwood allocation (0-1, unitless)
  & (/ undef,   0.25,   0.25,   0.30,   0.30,  0.30,    0.30, &
  &     0.30,   0.30,   0.30,   0.30,   0.30,  0.30 /)                   

  !
  ! RESPIRATION (stomate)
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: maint_resp_slope_c_mtc  =  &  !! slope of maintenance respiration coefficient (1/K),
  & (/  undef,   0.20,   0.20,   0.16,   0.16,   0.16,   0.16,  &          !! constant c of aT^2+bT+c, tabulated
  &      0.16,   0.16,   0.16,   0.12,   0.16,   0.12  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: maint_resp_slope_b_mtc  =  &  !! slope of maintenance respiration coefficient (1/K),
  & (/  undef,   0.0,        0.0,   0.0,        0.0,   0.0,   0.0,  &      !! constant b of aT^2+bT+c, tabulated
  &       0.0,   0.0,   -0.00133,   0.0,   -0.00133,   0.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: maint_resp_slope_a_mtc  =  &  !! slope of maintenance respiration coefficient (1/K),
  & (/  undef,   0.0,   0.0,   0.0,   0.0,   0.0,   0.0,  &                !! constant a of aT^2+bT+c, tabulated
  &       0.0,   0.0,   0.0,   0.0,   0.0,   0.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_leaf_mtc  =   &                  !! maintenance respiration coefficient
  & (/   undef,   2.35E-3,   2.62E-3,   1.01E-3,   2.35E-3,   2.62E-3,   1.01E-3,  &  !! at 0 deg C,for leaves, tabulated, 
  &    2.62E-3,   2.05E-3,   2.62E-3,   2.62E-3,   2.62E-3,   2.62E-3  /)             !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_sapabove_mtc =  &                !! maintenance respiration coefficient 
  & (/   undef,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,  &  !! at 0 deg C, for sapwood above,
  &    1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4  /)             !! tabulated, @tex $(gC.gC^{-1}.day^{-1})$ @endtex

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_sapbelow_mtc  =  &               !! maintenance respiration coefficient
  & (/   undef,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,  &  !! at 0 deg C, for sapwood below, 
  &    1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4  /)             !! tabulated, @tex $(gC.gC^{-1}.day^{-1})$ @endtex 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_heartabove_mtc  =  &             !! maintenance respiration coefficient
  & (/  undef,   0.0,   0.0,   0.0,   0.0,   0.0,   0.0,  &                           !! at 0 deg C, for heartwood above,
  &       0.0,   0.0,   0.0,   0.0,   0.0,   0.0  /)                                  !! tabulated, @tex $(gC.gC^{-1}.day^{-1})$ @endtex 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_heartbelow_mtc  =  &             !! maintenance respiration coefficient
  & (/  undef,   0.0,   0.0,   0.0,   0.0,   0.0,   0.0,  &                           !! at 0 deg C, for heartwood below, 
  &       0.0,   0.0,   0.0,   0.0,   0.0,   0.0  /)                                  !! tabulated, @tex $(gC.gC^{-1}.day^{-1})$ @endtex 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_root_mtc  =  &                   !! maintenance respiration coefficient
  & (/   undef,   1.67E-3,   1.67E-3,   1.67E-3,   1.67E-3,   1.67E-3,   1.67E-3,  &  !! at 0 deg C, for roots, tabulated,
  &    1.67E-3,   1.67E-3,   1.67E-3,   1.67E-3,   1.67E-3,   1.67E-3  /)             !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_fruit_mtc  =  &                  !! maintenance respiration coefficient
  & (/   undef,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,  &  !! at 0 deg C, for fruits, tabulated,
  &    1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4,   1.19E-4  /)             !!  @tex $(gC.gC^{-1}.day^{-1})$ @endtex
   
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_carbres_fun_all_mtc  =  &        !! maintenance respiration coefficient
  & (/   undef,   0.,   0.,   0.,   0.,   0.,   0.,  &                                !! at 0 deg C, for carbohydrate reserve,
  &         0.,   0.,   0.,   0.,   0.,   0.   /)                                     !! tabulated, @tex $(gC.gC^{-1}.day^{-1})$ @endtex

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_labile_fun_all_mtc =    &        !! maintenance respiration coefficient
  & (/  undef,  2.78E-3, 2.78E-3, 2.78E-3, 2.78E-3, 2.78E-3, 2.78E-3,    &            !! at 0 deg C, for labile carbon pool,
  &   2.78E-3,  2.78E-3, 2.78E-3, 2.78E-3, 2.78E-3, 2.78E-3  /)*12.                   !! tabulated, @tex $(gC.gC^{-1}.day^{-1})$ @endtex

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_carbres_res_lim_mtc  =  &        !! maintenance respiration coefficient
  & (/   undef, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,  &              !! at 0 deg C, for carbohydrate reserve,
  &    1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4  /)                       !! tabulated, @tex $(gC.gC^{-1}.day^{-1})$ @endtex

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cm_zero_labile_res_lim_mtc  =  &         !! (not used) maintenance respiration coefficient
  & (/   undef,   0.,   0.,   0.,   0.,   0.,   0.,  &                                !! at 0 deg C, for labile carbon pool,
  &    0.,        0.,   0.,   0.,   0.,   0.   /)                                     !! tabulated, @tex $(gC.gC^{-1}.day^{-1})$ @endtex  
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: coeff_maint_init_mtc = &                 !! Initial values for maintenance respiration 
  & (/  undef,   0.022,   0.022,  0.021,  0.033,  0.033,  0.033,       &              !! at 0 deg C, used in the functional allocation
  &     0.033,   0.033,   0.033,  0.033,  0.033,  0.033      /)                       !! scheme. The range of the values  is given by
                                                                                      !! Sitch et al 2003  but the values were tuned to
                                                                                      !! obtain a NPP/GPP ratio of 0.5 in forests
                                                                                      !! given a sufficient nutrient supply (see Vicca 
                                                                                      !! et al 2012 Ecology Letters)
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: frac_growthresp_res_lim_mtc = &          !! Fraction of growth respiration expressed as 
  &(/  0.28,   0.28,   0.28,   0.28,   0.28,   0.28,   0.28, &                        !! share of the total C that is to be allocated
  &    0.28,   0.28,   0.28,   0.28,   0.28,   0.28 /)                                !! (0-1). Value for the resource limitation based
                                                                                      !! allocation scheme
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: frac_growthresp_fun_all_mtc = &          !! Fraction of growth respiration expressed as
  &(/  0.28,   0.28,   0.28,   0.28,   0.28,   0.28,   0.28, &                        !! share of the total C that is to be allocated
  &    0.28,   0.28,   0.28,   0.28,   0.28,   0.28 /)                                !! (0-1). Value for the functional allocation 
                                                                                      !! approach
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: gpp_to_labile_mtc = &                    !! The size of the labile pool as a fraction of the
  &(/  1.,  3.,  1.,  1.,  3.,  1.,  3., &                                            !! weekly gpp (-). For example, 3 indicates that the 
  &    3.,  3.,  3.,  3.,  3.,  3.  /)                                                !! labile pool is 3 times the weekly gpp.    

  !
  ! STAND STRUCTURE
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pipe_density_mtc = &                     !! Wood density @tex $(gC.m^{-3})$ @endtex
  &(/   0.0,   3.e5,   3.e5,   2.e5,   3.e5,   3.e5,   2.e5,  &                       !! Current values are taken from the trunk. 
  &    3.e5,  2.e5,    2.e5,   2.e5,   2.e5,   2.e5  /)                               !! forestry-branch has more realistic values 
                                                                                      !! in it. Source: AFOCEL 2006

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pipe_tune1_mtc = &                       !! cn_area = pipe_tune1*...
  &(/ undef,  100.,  100.,  100.,  100.,  100.,  100., &                              !!    stem diameter**pipe_tune_exp_coeff
  &    100.,  100., undef, undef, undef, undef /) 
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tree_ff_mtc = &                          !! Tree form factor to reduce
  &(/ undef,  0.6,    0.6,   0.6,   0.6,   0.6,   0.8, &                              !! the volume of a cylinder 
  &     0.8,  0.8,  undef, undef, undef, undef /)                                     !! to the volume of the real tree shape
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pipe_tune2_mtc = &                       !! height=pipe_tune2 * diameter**pipe_tune3
  &(/ undef,   55.,   55.,   55.,   55.,   55.,   55., &
  &     55.,   55., undef, undef, undef, undef /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pipe_tune3_mtc = &                       !! height=pipe_tune2 * diameter**pipe_tune3
  &(/ undef,   0.65,   0.65,   0.65,   0.65,   0.65,  0.65, &
  &     0.65,   0.65, undef, undef, undef, undef /)   
      
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pipe_tune4_mtc = &                       !! CHECK - needed for stem diameter no longer used
  &(/ undef,   0.3,   0.3,   0.3,   0.3,   0.3,   0.3, &
        0.3,   0.3, undef, undef, undef, undef /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pipe_k1_mtc = &                          !! CHECK - no longer used
  &(/ undef,  8.e3,  8.e3,  8.e3,  8.e3,  8.e3,  8.e3, &
  &    8.e3,  8.e3, undef, undef, undef, undef /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pipe_tune_exp_coeff_mtc = &              !! cn_area = pipe_tune1*...  
  &(/ undef,   1.6,   1.6,   1.6,   1.6,   1.6,   1.6, &                              !!    stem diameter**pipe_tune_exp_coeff
  &     1.6,   1.6, undef, undef, undef, undef /)  
      
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: mass_ratio_heart_sap_mtc = &             !! mass ratio (heartwood+sapwood)/heartwood 
  &(/ undef,    3.,    3.,    3.,    3.,    3.,    3., &
  &      3.,    3., undef, undef, undef, undef /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: lai_to_height_mtc = &                    !! Convertion from lai to height for grasses
  &(/ undef, undef, undef, undef, undef, undef, undef, &                              !! and cropland. Convert lai because that way a dynamic
  &   undef, undef,   0.1,   0.2,   0.1,   0.2 /)                                     !! sla is accounted for

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: canopy_cover_mtc = &                     !! Prescribed canopy cover (1-gap fraction) 
  & (/ undef,    0.9,   0.9,   0.7,   0.7,   0.7,   0.6, &                            !! of a canopy (unitless)
  &      0.5,    0.5,   0.9,   0.9,   0.9,   0.9 /)  

  INTEGER(i_std), PARAMETER, DIMENSION(nvmc) :: nmaxtrees_mtc = &                     !! Initial number of trees per ha. This parameter is 
  & (/  10000,  10000,  10000,  10000,  10000,  10000,  2000,  &                      !! used at .firstcall. and after clearcuts
  &      2000,   2000,  10000,  10000,  10000,  10000 /)                              !! the value is used by the allometric allocation
                                                                                      !! and forestry subroutines.

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: height_init_min_mtc = &                  !! The minimum height (m) of a tree sapling when a forest 
  &(/ undef,    2.,    2.,    2.,    2.,    2.,    3., &                              !! stand is established. Owing to the allometric 
  &      3.,    3.,   0.1,   0.1,   0.1,   0.1 /)                                     !! relationship this setting determines all
                                                                                      !! biomass components of a newly establised stand

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: height_init_max_mtc = &                  !! The maximum height (m) of a tree sapling when a forest 
  &(/ undef,    3.,    3.,    3.,    3.,    3.,    4., &                              !! stand is established. 
  &      4.,    4.,   0.2,   0.2,   0.2,   0.2 /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alpha_self_thinning_mtc = &              !! Coefficient of the self-thinning relationship D=alpha*N^beta 
  &(/ undef,  3000.,  3000.,  1462.,  2262.,  1900.,  960., &                         !! estimated from German, French, Spanish and Swedish 
  &     939.,  1046.,  undef,  undef,  undef,  undef/)                                !! forest inventories
 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: beta_self_thinning_mtc = &               !! Exponent of the self-thinning relationship D=alpha*N^beta 
  &(/ undef,  -0.57,  -0.57,  -0.55,  -0.61,  -0.58,  -0.55, &                        !! estimated from German, French, Spanish and Swedish 
  &    -0.56, -0.56,  undef,  undef,  undef,  undef/)                                 !! forest inventories

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fuelwood_diameter_mtc = &                !! Diameter below which the wood harvest is used as fuelwood (m)
  &(/ undef,   0.3,   0.3,   0.2,   0.3,   0.3,   0.2, &                              !! Affects the way the wood is used in the dim_product_use   
  &     0.2,   0.2, undef, undef, undef, undef/)                                      !! subroutine 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: coppice_kill_be_wood_mtc = &             !! The fraction of the belowground wood killed during coppicing.
  &(/ undef,   0.0,   0.0,   0.0,   0.0,   0.0,   0.0, &                              !! (unitless)
  &     0.0,   0.0, undef, undef, undef, undef/)                                      
                                                                                      
  !
  ! GROWTH
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cn_leaf_prescribed_mtc = &  !! C/N of leaves according to stich et al 2003
  & (/ undef,  29.,  29.,  29.,  29.,  29.,  29.,  &
  &      29.,  29.,  29.,  29.,  29.,  29.   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fcn_wood_mtc = &      !! C/N of "wood" for allocation relative to leaf C/N  according 
  & (/ undef,    .087,   .087,   .087,   .087,   .087,  .087,  &   !! to stich et al 2003
  &     .087,    .087,     1.,     1.,     1.,     1.   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fcn_root_mtc = &      !! C/N of "root" for allocation relative to leaf C/N  according 
  & (/ undef,   .86,    .86,    .86,    .86,    .86,   .86,   &    !! to stich et al 2003
  &      .86,   .86,    .86,    .86,    .86,    .86   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: k_latosa_max_mtc = &  !! Maximum leaf-to-sapwood area ratio as defined in McDowell et al
  & (/ undef,  5000.,  5000.,  5000.,  3000.,  5000.,  5000.,  &   !! 2002, Oecologia and compiled in Hickler et al 2006, Appendix S2 
  &    5000.,  5000.,  0.833,  0.833,  0.833,  0.833 /)                      !! The values for grasses and crops are tuned. More work is needed
                                                                   !! to fully justify this approach for the herbacuous PFTs (unitless)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: k_latosa_min_mtc = &  !! Minimum leaf-to-sapwood area ratio as defined in McDowell et al
  & (/ undef,  5000.,  5000.,  5000.,  3000.,  5000.,  5000.,  &   !! 2002, Oecologia and compiled in Hickler et al 2006, Appendix S2 
  &    5000.,  5000.,  0.833,  0.833,  0.833,  0.833  /)           !! The values for grasses and crops are tuned. More work is needed
                                                                   !! to fully justify this approach for the herbacuous PFTs (unitless)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fruit_alloc_mtc = &   !! Fraction of biomass allocated to fruit production (0-1)
  & (/ undef,   0.1,    0.1,    0.1,     0.1,     0.1,    0.1, &   !! currently only parameterized for forest PFTs 
  &      0.1,   0.1,     0.,     0.,      0.,      0. /)  

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: lai_max_to_happy_mtc = & !! Multiplicative factor of lai_max that determines
  & (/ undef,   0.5,    0.5,    0.5,     0.5,     0.4,    0.5, &   !! the threshold value of LAI below which the carbohydrate
  &      0.36,   0.35,     0.35,     0.5,      0.5,      0.5 /)    !! reserve is used 
 
  !
  ! HYDRAULIC ARCHITECTURE
  ! 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: k_root_mtc = &        !! Fine root specific conductivity. Values compiled in T. Hickler     
  & (/ undef,    4.,    4.,   4.,   4.,   4.,   4.,       &        !! et al. 2006. @tex $(m^{3} kg^{-1} s^{-1} MPa^{-1})$ @endtex    
  &       4.,    4.,   50.,  50.,  50.,  50.   /)*1.e-7         
                                                                       
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: k_sap_mtc = &         !! Maximal sapwood specific conductivity. Values compiled in T. Hickler 
  & (/ undef,   50.,   10.,    8.,    5.,   30.,    8.,    &       !! et al. 2006. @tex $(m^{2} s^{-1} MPa^{-1})$ @endtex 
  &      20.,    8., undef, undef, undef, undef    /)*1.e-4 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: k_leaf_mtc = &        !! Leaf conductivity. Values compiled in T. Hickler et al 2006
  & (/ undef,  1.5,  1.5,  1.5,  1.5,  1.5,  1.5,         &        !! @tex $(m s^{-1} MPa^{-1})$ @endtex
         1.5,  1.5,  1.5,  1.5,  1.5,  1.5         /)*1.e-7

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: phi_leaf_mtc = &      !! Minimal leaf water potential. Values in T. Hickler et al 2006
  & (/ undef, -2.2, -2.2, -2.2, -3.5, -2.2, -2.2,   &              !! @tex $(MPa)$ @endtex
        -2.2, -2.2, -2.2, -2.2, -2.2, -2.2        /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: phi_50_mtc = &        !! Sapwood leaf water potential that causes 50% loss of xylem
  & (/ undef, -0.3, -1.3, -2.0, -1.7, -1.0, -2.0, &                !! conductivity through cavitation. @tex $(MPa)$ @endtex
        -1.0, -2.0, undef, undef, undef, undef /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: c_cavitation_mtc = &  !! Shape parameter for loss of conductance Machado & Tyree, 1994
  & (/ undef,  5.,  3.,  3.,  3.,  3.,  3.,  &                     !! (unitless)
          3.,  3., undef, undef, undef, undef /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: phi_soil_tune_mtc = & !! Additive tuning parameter to account for soil-root interactions
  & (/ undef,  0.,  0.,  0.,  0.,  0.,  0.,  &                     !! @tex $(MPa)$ @endtex
          0.,  0.,  0.,  0.,  0.,  0. /)                                  

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: lai_happy_mtc = &     !! Lai threshold below which carbohydrate
  & (/ undef,  1.,  1.,  1.,  1.,  1.,  1.,  &                     !! reserve may be used in functional allocation.
          1.,  1.,  1.,  1.,  1.,  1. /)                           !! Also used in phenology to see if mixed classes
                                                                   !! should die.  These seem completely arbitrary.
                                                                   !! @tex $(m^2.m^{-2})$ @endtex

  ! -------------------------------------------------------------------------------------------------------
  ! tzjh parameter for the new hydraulic architecture -- all set up for PFT2 now
  ! -------------------------------------------------------------------------------------------------------
 
  ! Stomatal conductance parameters

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: gpsi_mtc = &        !! ! gs vs psi_leaf curve parameter     
  & (/ undef,   -2.0,    -2.0,   -2.0,  -2.0,   -2.0,   -2.0,       & !!     
  &       -2.0,    -2.0,   -2.0,  -2.0,  -2.0,  -2.0   /)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: gpsi_50_mtc = &        !! ! psi_leaf at 50% stomatal closure, -MPa     
  & (/ undef,   1.5,    1.5,   1.5,  1.5,   1.5,   1.5,       & !!     
  &       1.5,    1.5,   1.5,  1.5,  1.5,  1.5   /)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: gmax_mtc = &        !! maximum stomatal conductance     
  & (/ undef,   500.,    500.,   500.,   500.,   500.,   500.,       & !! @tex $mmol m^{-2}s^{-1}$ @endtex    
  &       500.,    500.,   500.,  500.,  500.,  500.   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: gmin_mtc = &        !! minimum (cuticular) conductance     
  & (/ undef,   10.,    10.,   10.,   10.,   10.,   10.,       & !! @tex $mmol m^{-2}s^{-1}$ @endtex    
  &       10.,    10.,   10.,  10.,  10.,  10.   /)
 
  ! Hydraulic conductivity parameters
 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: kmax_leaf_mtc = &    !! maximum hydraulic conductivity of leaf     
  & (/ undef,   20.,    20.,   20.,   20.,   20.,   20.,       &   !! @tex $mmol m^{-2}s^{-1} MPa^{-1}$ @endtex    
  &       10.,    10.,   10.,  10.,  10.,  10.   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: kmax_stem_mtc = &    !! maximum hydraulic conductivity of stem     
  & (/ undef,   10.,    10.,   10.,   10.,   10.,   10.,       &   !! @tex $mmol m^{-2}s^{-1} MPa^{-1}$ @endtex    
  &       10.,    10.,   10.,  10.,  10.,  10.   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: kmax_root_mtc = &    !! maximum hydraulic conductivity of root     
  & (/ undef,   10.,    10.,   10.,   10.,   10.,   10.,       &   !! @tex $mmol m^{-2}s^{-1} MPa^{-1}$ @endtex    
  &       10.,    10.,   10.,  10.,  10.,  10.   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: a_leaf_mtc = &        !! kleaf vs. psi_leaf curve parameter    
  & (/ undef,   -1.2,    -1.2,   -1.2,  -1.2,   -1.2,   -1.2,       & !!     
  &       -1.2,    -1.2,   -1.2,  -1.2,  -1.2,  -1.2   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: a_stem_mtc = &        !! kstem vs. psi_stem curve parameter    
  & (/ undef,   -1.2,    -1.2,   -1.2,  -1.2,   -1.2,   -1.2,       & !!     
  &       -1.2,    -1.2,   -1.2,  -1.2,  -1.2,  -1.2   /)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: a_root_mtc = &        !! kroot vs. psi_root curve parameter    
  & (/ undef,   -1.2,    -1.2,   -1.2,  -1.2,   -1.2,   -1.2,       & !!     
  &       -1.2,    -1.2,   -1.2,  -1.2,  -1.2,  -1.2   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: P50_leaf_mtc = &      !! psi_leaf at 50% loss of leaf hydraulic conductivity, MPa
  & (/ undef,   2.0,    2.0,   2.0,  2.0,   2.0,   2.0,       & !!     
  &       2.0,    2.0,   2.0,  2.0,  2.0,  2.0   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: P50_stem_mtc = &      !! psi_stem at 50% loss of leaf hydraulic conductivity, MPa
  & (/ undef,   2.5,    2.5,   2.5,  2.5,   2.5,   2.5,       & !!     
  &       2.5,    2.5,   2.5,  2.5,  2.5,  2.5   /)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: P50_root_mtc = &      !! psi_root at 50% loss of leaf hydraulic conductivity, MPa
  & (/ undef,   2.0,    2.0,   2.0,  2.0,   2.0,   2.0,       & !!     
  &       2.0,    2.0,   2.0,  2.0,  2.0,  2.0   /)

  ! Water storage parameters 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: wood_density_mtc = &      !! g of stem dry mass per m3 of stem volume Averaged across all Neotropical species
  & (/ undef,   645000.0,    645000.0,   645000.0,  645000.0,   645000.0,   645000.0,      &     !! from Chave et al. 2006 Ecological Applications
  &       645000.0,    645000.0,   645000.0,  645000.0,  645000.0,  645000.0   /)                !! in the code pipe_density, not the same values
                                                                   !!  (create a new variable for now to don't change the allocation)   

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: w_density_stem_mtc = &    !! mmol H2O per m3 of stem volume values averaged from a Bornean tropical forest, 
  & (/ undef,  25000000.0,   25000000.0,   25000000.0,  25000000.0,   25000000.0,  25000000.0, & !! from Suzuki et al. 1999 Ecological Research
  & 25000000.0, 25000000.0,  25000000.0, 25000000.0,  25000000.0,  25000000.0 /)             !!       

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: root_shoot_ratio_mtc = &   !! ratio of root mass to shoot mass, g g-1 values are averaged for wet and
  & (/ undef,   0.25,   0.25 ,  0.25 , 0.25 ,  0.25 ,  0.25 ,       & !!      dry tropical forests from Mokany et al. 2005 Global Change Biology
  &      0.25 ,   0.25 ,  0.25 ,  0.25,  0.25, 0.25     /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: rwc_root_mtc = &   !! mmol H2O per g of dry root mass
  & (/ undef,   35.0,  35.0  ,   35.0,  35.0,   35.0,   35.0,       & !!      dry tropical forests from Mokany et al. 2005 Global Change Biology
  &      35.0 ,    35.0,   35.0,  35.0,  35.0, 35.0    /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: root_density_mtc = &   !! wood density of the roots, g dry mass cm-3 volume
  & (/ undef,   0.502,  0.502  ,   0.502,  0.502,   0.502,   0.502,       & !!    
  &      0.502 ,    0.502,   0.502,  0.502,  0.502, 0.502    /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: LDMC_mtc = &   !! leaf dry matter content (g dry mass g-1 fresh mass), currently the global mean in the TRY
  & (/ undef,   0.2,    0.2,   0.2,  0.2,   0.2,   0.2,       & !!      database but should be replaced with the mean across tropical species (Kattge et al. 2011 Global Change Biology)
  &       0.2,    0.2,   0.2,  0.2,  0.2,  0.2   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: sla_hydro_mtc = &    !! sla (m2 kg-1), currenly the global mean in the TRY     
  & (/ undef,   16.6,    16.6,   16.6,   16.6,   16.6,   16.6,     &   !! database but should be replaced with the mean across tropical species (Kattge et    
  &       16.6,    16.6,   16.6,  16.6,  16.6,  16.6   /)               !! al. 2011 Global Change Biology)   idem, sla dalready in the code, to change ?  

  ! Capacitance parameters
 
!  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cxyl_mtc = &    !! stem capacitance, kg m^-3 MPa-1     
! & (/ undef,   0,    0,   0,   0,   0,   0,     &   !!    
!  &       0,    0,   0,  0,  0,  0   /)               !!  

! REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cr_mtc = &    !! root capacitance, kg m^-3 MPa-1     
!  & (/ undef,   0,    0,   0,   0,   0,   0,     &   !!    
!  &       0,    0,   0,  0,  0,  0   /)               !!  

! REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cl_mtc = &    !! leaf capacitance, mmol m^2 MPa-1     
!  & (/ undef,   0,    0,   0,   0,   0,   0,     &   !!    
!  &       0,    0,   0,  0,  0,  0   /)               !!  

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cxyl_mtc = &    !! stem capacitance, kg m^-3 MPa-1     
  & (/ undef,   124.0,    124.0,   124.0,   124.0,   124.0,   124.0,     &   !!    
  &       124.0,    124.0,   124.0,  124.0,  124.0,  124.0   /)               !!  

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cr_mtc = &    !! root capacitance, kg m^-3 MPa-1     
  & (/ undef,   150.0,    150.0,   150.0,   150.0,   150.0,   150.0,     &   !!    
  &       150.0,    150.0,   150.0,  150.0,  150.0,  150.0   /)               !!  

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: cl_mtc = &    !! leaf capacitance, mmol m^2 MPa-1     
  & (/ undef,   750.0,    670.0,   670.0,   670.0,   670.0,   670.0,     &   !!    
  &       670.0,    670.0,   670.0,  670.0,  670.0,  670.0   /)               !!  
  !
  ! MORTALITY (stomate)
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: death_distribution_factor_mtc = &    !!  The scale factor between the smallest and largest
       (/ undef,  100.,  100.,  100.,  100.,  100.,  100.,  &                     !! circ class for tree mortality in stomate_mark_kill.
            100.,  100., undef, undef, undef, undef /)                            !! (unitless)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: npp_reset_value_mtc = &  !! The value of the NPP that the long-term value is
       (/ undef,  undef,  undef,  undef,  undef,  undef,  undef,  &   !! reset to after a PFT dies in stomate_kill.  This
          undef,  undef,   500.,   500.,   500.,   500. /)            !! only seems to be used for non-trees.
                                                                      !! @tex $(gC m^{-2})$ @endtex

  
  !
  ! FIRE (stomate)
  !
  REAL(r_std),PARAMETER, DIMENSION(nvmc) :: flam_mtc  =  &         !! flamability: critical fraction of water 
  & (/  undef,   0.15,   0.25,   0.25,   0.25,   0.25,   0.25,  &  !! holding capacity (0-1, unitless)
  &      0.25,   0.25,   0.25,   0.25,   0.35,   0.35  /)

  REAL(r_std),PARAMETER, DIMENSION(nvmc) :: resist_mtc  =  &       !! fire resistance (0-1, unitless)
  & (/ undef,   0.95,   0.90,   0.12,   0.50,   0.12,   0.12,  &
  &    0.12,    0.12,    0.0,    0.0,    0.0,    0.0 /) 


  !
  ! FLUX - LUC
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: coeff_lcchange_s_mtc  =  &   !! Coeff of biomass export for the year
  & (/  undef,   0.897,   0.897,   0.597,   0.597,   0.597,   0.597,  &   !! (0-1, unitless)
  &     0.597,   0.597,   0.597,   0.597,   0.597,   0.597  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: coeff_lcchange_m_mtc  =  &  !! Coeff of biomass export for the decade 
  & (/  undef,   0.103,   0.103,   0.299,   0.299,   0.299,   0.299,  &   !! (0-1, unitless)
  &     0.299,   0.299,   0.299,   0.403,   0.299,   0.403  /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: coeff_lcchange_l_mtc  =  & !! Coeff of biomass export for the century
  & (/  undef,     0.0,     0.0,   0.104,   0.104,   0.104,   0.104,  &   !! (0-1, unitless)
  &     0.104,   0.104,   0.104,     0.0,   0.104,     0.0  /)


  !
  ! PHENOLOGY
  !
  !-
  ! 1. Stomate
  !-
  REAL(r_std), PARAMETER, DIMENSION (nvmc) :: lai_max_mtc  =  &          !! maximum LAI, PFT-specific 
  & (/ undef,   7.0,   7.0,   5.0,   5.0,   5.0,   4.5,  &               !! @tex $(m^2.m^{-2})$ @endtex
  &      4.5,   3.0,   2.5,   2.5,   5.0,   5.0  /)

  INTEGER(i_std), PARAMETER, DIMENSION(nvmc) :: pheno_type_mtc  =  &     !! type of phenology (0-4, unitless)
  & (/  0,   1,   3,   1,   1,   2,   1,  &                              !! 0=bare ground 1=evergreen,  2=summergreen, 
  &     2,   2,   4,   4,   2,   3  /)                                   !! 3=raingreen,  4=perennial
  !-
  ! 2. Leaf Onset
  !-
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pheno_gdd_crit_c_mtc  =  &    !! critical gdd, tabulated (C),
  & (/  undef,   undef,   undef,   undef,   undef,   undef,   undef,  &    !! constant c of aT^2+bT+c
  &     undef,   undef,   320.0,   400.0,   450.0,   550.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pheno_gdd_crit_b_mtc  =  &    !! critical gdd, tabulated (C),
  & (/  undef,   undef,   undef,   undef,   undef,   undef,   undef,  &    !! constant b of aT^2+bT+c
  &     undef,   undef,    6.25,     0.0,    6.25,     0.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: pheno_gdd_crit_a_mtc  =  &    !! critical gdd, tabulated (C),
  & (/  undef,   undef,     undef,   undef,   undef,   undef,   undef,  &  !! constant a of aT^2+bT+c
  &     undef,   undef,   0.03125,     0.0,  0.0315,   0.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: ngd_crit_mtc  =  &            !! critical cumulated ngd, tabulated. 
  & (/  undef,   undef,   undef,   undef,   undef,   undef,   undef,  &    !! Threshold -5 degrees (C)
  &     undef,    17.0,   undef,   undef,   undef,   undef  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: opti_kpheno_crit_mtc  =  &   !! multiplicative factor to use optimized 
  & (/  undef,   1.,   1.,   1.,   1.,   1.13,   1.,  &                   !! gdd_crit (N. MacBean)
  &     0.87,    1.08,   0.81,   1.,   1.,   1.  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: ncdgdd_temp_mtc  =  &         !! critical temperature for the ncd vs. gdd 
  & (/  undef,   undef,   undef,   undef,   undef,     5.0,   undef,  &    !! function in phenology (C)
  &       0.0,     0.0,   undef,   undef,   undef,   undef  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: hum_frac_mtc  =  &            !! critical humidity (relative to min/max) 
  & (/  undef,   undef,   0.5,   undef,   undef,   undef,   undef, &       !! for phenology (unitless)
  &     undef,   undef,   0.5,     0.5,     0.5,     0.5  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: hum_min_time_mtc  =  &        !! minimum time elapsed since
  & (/  undef,   undef,   50.0,   undef,   undef,   undef,   undef,  &     !! moisture minimum (days)
  &     undef,   undef,   58.71,    35.0,    75.0,    75.0  /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tau_sap_mtc  =  &             !! Sapwood longivety (days)  
  & (/  undef,   730.,   730.,   730.,   730.,   730.,   730.,  &
  &      730.,   730.,  undef,  undef,  undef,  undef  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tau_fruit_mtc  =  &           !! fruit longivety (days)
  & (/  undef,   90.,   90.,    90.,     90.,   90.,   90.,  &
  &       90.,   90., undef,  undef,   undef,   undef  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tau_root_mtc  =  &            !! roots longevity (days)
  & (/  undef,  365.,   365.,    365.,    365.,   365.,   365.,  &
  &      365.,  365.,   365.,    365.,    365.,   365.  /)/7

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tau_leaf_mtc  =  &            !! leaf longevity (days)
  & (/  undef,   730.,   180.,    910.,   730.,   160.62,   910.,  &
  &      240.,   89.57,   89.57,    120.,    90.,    90.  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: ecureuil_mtc  =  &            !! fraction of primary leaf and root allocation
  & (/  undef,   0.0,   1.0,   0.0,   0.0,   1.0,   0.0,  &                !! put into reserve (0-1, unitless)
  &       1.0,   1.0,   1.0,   1.0,   1.0,   1.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alloc_min_mtc  =  &           !! NEW - allocation above/below = f(age) 
  & (/  undef,   0.2,     0.2,     0.2,     0.2,    0.2,   0.2,  &         !! - 30/01/04 NV/JO/PF
  &       0.2,   0.2,   undef,   undef,   undef,   undef  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alloc_max_mtc  =  &           !! NEW - allocation above/below = f(age) 
  & (/  undef,   0.8,     0.8,     0.8,     0.8,    0.8,   0.8,  &         !! - 30/01/04 NV/JO/PF
  &       0.8,   0.8,   undef,   undef,   undef,   undef  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: demi_alloc_mtc  =  &          !! NEW - allocation above/below = f(age) 
  & (/  undef,   5.0,     5.0,     5.0,     5.0,    5.0,   5.0,  &         !! - 30/01/04 NV/JO/PF
  &       5.0,   5.0,   undef,   undef,   undef,   undef  /)

  !-
  ! 3. Senescence
  !-
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: leaffall_mtc  =  &             !! length of death of leaves, tabulated (days)
  & (/  undef,   undef,   10.0,   undef,   undef,   29.48,   undef,  &
  &      4.71,    9.41,   10.0,    10.0,    10.0,   10.0  /)

  CHARACTER(LEN=6), PARAMETER, DIMENSION(nvmc) :: senescence_type_mtc  =  & !! type of senescence, tabulated (unitless)
  & (/  'none  ',  'none  ',   'dry   ',  'none  ',  'none  ',  &
  &     'cold  ',  'none  ',   'cold  ',  'cold  ',  'mixed ',  &
  &     'mixed ',  'crop  ',   'crop  '            /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: senescence_hum_mtc  =  &       !! critical relative moisture availability
  & (/  undef,   undef,   0.3,   undef,   undef,   undef,   undef,  &       !! for senescence (0-1, unitless)
  &     undef,   undef,   0.2,     0.2,     0.3,     0.2  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: nosenescence_hum_mtc  =  &     !! relative moisture availability above which 
  & (/  undef,   undef,   0.8,   undef,   undef,   undef,   undef,  &       !! there is no humidity-related senescence
  &     undef,   undef,   0.63,     0.3,     0.3,     0.3  /)                !! (0-1, unitless)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: max_turnover_time_mtc  =  &    !! maximum turnover time for grasses (days)
  & (/  undef,   undef,   undef,   undef,   undef,   undef,   undef,  &
  &     undef,   undef,    80.0,    80.0,    80.0,    80.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: min_turnover_time_mtc  =  &    !! minimum turnover time for grasses (days)
  & (/  undef,   undef,   undef,   undef,   undef,   undef,   undef,  &
  &     undef,   undef,    10.0,    10.0,    10.0,    10.0  /)
 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: min_leaf_age_for_senescence_mtc  =  &  !! minimum leaf age to allow 
  & (/  undef,   undef,   90.0,   undef,   undef,   90.0,   undef,  &               !! senescence g (days)
  &      60.0,    60.0,   30.0,    30.0,    30.0,   30.0  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: senescence_temp_c_mtc  =  &    !! critical temperature for senescence (C)
  & (/  undef,   undef,    undef,   undef,   undef,   16.57,   undef,  &     !! constant c of aT^2+bT+c, tabulated
  &       14.61,    12.0,   9.38,     5.0,    13.0,    10.0  /)              !! (unitless)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: senescence_temp_b_mtc  =  &    !! critical temperature for senescence (C), 
  & (/  undef,   undef,   undef,   undef,   undef,   0.0,   undef,  &       !! constant b of aT^2+bT+c, tabulated
  &       0.0,     0.0,     0.1,     0.0,     0.0,   0.0  /)                !! (unitless)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: senescence_temp_a_mtc  =  &    !! critical temperature for senescence (C), 
  & (/  undef,   undef,     undef,   undef,   undef,   0.0,   undef,  &     !! constant a of aT^2+bT+c, tabulated
  &       0.0,     0.0,   0.00375,     0.0,     0.0,   0.0  /)              !! (unitless)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: gdd_senescence_mtc  =  &       !! minimum gdd to allow senescence of crops (days)
  & (/  undef,   undef,    undef,   undef,     undef,    undef,    undef,  &
  &     undef,   undef,    undef,   undef,     1500.,    1500.  /)


  !
  ! DGVM
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: residence_time_mtc  =  &    !! residence time of trees (years). NOTE: the meaning of  
  & (/  undef,   30.0,   30.0,   40.0,   40.0,   40.0,   80.0,  &        !! ::residence_time is very different between the DOFOCO
  &      80.0,   80.0,    0.0,    0.0,    0.0,    0.0  /)                !! branch and the trunk. In the trunk biomass has no age
                                                                         !! thus the residence time accounts for all forest dynamics 
                                                                         !! including self-thinning, pests, diseases and wind fall. 
                                                                         !! In the DOFOCO branch biomass has an age and 
                                                                         !! self-thinning is explicitly accounted for. Hence, the 
                                                                         !! residence time should be much higher as it only accounts 
                                                                         !! for mortality due to pest, diseases and windfall. Even the 
                                                                         !! latter is not exact because as long as those disturbances 
                                                                         !! are small scale they are probably accounted for in the       ! added by yitong yao 07 Jan 2020 08:43                                !! parametrization of self-thinning.
  REAL(r_std), PARAMETER, DIMENSION(nvmc)  :: plc_kill_frac_mtc  =  &
  & (/  undef,   0.01,   0.01,   0.01,   0.01,   0.01,   0.01,  & 
  &     0.01,    0.01,   0.0,    0.0,   0.0,   0.0   /)
  ! added by yitong yao 07 Jan 2020 08:44 above line   
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc)  :: mor_kill_frac_mtc  =  &
  & (/  undef,   0.001,   0.01,   0.01,   0.01,   0.01,   0.01,  &
  &     0.01,    0.01,   0.0,    0.0,   0.0,   0.0   /)


  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tmin_crit_mtc  =  &
  & (/  undef,     0.0,     0.0,   -30.0,   -14.0,   -30.0,   -45.0,  &  !! critical tmin, tabulated (C)
  &     -45.0,   undef,   undef,   undef,   undef,   undef  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: tcm_crit_mtc  =  &
  & (/  undef,   undef,   undef,     5.0,    15.5,    15.5,   -8.0,  &   !! critical tcm, tabulated (C)
  &      -8.0,    -8.0,   undef,   undef,   undef,   undef  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: mortality_min_mtc = &       !! Asymptotic mortality if plant growth exceeds long term
  & (/  undef,  0.01,  0.01,  0.01,  0.01,  0.01,  0.01,  &               !! NPP (thus a strongly growing PFT)
  &      0.01,  0.01,  0.01,  0.01,  0.01,  0.01  /)                      !! @tex $(year^{-1})$ @endtex
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: mortality_max_mtc = &       !! Maximum mortality if plants hardly grows thus 
  & (/  undef,  0.1,  0.1,  0.1,  0.1,  0.1,  0.1,  &                      !! NPP << NPPlongterm @tex $(year^{-1})$ @endtex
  &       0.1,  0.1,  0.1,  0.1,  0.1,  0.1  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: ref_mortality_mtc = &       !! Reference mortality rate used to calculate mortality
  & (/  undef,  0.035,  0.035,  0.035,  0.035,  0.035,  0.035,  &        !! as a function of the plant vigor 
  &     0.035,  0.035,  0.035,  0.035,  0.035,  0.035  /)                !! @tex $(year^{-1})$ @endtex



  !
  ! Biogenic Volatile Organic Compounds
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_isoprene_mtc = &     !! Isoprene emission factor 
  & (/  0.,    24.,   24.,    8.,   16.,   45.,   8.,  &                    !!
  &     8.,     8.,   16.,   24.,    5.,    5.  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_monoterpene_mtc = &  !! Monoterpene emission factor
  & (/   0.,   0.8,    0.8,   2.4,    1.2,    0.8,    2.4,  &               !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &    2.4,    2.4,    0.8,   1.2,    0.2,     0.2  /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_ORVOC_mtc = &        !! ORVOC emissions factor 
  &  (/  0.,    1.5,    1.5,    1.5,    1.5,   1.5,    1.5,  &              !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &     1.5,    1.5,    1.5,    1.5,    1.5,   1.5  /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_OVOC_mtc = &         !! OVOC emissions factor 
  &  (/  0.,    1.5,    1.5,    1.5,    1.5,   1.5,    1.5,  &              !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &     1.5,    1.5,    1.5,    1.5,    1.5,   1.5  /)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_MBO_mtc = &          !! MBO emissions factor
  & (/  0.,    0.,    0.,    20.0,    0.,    0.,    0.,  &                  !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &     0.,    0.,    0.,       0.,   0.,    0.  /)  
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_methanol_mtc = &     !! Methanol emissions factor 
  & (/  0.,    0.6,   0.6,   1.8,   0.9,   0.6,   1.8,  &                   !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &    1.8,    1.8,   0.6,   0.9,    2.,     2.  /)  
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_acetone_mtc = &      !! Acetone emissions factor
  & (/  0.,   0.29,   0.29,   0.87,   0.43,   0.29,   0.87,  &              !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &   0.87,   0.87,   0.29,   0.43,   0.07,   0.07  /)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_acetal_mtc = &       !! Acetaldehyde emissions factor 
  & (/  0.,   0.1,    0.1,     0.3,    0.15,   0.1,   0.3,   0.3,   &       !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &    0.3,   0.1,   0.15,   0.025,   0.025  /)  
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_formal_mtc = &       !! Formaldehyde emissions factor
  & (/  0.,   0.07,   0.07,   0.2,     0.1,    0.07,   0.2,  &              !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &    0.2,    0.2,   0.07,   0.1,   0.017,   0.017  /)  

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_acetic_mtc = &       !! Acetic Acid emissions factor
  & (/   0.,   0.002,   0.002,   0.006,   0.003,     0.002,   0.006,   &    !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &   0.006,   0.006,   0.002,   0.003,   0.0005,   0.0005  /)  

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: em_factor_formic_mtc = &       !! Formic Acid emissions factor
  & (/  0.,   0.01,   0.01,   0.03,     0.015,     0.01,   0.03,  &         !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
  &   0.03,   0.03,   0.01,   0.015,   0.0025,   0.0025  /)  

  REAL(r_std),PARAMETER, DIMENSION(nvmc) :: em_factor_no_wet_mtc = &        !! NOx emissions factor soil emissions and exponential
  & (/  0.,   2.6,   0.06,   0.03,   0.03,   0.03,   0.03,  &               !! dependancy factor for wet soils
  &  0.03,   0.03,   0.36,   0.36,   0.36,   0.36  /)                       !! @tex $(ngN.m^{-2}.s^{-1})$ @endtex

  REAL(r_std),PARAMETER, DIMENSION(nvmc) :: em_factor_no_dry_mtc = &        !! NOx emissions factor soil emissions and exponential
  & (/  0.,   8.60,   0.40,   0.22,   0.22,   0.22,   0.22,  &              !! dependancy factor for dry soils
  &   0.22,   0.22,   2.65,   2.65,   2.65,   2.65  /)                      !! @tex $(ngN.m^{-2}.s^{-1})$ @endtex 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: Larch_mtc = &                  !! Larcher 1991 SAI/LAI ratio (unitless)
  & (/   0.,   0.015,   0.015,   0.003,   0.005,   0.005,   0.003,  &
  &   0.005,   0.003,   0.005,   0.005,   0.008,   0.008  /)  

  !
  ! Forest Management
  !

!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fm_allo_a_mtc = &
!!$  & (/ undef,   19.42,   19.42,     9.3,   19.42,   19.42,   9.3,  &        
!!$  &    19.42,     9.3,   undef,   undef,   undef,   undef   /)   
!!$    
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fm_allo_c_mtc = &
!!$  & (/ undef,    0.11,   0.11,     0.35,   0.11,    0.11,   0.35,  &        
!!$  &    0.11,     0.35,   undef,   undef,   undef,   undef   /)     
!!$  
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fm_allo_d_mtc = &
!!$  & (/ undef,    0.13,   0.13,     0.3,   0.13,    0.13,   0.3,  &        
!!$  &    0.13,     0.3,   undef,   undef,   undef,   undef   /)     
!!$  
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fm_allo_p_mtc = &
!!$  & (/ undef,    0.75,   0.75,     0.69,   0.75,    0.75,   0.69,  &        
!!$  &    0.75,     0.69,   undef,   undef,   undef,   undef   /) 
!!$      
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: fm_allo_q_mtc = &
!!$  & (/ undef,    -0.12,   -0.12,     -0.32,   -0.12,    -0.12,   -0.32,  &        
!!$  &    -0.12,    -0.32,    undef,    undef,   undef,    undef   /)
!!$       
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: allo_crown_a0_mtc = &
!!$  & (/   undef,   -0.7602,   -0.7602,     -1.019,   -0.7602,   -0.7602,   -1.019,  &        
!!$  &    -0.7602,    -1.019,     undef,      undef,     undef,      undef   /) 
!!$  
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: allo_crown_a1_mtc = &
!!$  & (/   undef,   0.6672,   0.6672,     0.887,   0.6672,   0.6672,   0.887,  &        
!!$  &    0.6672,     0.887,     undef,      undef,     undef,      undef   /)   
!!$
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: allo_crown_a2_mtc = &
!!$  & (/   undef,   0.12646,   0.12646,     0.188,   0.12646,   0.12646,   0.188,  &        
!!$  &    0.12646,     0.188,     undef,      undef,     undef,      undef   /)   
!!$
!!$  LOGICAL, PARAMETER, DIMENSION(nvmc) :: plantation_mtc = & 
!!$  & (/  .FALSE.,  .FALSE.,  .FALSE.,  .FALSE.,  .FALSE.,  .FALSE.,  .FALSE.,  &
!!$  &     .FALSE.,  .FALSE.,  .FALSE.,  .FALSE.,  .FALSE.,  .FALSE.  /)
!!$
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: decl_factor_mtc = &
!!$  & (/     0.0,   0.0005,   0.0005,   0.0007,   0.0005,   0.0005,   0.0009, & 
!!$  &    0.00075,   0.0005,      1.0,      1.0,      1.0,      1.0 /)    
!!$
!!$  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: opt_factor_mtc = & 
!!$  & (/  1.0,  1.0,  1.0,  1.0,  1.0,  1.0,  1.0,  &
!!$  &     1.0,  1.0,  1.0,  1.0,  1.0,  1.0  /)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: h_first_mtc = &                            !! Height at which thinning will start (m)            
  & (/   0.0,   10.0,   10.0,   10.0,   10.0,   10.0,  10.0,   &
  &     10.0,   10.0,    0.0,    0.0,    0.0,    0.0   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: dens_target_mtc =  &                       !! Minimal density. Below this density the forest
  & (/   0.0,   100.0,   100.0,   200.0,   100.0,   100.0,   200.0,  &                  !! will be clearcut (trees.ha-1)
  &    100.0,   200.0,     0.0,     0.0,     0.0,     0.0   /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: thinstrat_mtc =  &                         !! Thinning strategy. The FM code distinguished
  & (/   0.0,   1.0,   1.0,   1.0,   1.0,   1.0,   1.0,  &                              !! thinning from above (<0) or from below (>0).  
  &    1.0,   1.0,     0.0,     0.0,     0.0,     0.0   /)                              

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: taumin_mtc =  &                            !! Minimum probability that a tree get thinned (unitless)
  & (/   0.0,   0.01,   0.01,   0.01,   0.01,   0.01,   0.01,  &
  &    0.01,   0.01,     0.0,     0.0,     0.0,     0.0   /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: taumax_mtc =  &                            !! Maximum probability that a tree get thinned (unitless)
  & (/   0.0,   0.05,   0.05,   0.05,   0.05,   0.05,   0.05,  &
  &    0.05,   0.05,     0.0,     0.0,     0.0,     0.0   /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alpha_rdi_upper_mtc = &                    !! Coefficient of the yield-table derived thinning relationship 
  &(/ undef,  3000.,  3000.,  592.,  862.,  504.,  1287., &                             !! D=alpha*N^beta estimated from JRC yield table database 
  &    984.,   589.,  undef,  undef,  undef,  undef/)                                  
 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: beta_rdi_upper_mtc = &                     !! Coefficient of the yield-table derived thinning relationship 
  &(/ undef,  -0.57,  -0.57,  -0.46,  -0.51,  -0.44,  -0.59, &                          !! D=alpha*N^beta estimated from JRC yield table database 
  &   -0.57,  -0.48,  undef,  undef,  undef,  undef/)                                   

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: alpha_rdi_lower_mtc = &                    !! Coefficient of the yield-table derived thinning relationship 
  &(/ undef,  2999.,  2999.,  433.,  445.,  369.,  1022., &                             !! D=alpha*N^beta estimated from JRC yield table database 
  &    828.,   385.,  undef,  undef,  undef,  undef/)                                  
 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: beta_rdi_lower_mtc = &                     !! Coefficient of the yield-table derived thinning relationship 
  &(/ undef,  -0.57,  -0.57,  -0.46,  -0.51,  -0.44,  -0.59, &                          !! D=alpha*N^beta estimated from JRC yield table database 
  &   -0.57,  -0.48,  undef,  undef,  undef,  undef/) 
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: largest_tree_dia_mtc =  &                  !! Maximal tree diameter (m). If this diameter is exceeded a
  & (/   0.0,   .45,   .45,   .45,   .45,   .45,   .45,  &                              !! a clearcut will happen.
  &   .45,    .45,     0.0,     0.0,     0.0,     0.0   /) 

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: branch_ratio_mtc =  &                      !! Ratio of branches to total woody biomass (unitless)
  & (/  0.0,   0.38,   0.38,   0.25,   0.38,   0.38,   0.25,  &
  &    0.38,   0.25,    0.0,    0.0,    0.0,    0.0 /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: branch_harvest_mtc =  &                    !! Ratio of branches harvested in FM2 management.
  & (/  0.0,   1.0,   1.0,   1.0,   1.0,   1.0,   1.0,  &
  &    1.0,   1.0,    0.0,    0.0,    0.0,    0.0 /)

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: m_dv_mtc = &                               !! Parameter in the Deleuze & Dhote allocation 
  & (/ undef,  1.05,  1.05,  1.05,  1.05,  1.05,  1.05, &                               !! rule that relaxes the cut-off imposed by
  &     1.05,  1.05,    0.,    0.,    0.,    0. /)                                      !! ::sigma. Owing to m_relax trees still grow
                                                                                        !! a little when their ::circ is below ::sigma
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: coppice_diameter_mtc = &                   !! The trunk diameter above which one coppices
  & (/ undef,  0.20,  0.20,  0.20,  0.20,  0.20,  0.20, &                               !! trees. (m)
  &     0.20,  0.20,    0.,    0.,    0.,    0. /)                                      
  INTEGER(i_std), PARAMETER, DIMENSION(nvmc) :: shoots_per_stool_mtc = &                !! The number of shoots which regrow on a stool after
  (/ 9999,  6,     6,     6,      6,     6,     6, &                                    !! coppicing. 
  6,  6, 9999, 9999,  9999, 9999 /)   
  INTEGER(i_std), PARAMETER, DIMENSION(nvmc) :: src_rot_length_mtc = &                  !! The number of years between SRC cuttings.
  (/ 9999,   3,     3,     3,     3,     3,     3, &                                    !! (-)
  3,   3, 9999, 9999, 9999, 9999 /)                            
  INTEGER(i_std), PARAMETER, DIMENSION(nvmc) :: src_nrots_mtc = &                       !! The number of SRC rotations before the whole stand
  (/ 9999,   10,    10,    10,    10,    10,    10, &                                   !! is harvested (-)
  10,  10, 9999, 9999, 9999, 9999 /)
 
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: deleuze_a_mtc = &                          !! intercept of the intra-tree competition within a stand
  & (/ undef,  0.23,  0.23,  0.23,  0.23,  0.23,  0.23, &                               !! based on the competion rule of Deleuze and Dhote 2004
  &     0.23,  0.23, undef, undef, undef, undef /)                                      !! Used when n_circ > 6

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: deleuze_b_mtc = &                          !! slope of the intra-tree competition within a stand
  & (/ undef,  0.58,  0.58,  0.58,  0.58,  0.58,  0.58, &                               !! based on the competion rule of Deleuze and Dhote 2004
  &     0.58,  0.58, undef, undef, undef, undef /)                                      !! Used when n_circ > 6

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: deleuze_p_all_mtc = &                      !! Percentile of the circumferences that receives photosynthates
  & (/ undef,  0.50,  0.50,  0.99,  0.99,  0.99,  0.99, &                               !! based on the competion rule of Deleuze and Dhote 2004
  &     0.99,  0.99, undef, undef, undef, undef /)                                      !! Used when n_circ > 6 for FM1, FM2 and FM4

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: deleuze_p_coppice_mtc = &                  !! Percentile of the circumferences that receives photosynthates
  & (/ undef,  0.50,  0.50,  0.50,  0.50,  0.50,  0.50, &                               !! based on the competion rule of Deleuze and Dhote 2004
  &     0.50,  0.50, undef, undef, undef, undef /)                                      !! Used when n_circ > 6 for FM3

  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: recruitment_light_threshold_mtc = &          !! Light threshold (0 - 1) under which no recruitment is possible
  &(/ undef, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, 0.01, undef, undef, undef, undef/)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: dia_recr_mtc = &                         !! Diameter (m) of the recruited stems
  &(/ undef, 0.001, 0.001, 0.001, 0.001, 0.001, 0.001, 0.001, 0.001, undef, undef, undef, undef/)
  
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: hei_recr_mtc = &                         !! Height (m) of the recruited stems (derived from allometric equation
  &(/ undef, 0.9, 0.9, 0.9, 0.9, 0.9, 0.9, 0.9, 0.9, undef, undef, undef, undef/)     !! for Nouragues, French Guiana). 
  
 
  !
  ! CROP MAANAGEMENT
  !
  REAL(r_std), PARAMETER, DIMENSION(nvmc) :: harvest_ratio_mtc = &                      !! Share of biomass that is removed from the site during harvest
  & (/ undef,  undef,  undef,  undef,  undef,  undef,  undef, &                         !! A high value indicates a high harvest efficiency and thus a 
  &    undef,  undef,  undef,  undef,    0.5,    0.5 /)                                 !! input of residuals. (unitless, 0-1).
  
                                                                                      
END MODULE constantes_mtc
