! =================================================================================================================================
! MODULE       : pft_parameters_var
!
! CONTACT      : orchidee-help _at_ ipsl.jussieu.fr
!
! LICENCE      : IPSL (2011)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF        This module contains the variables in function of plant funtional type (pft).
!!
!!\n DESCRIPTION: This module contains the declarations for the externalized variables in function of the 
!!                plant foncional type(pft). \n
!!                The module is already USE in module pft_parameters. Therefor no need to USE it seperatly except
!!                if the subroutines in module pft_parameters are not needed.\n
!!
!! RECENT CHANGE(S): None
!!
!! REFERENCE(S)	: None
!!
!! SVN          :
!! $HeadURL: $
!! $Date: 2015-02-22 16:18:16 +0100 (Sun, 22 Feb 2015) $
!! $Revision: 2555 $
!! \n
!_ ================================================================================================================================

MODULE pft_parameters_var

  USE defprec
  
  IMPLICIT NONE


  !
  ! PFT GLOBAL
  !
  INTEGER(i_std), SAVE :: nvm = 13                               !! Number of vegetation types (2-N, unitless)
!$OMP THREADPRIVATE(nvm)

  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pft_to_mtc  !! Table of conversion : we associate one pft to one metaclass 
                                                                 !! (1-13, unitless)
!$OMP THREADPRIVATE(pft_to_mtc)

  CHARACTER(LEN=34), ALLOCATABLE, SAVE, DIMENSION(:) :: PFT_name !! Description of the PFT (unitless)
!$OMP THREADPRIVATE(PFT_name)

  LOGICAL, SAVE   :: l_first_pft_parameters = .TRUE.             !! To keep first call trace of the module (true/false)
!$OMP THREADPRIVATE(l_first_pft_parameters)
  LOGICAL, SAVE   :: ok_throughfall_by_pft = .TRUE.             !! Flag to use the parameter PERCENT_THROUGHFALL_PFT (true/false) 
!$OMP THREADPRIVATE(ok_throughfall_by_pft)


  !
  ! VEGETATION STRUCTURE
  !
  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: leaf_tab       !! leaf type (1-4, unitless)
                                                                    !! 1=broad leaved tree, 2=needle leaved tree, 
                                                                    !! 3=grass 4=bare ground 
!$OMP THREADPRIVATE(leaf_tab)

  CHARACTER(len=6), ALLOCATABLE, SAVE, DIMENSION(:) :: pheno_model  !! which phenology model is used? (tabulated) (unitless)
!$OMP THREADPRIVATE(pheno_model)

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: is_tree               !! Is the vegetation type a tree ? (true/false)
!$OMP THREADPRIVATE(is_tree)

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: is_deciduous          !! Is PFT deciduous ? (true/false)
!$OMP THREADPRIVATE(is_deciduous)

   LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: is_tropical          !! Is PFT tropical ? (true/false)
!$OMP THREADPRIVATE(is_tropical)

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: is_temperate          !! Is PFT temperate ? (true/false)
!$OMP THREADPRIVATE(is_temperate)

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: is_boreal             !! Is PFT boreal ? (true/false)
!$OMP THREADPRIVATE(is_boreal)

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: is_evergreen          !! Is PFT evegreen ? (true/false)
!$OMP THREADPRIVATE(is_evergreen)

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: is_needleleaf         !! Is PFT needleleaf ? (true/false)
!$OMP THREADPRIVATE(is_needleleaf)

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: natural               !! natural? (true/false)
!$OMP THREADPRIVATE(natural)

  CHARACTER(len=5), ALLOCATABLE, SAVE, DIMENSION(:) :: type_of_lai  !! Type of behaviour of the LAI evolution algorithm 
                                                                    !! for each vegetation type.
                                                                    !! Value of type_of_lai, one for each vegetation type :
                                                                    !! mean or interp
!$OMP THREADPRIVATE(type_of_lai)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: veget_ori_fixed_test_1 !! Value for veget_ori for tests in 0-dim simulations 
                                                                         !! (0-1, unitless)
!$OMP THREADPRIVATE(veget_ori_fixed_test_1)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: llaimax                !! laimax for maximum lai see also type of lai 
                                                                         !! interpolation
                                                                         !! @tex $(m^2.m^{-2})$ @endtex 
!$OMP THREADPRIVATE(llaimax)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: llaimin                !! laimin for minimum lai see also type of lai 
                                                                         !! interpolation 
                                                                         !! @tex $(m^2.m^{-2})$ @endtex
!$OMP THREADPRIVATE(llaimin)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: height_presc           !! prescribed height of vegetation.(m) Only used without stomate
                                                                         !! Value for height_presc : one for each vegetation type
!$OMP THREADPRIVATE(height_presc)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) ::  rveg_pft              !! Potentiometer to set vegetation resistance (unitless)
                                                                         !! Nathalie on March 28th, 2006 - from Fred Hourdin,
!$OMP THREADPRIVATE(rveg_pft)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: sla                    !! specif leaf area @tex $(m^2.gC^{-1})$ @endtex 
!$OMP THREADPRIVATE(sla)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: lai_happy              !! Lai threshold below which carbohydrate 
                                                                         !! reserve may be used in functional allocation.
                                                                         !! Also used in phenology to see if mixed classes
                                                                         !! should die.  These seem completely arbitrary.
                                                                         !! @tex $(m^2.m^{-2})$ @endtex 
!$OMP THREADPRIVATE(lai_happy)

  !
  ! EVAPOTRANSPIRATION (sechiba)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: rstruct_const          !! Structural resistance. 
                                                                         !! Value for rstruct_const : one for each vegetation type
                                                                         !! @tex $(s.m^{-1})$ @endtex
!$OMP THREADPRIVATE(rstruct_const)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: kzero                  !! A vegetation dependent constant used in the calculation
                                                                         !! of the surface resistance. 
                                                                         !! Value for kzero one for each vegetation type
                                                                         !! @tex $(kg.m^2.s^{-1})$ @endtex
!$OMP THREADPRIVATE(kzero)

  !
  ! WATER (sechiba)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: wmax_veg  !! Volumetric available soil water capacity in each PFT
                                                            !! @tex $(kg.m^{-3} of soil)$ @endtex
!$OMP THREADPRIVATE(wmax_veg)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: humcste   !! Root profile description for the different vegetation types.
                                                            !! These are the factor in the exponential which gets
                                                            !! the root density as a function of depth 
                                                            !! @tex $(m^{-1})$ @endtex
!$OMP THREADPRIVATE(humcste)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: throughfall_by_pft !! Fraction of rain intercepted by the canopy (0-100, unitless)
!$OMP THREADPRIVATE(throughfall_by_pft)

  !
  ! ALBEDO (sechiba)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: snowa_aged    !! Minimum snow albedo value for each vegetation type
                                                                !! after aging (dirty old snow) (unitless)
                                                                !! Source : Values are from the Thesis of S. Chalita (1992)
!$OMP THREADPRIVATE(snowa_aged)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: snowa_dec     !! Decay rate of snow albedo value for each vegetation type
                                                                !! as it will be used in condveg_snow (unitless)
                                                                !! Source : Values are from the Thesis of S. Chalita (1992)
!$OMP THREADPRIVATE(snowa_dec)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alb_leaf_vis  !! leaf albedo of vegetation type, visible albedo (unitless)
!$OMP THREADPRIVATE(alb_leaf_vis)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alb_leaf_nir  !! leaf albedo of vegetation type, near infrared albedo (unitless)
!$OMP THREADPRIVATE(alb_leaf_nir)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:,:) :: leaf_ssa       !! leaf single scattering albedo of all 
!$OMP THREADPRIVATE(leaf_ssa)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:,:) :: leaf_psd       !! leaf prefered scattering direction of all 
                                                                       !! vegetation types and spectra (unitless)
!$OMP THREADPRIVATE(leaf_psd)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:,:) :: bgd_reflectance  !! background reflectance of all vegetation types and spectra (unitless)
!$OMP THREADPRIVATE(bgd_reflectance)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: leaf_to_shoot_clumping       !! The clumping factor for leaves to shoots in the 
                                                                               !! effective LAI calculation...notice this should be
                                                                               !! equal to unity for grasslands/croplands
!$OMP THREADPRIVATE(leaf_to_shoot_clumping)


!---add by YC ---a constant for tunning the LAI, which coupled with the atmosphere for the transpiaration  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tune_coupled                 !! The coupled factor of LAI for the transpiration                                                                    
!$OMP THREADPRIVATE(tune_coupled)




! NOTE: this next variable originally was a plant-to-stand clumping factor to be used
! in describing how grasses and crops clump together at the plant level (but not trees, 
! as their plant-to-stand clumping is calculated directly) to calculate abledo. However, we
! get the effective spectral parameters for the albedo calculation from inverting satelite data,
! which includes all clumping.  Therefore we do not wish to account for this effect twice.
! What will be incorrect about our grassland and crop albedo is the lack of management options
! for these PFTs in ORCHIDEE, which will lead to LAI values which are wrong.  Thus we 
! will include an LAI correction factor in the calculation of the effective LAI which
! allows us to compensate for this via tuning. 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: lai_correction_factor  !! see note above
!$OMP THREADPRIVATE(lai_correction_factor)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: min_level_sep          !! This is used in determining the levels
                                                                         !! for photosynthesis.  This is the thinnest
                                                                         !! that the levels are allowed to be, in 
                                                                         !! vertical thickness.
                                                                         !! @tex $(m)$ @endtex
!$OMP THREADPRIVATE(min_level_sep)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: lai_top                !! Diffuco.f90 calculates the stomatal conductance of the
                                                                         !! top layer of the canopy. Because the top layer can contain
                                                                         !! different amounts of LAI depending on the crown diameter
                                                                         !! we had to define top layer in terms of the LAI it contains.
                                                                         !! stomatal conductance in the top layer contributes to the 
                                                                         !! transpiration (m2 m-2). Arbitrary values.
!$OMP THREADPRIVATE(lai_top)



  !
  ! SOIL - VEGETATION
  !
  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pref_soil_veg      !! Table which contains the correlation between the soil
                                                                        !! types and vegetation type. Two modes exist :
                                                                        !! 1) pref_soil_veg = 0 then we have an equidistribution
                                                                        !!    of vegetation on soil types
                                                                        !! 2) Else for each pft the prefered soil type is given :
                                                                        !!    1=sand, 2=loan, 3=clay
                                                                        !! This variable is initialized in slowproc.(1-3, unitless)
!$OMP THREADPRIVATE(pref_soil_veg)

  !
  ! PHOTOSYNTHESIS
  !
  !-
  ! 1. CO2
  !-
  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:) :: is_c4             !! flag for C4 vegetation types (true/false)
!$OMP THREADPRIVATE(is_c4)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: vcmax_fix     !! values used for vcmax when STOMATE is not activated
                                                                !! @tex $(\mu mol.m^{-2}.s^{-1})$ @endtex
!$OMP THREADPRIVATE(vcmax_fix)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: vjmax_fix     !! values used for vjmax when STOMATE is not activated 
                                                                !! @tex $(\mu mol.m^{-2}.s^{-1})$ @endtex
!$OMP THREADPRIVATE(vjmax_fix)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: co2_tmin_fix  !! values used for photosynthesis tmin when STOMATE 
                                                                !! is not activated (C)
!$OMP THREADPRIVATE(co2_tmin_fix)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: co2_topt_fix  !! values used for photosynthesis topt when STOMATE 
                                                                !! is not activated (C)
!$OMP THREADPRIVATE(co2_topt_fix)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: co2_tmax_fix  !! values used for photosynthesis tmax when STOMATE 
                                                                !! is not activated (C)
!$OMP THREADPRIVATE(co2_tmax_fix)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: downregulation_co2_coeff !! Coefficient for CO2 downregulation (unitless)
!$OMP THREADPRIVATE(downregulation_co2_coeff)


  !-
  ! 2. Stomate
  !-
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: ext_coeff     !! extinction coefficient of the Monsi&Saeki relationship (1953)
                                                                !! (unitless)
!$OMP THREADPRIVATE(ext_coeff)
 REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: E_KmC          !! Energy of activation for KmC (J mol-1)
!$OMP THREADPRIVATE(E_KmC)                                                               
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: E_KmO         !! Energy of activation for KmO (J mol-1)
!$OMP THREADPRIVATE(E_KmO)          
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: E_gamma_star  !! Energy of activation for gamma_star (J mol-1)
!$OMP THREADPRIVATE(E_gamma_star)    
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: E_Vcmax       !! Energy of activation for Vcmax (J mol-1) 
!$OMP THREADPRIVATE(E_Vcmax)                                                              
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: E_Jmax        !! Energy of activation for Jmax (J mol-1)
!$OMP THREADPRIVATE(E_Jmax) 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: aSV           !! a coefficient of the linear regression (a+bT) defining the Entropy term for Vcmax (J K-1 mol-1)
!$OMP THREADPRIVATE(aSV)    
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: bSV           !! b coefficient of the linear regression (a+bT) defining the Entropy term for Vcmax (J K-1 mol-1 °C-1)
!$OMP THREADPRIVATE(bSV)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tphoto_min   !! minimum photosynthesis temperature (deg C)
!$OMP THREADPRIVATE(tphoto_min) 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tphoto_max   !! maximum photosynthesis temperature (deg C)
!$OMP THREADPRIVATE(tphoto_max) 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: aSJ           !! a coefficient of the linear regression (a+bT) defining the Entropy term for Jmax (J K-1 mol-1)
!$OMP THREADPRIVATE(aSJ)    
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: bSJ           !! b coefficient of the linear regression (a+bT) defining the Entropy term for Jmax (J K-1 mol-1 °C-1)
!$OMP THREADPRIVATE(bSJ)    
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: D_Vcmax       !! Energy of deactivation for Vcmax (J mol-1)
!$OMP THREADPRIVATE(D_Vcmax)                     
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: D_Jmax        !! Energy of deactivation for Jmax (J mol-1)
!$OMP THREADPRIVATE(D_Jmax)                                    
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: E_Rd          !! Energy of activation for Rd (J mol-1)
!$OMP THREADPRIVATE(E_Rd)                                      
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: Vcmax25       !! Maximum rate of Rubisco activity-limited carboxylation at 25°C
                                                                !! @tex $(\mu mol.m^{-2}.s^{-1})$ @endtex
!$OMP THREADPRIVATE(Vcmax25)
 REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: arJV          !! a coefficient of the linear regression (a+bT) defining the Jmax25/Vcmax25 ratio (mu mol e- (mu mol CO2)-1)
!$OMP THREADPRIVATE(arJV)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: brJV          !! b coefficient of the linear regression (a+bT) defining the Jmax25/Vcmax25 ratio (mu mol e- (mu mol CO2)-1)
!$OMP THREADPRIVATE(brJV)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: KmC25         !! Michaelis–Menten constant of Rubisco for CO2 at 25°C (ubar)
!$OMP THREADPRIVATE(KmC25)                                     
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: KmO25         !! Michaelis–Menten constant of Rubisco for O2 at 25°C (ubar)
!$OMP THREADPRIVATE(KmO25)                
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: gamma_star25  !! Ci-based CO2 compensation point in the absence of Rd at 25°C (ubar)
!$OMP THREADPRIVATE(gamma_star25)       
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: a1            !! Empirical factor involved in the calculation of fvpd (-)
!$OMP THREADPRIVATE(a1)                                        
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: b1            !! Empirical factor involved in the calculation of fvpd (-)
!$OMP THREADPRIVATE(b1)                                        
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: g0            !! Residual stomatal conductance when irradiance approaches zero (mol m−2 s−1 bar−1)
!$OMP THREADPRIVATE(g0)                                        
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: h_protons     !! Number of protons required to produce one ATP (mol mol-1)
!$OMP THREADPRIVATE(h_protons)                                 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fpsir         !! Fraction of PSII e− transport rate partitioned to the C4 cycle (-)
!$OMP THREADPRIVATE(x)                                         
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fQ            !! Fraction of electrons at reduced plastoquinone that follow the Q-cycle (-) - Values for C3 platns are not used
!$OMP THREADPRIVATE(fQ)                                        
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fpseudo       !! Fraction of electrons at PSI that follow  pseudocyclic transport (-) - Values for C3 platns are not used
!$OMP THREADPRIVATE(fpseudo)                                   
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: kp            !! Initial carboxylation efficiency of the PEP carboxylase (mol m−2 s−1 bar−1) 
!$OMP THREADPRIVATE(kp)                                        
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alpha         !! Fraction of PSII activity in the bundle sheath (-)
!$OMP THREADPRIVATE(alpha)                                     
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: gbs           !! Bundle-sheath conductance (mol m−2 s−1 bar−1)
!$OMP THREADPRIVATE(gbs)                                       
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: theta         !! Convexity factor for response of J to irradiance (-)
!$OMP THREADPRIVATE(theta)                                     
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alpha_LL      !! Conversion efficiency of absorbed light into J at strictly limiting light (mol e− (mol photon)−1)
!$OMP THREADPRIVATE(alpha_LL)
                                                                                                                                                                              
  !
  ! ALLOCATION (stomate)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: S0            !! Default sapwood allocation (0-1, unitless)
!$OMP THREADPRIVATE(S0)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: L0            !! Default leaf allocation (0-1, unitless)
!$OMP THREADPRIVATE(L0)


  !
  ! RESPIRATION (stomate)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:,:) :: maint_resp_slope  !! slope of maintenance respiration coefficient 
                                                                      !! (1/K, 1/K^2, 1/K^3), used in the code
!$OMP THREADPRIVATE(maint_resp_slope)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: maint_resp_slope_c  !! slope of maintenance respiration coefficient (1/K),
                                                                      !! constant c of aT^2+bT+c , tabulated
!$OMP THREADPRIVATE(maint_resp_slope_c)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: maint_resp_slope_b  !! slope of maintenance respiration coefficient (1/K), 
                                                                      !! constant b of aT^2+bT+c , tabulated
!$OMP THREADPRIVATE(maint_resp_slope_b)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: maint_resp_slope_a  !! slope of maintenance respiration coefficient (1/K), 
                                                                      !! constant a of aT^2+bT+c , tabulated
!$OMP THREADPRIVATE(maint_resp_slope_a)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:,:) :: coeff_maint_zero  !! maintenance respiration coefficient at 0 deg C, 
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(coeff_maint_zero)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_leaf        !! maintenance respiration coefficient at 0 deg C,
                                                                      !! for leaves, tabulated 
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_leaf)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_sapabove    !! maintenance respiration coefficient at 0 deg C,
                                                                      !! for sapwood above, tabulated
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_sapabove)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_sapbelow    !! maintenance respiration coefficient at 0 deg C,
                                                                      !! for sapwood below, tabulated 
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_sapbelow)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_heartabove  !! maintenance respiration coefficient at 0 deg C
                                                                      !! for heartwood above, tabulated 
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_heartabove)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_heartbelow  !! maintenance respiration coefficient at 0 deg C,
                                                                      !! for heartwood below, tabulated 
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_heartbelow)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_root        !! maintenance respiration coefficient at 0 deg C,
                                                                      !! for roots, tabulated
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_root)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_fruit       !! maintenance respiration coefficient  at 0 deg C,
                                                                      !! for fruits, tabulated
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_fruit)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_carbres     !! maintenance respiration coefficient at 0 deg C,
                                                                      !! for carbohydrate reserve, tabulated
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_carbres)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cm_zero_labile      !! maintenance respiration coefficient at 0 deg C,
                                                                      !! for the labile pool, tabulated
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(cm_zero_labile)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: coeff_maint_init    !! initial value for maintenance respiration 
                                                                      !! coefficient at 0 deg C used in functional allocation
                                                                      !! @tex $(gC.gC^{-1}.day^{-1})$ @endtex
!$OMP THREADPRIVATE(coeff_maint_init)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: frac_growthresp     !! Fraction of growth respiration expressed as
                                                                      !! share of the total C that is to be allocated
                                                                      !! (0-1).
!$OMP THREADPRIVATE(frac_growthresp)

 REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: gpp_to_labile        !! The size of the labile pool as a fraction of the
                                                                      !! weekly gpp (-). For example, 3 indicates that the 
                                                                      !! is 3 times the weekly gpp. 
!$OMP THREADPRIVATE(gpp_to_labile)


  !
  ! STAND STRUCTURE (stomate) 
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pipe_density        !! Wood density in @tex $(gC.m^{-3})$ @endtex
!$OMP THREADPRIVATE(pipe_density)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pipe_tune1          !! crown area = pipe_tune1*stem diameter**pipe_tune_exp_coeff
!$OMP THREADPRIVATE(pipe_tune1)
  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pipe_tune2          !! height=pipe_tune2 * diameter**pipe_tune3
!$OMP THREADPRIVATE(pipe_tune2)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tree_ff             !! Volume reduction factor from cylinder to real tree shape (inc.branches)
!$OMP THREADPRIVATE(tree_ff)
  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pipe_tune3          !! height=pipe_tune2 * diameter**pipe_tune3
!$OMP THREADPRIVATE(pipe_tune3)      
  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pipe_tune4          !! ???needed for stem diameter
!$OMP THREADPRIVATE(pipe_tune4)      
  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pipe_k1             !! ???
!$OMP THREADPRIVATE(pipe_k1)       
  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pipe_tune_exp_coeff !! crown area = pipe_tune1*stem diameter**pipe_tune_exp_coeff
!$OMP THREADPRIVATE(pipe_tune_exp_coeff)      
  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: mass_ratio_heart_sap!! mass ratio (heartwood+sapwood)/heartwood 
!$OMP THREADPRIVATE(mass_ratio_heart_sap)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: lai_to_height       !! Covert lai into vegetation height for grasses and crops
!$OMP THREADPRIVATE(lai_to_height)    

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: canopy_cover        !! Canopy cover - current values are guesses for testing
                                                                      !! could tune this variable to match MODIS albedo
!$OMP THREADPRIVATE(canopy_cover)
 

  !
  ! GROWTH (resource limitation - stomate) 
  !  
  
  !
  ! GROWTH (functional allocation - stomate)
  !  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cn_leaf_prescribed  !! CN of foliage for allocation, according to stich et al 2003
!$OMP THREADPRIVATE(cn_leaf_prescribed)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fcn_wood            !! CN of wood for allocation, relative to leaf CN according
                                                                      !! to stich et al 2003
!$OMP THREADPRIVATE(fcn_wood)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fcn_root            !! CN of roots for allocation, relative to leaf CN according
                                                                      !! to stich et al 2003
!$OMP THREADPRIVATE(fcn_root)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: k_latosa_max       !! Maximum leaf-to-sapwood area ratio (unitless)
!$OMP THREADPRIVATE(k_latosa_max)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: k_latosa_min       !! Minimum leaf-to-sapwood area ratio (unitless)
!$OMP THREADPRIVATE(k_latosa_min)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fruit_alloc         !! Fraction of biomass allocated to fruit production (0-1)

!$OMP THREADPRIVATE(fruit_alloc) 

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: m_dv                !! Parameter in the Deleuze & Dhote allocation rule that
                                                                      !! relaxes the cut-off imposed by ::sigma. Owing to m_relax 
                                                                      !! trees still grow a little when their ::circ is below 
                                                                      !! ::sigma
REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: recruitment_light_threshold !! Parameter in the Deleuze & Dhote allocation rule that
                                                                      !! relaxes the cut-off imposed by ::sigma. Owing to m_relax 
                                                                      !! trees still grow a little when their ::circ is below 
                                                                      !! ::sigma
!$OMP THREADPRIVATE(recruitment_light_threshold) 

REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: dia_recr              !! Parameter in the Deleuze & Dhote allocation rule that
                                                                      !! relaxes the cut-off imposed by ::sigma. Owing to m_relax 
                                                                      !! trees still grow a little when their ::circ is below 
                                                                      !! ::sigma
!$OMP THREADPRIVATE(dia_recr) 

REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: hei_recr              !! Parameter in the Deleuze & Dhote allocation rule that
                                                                      !! relaxes the cut-off imposed by ::sigma. Owing to m_relax 
                                                                      !! trees still grow a little when their ::circ is below 
                                                                      !! ::sigma
!$OMP THREADPRIVATE(hei_recr) 
                                                                      
!$OMP THREADPRIVATE(m_dv) 

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: lai_max_to_happy    !! Multiplicative factor of lai_max that determines
                                                                      !! the threshold value of LAI below which the carbohydrate
                                                                      !! reserve is used. 
                                                       
!$OMP THREADPRIVATE(lai_max_to_happy) 

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: k_root              !! Fine root specific conductivity 
                                                                      !! @tex $(m^{3} kg^{-1} s^{-1} MPa^{-1})$ @endtex 
!$OMP THREADPRIVATE(k_root)
 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: k_sap               !! Sapwood specific conductivity
                                                                      !! @tex $(m^{3} kg^{-1} s^{-1} MPa^{-1})$ @endtex 
!$OMP THREADPRIVATE(k_sap)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: k_leaf              !! Leaf conductivity @tex $(m s^{-1} MPa^{-1})$ @endtex
!$OMP THREADPRIVATE(k_leaf)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: phi_leaf            !! Minimal leaf water potential @tex $(m s^{-1} MPa^{-1})$ @endtex
!$OMP THREADPRIVATE(phi_leaf)
  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: phi_50              !! Sapwood leaf water potential that causes 50% loss of xylem
                                                                      !! conductivity through cavitation @tex $(m s^{-1} MPa^{-1})$ @endtex
!$OMP THREADPRIVATE(phi_50)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: c_cavitation        !! Shape parameter for loss of conductance Machado & Tyree, 1994 (unitless)          
!$OMP THREADPRIVATE(c_cavitation)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: phi_soil_tune       !! Additive tuning parameter to account for soil-root interaction
                                                                      !! @tex $(MPa)$ @endtex        
!$OMP THREADPRIVATE(phi_soil_tune)

! -----------------------------------------------------------------------------------------------------
! tzjh hydraulic conductivity

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: gpsi    !! gs vs psi_leaf curve parameter     
!$OMP THREADPRIVATE(gpsi)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: gpsi_50    !! psi_leaf at 50% stomatal closure, -MPa       
!$OMP THREADPRIVATE(gpsi_50)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: gmax    !! maximum stomatal conductance @tex $mmol m^{-2}s^{-1}$ @endtex   
!$OMP THREADPRIVATE(gmax)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: gmin    !! minimum stomatal conductance @tex $mmol m^{-2}s^{-1}$ @endtex   
!$OMP THREADPRIVATE(gmin)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: kmax_leaf    !! maximum hydraulic conductivity of leaf @tex $mmol m^{-2}s^{-1} MPa^{-1}$ @endtex   
!$OMP THREADPRIVATE(kmax_leaf)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: kmax_stem    !! maximum hydraulic conductivity of stem @tex $mmol m^{-2}s^{-1} MPa^{-1}$ @endtex   
!$OMP THREADPRIVATE(kmax_stem)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: kmax_root    !! maximum hydraulic conductivity of root @tex $mmol m^{-2}s^{-1} MPa^{-1}$ @endtex   
!$OMP THREADPRIVATE(kmax_root)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: a_leaf    !!  kleaf vs. psi_leaf curve parameter  
!$OMP THREADPRIVATE(a_leaf)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: a_stem    !!  kstem vs. psi_stem curve parameter  
!$OMP THREADPRIVATE(a_stem)
 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: a_root    !!  kroot vs. psi_root curve parameter  
!$OMP THREADPRIVATE(a_root)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: P50_leaf    !!  psi_leaf at 50% loss of leaf hydraulic conductivity, MPa  
!$OMP THREADPRIVATE(P50_leaf)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: P50_stem    !!  psi_stem at 50% loss of leaf hydraulic conductivity, MPa  
!$OMP THREADPRIVATE(P50_stem)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: P50_root    !!  psi_root at 50% loss of leaf hydraulic conductivity, MPa  
!$OMP THREADPRIVATE(P50_root)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: wood_density    !!  g of stem dry mass per m3 of stem volume Averaged across all Neotropical species from Chave et al. 2006 Ecological Applications  
!$OMP THREADPRIVATE(wood_density)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: w_density_stem    !!  mmol H2O per m3 of stem volume values averaged from a Bornean tropical forest  
!$OMP THREADPRIVATE(w_density_stem)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: root_shoot_ratio    !!   ratio of root mass to shoot mass, g g-1 values are averaged for wet an dry tropical forests from Mokany et al. 2005 Global Change Biology
!$OMP THREADPRIVATE(root_shoot_ratio)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: rwc_root    !!  mmol H2O per g of dry root mass dry tropical forests from Mokany et al. 2005 Global Change Biology
!$OMP THREADPRIVATE(rwc_root)
 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: root_density    !! wood density of the roots, g dry mass cm-3 volume  
!$OMP THREADPRIVATE(root_density)
  
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: LDMC    !! leaf dry matter content (g dry mass g-1 fresh mass),    
!$OMP THREADPRIVATE(LDMC)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: sla_hydro    !! sla (m2 kg-1), currenly the global mean in the TRY    
!$OMP THREADPRIVATE(sla_hydro)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cxyl   !!  stem capacitance, kg m^-3 MPa-1  
!$OMP THREADPRIVATE(cxyl)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cr   !!  root capacitance, kg m^-3 MPa-1  
!$OMP THREADPRIVATE(cr)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cl   !!  leaf capacitance, mmol m^-2 MPa-1  
!$OMP THREADPRIVATE(cl)


  !
  ! PRESCRIBE (stomate)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tune_reserves_in_sapling  !! A factor to scale the reserve pool of newly
                                                                      !! planted saplings.  This is required by some deciduous
                                                                      !! trees in order to survive the first year until budburst,
                                                                      !! but it has no physical basis.
                                                                      !! (unitless)

!$OMP THREADPRIVATE(tune_reserves_in_sapling)

  !
  ! MORTALITY (stomate)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) &
                          :: death_distribution_factor              !! The scale factor between the smallest and largest 
                                                                    !! circ class for tree mortality in lpj_kill.
                                                                    !! (unitless)
!$OMP THREADPRIVATE(death_distribution_factor)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) &
                          :: npp_reset_value                        !! The value of the NPP that the long-term value is
                                                                    !! reset to after a PFT dies in stomate_kill.  This
                                                                    !! only seems to be used for non-trees.
                                                                    !! @tex $(gC m^{-2})$ @endtex
!$OMP THREADPRIVATE(npp_reset_value)

  !
  ! FIRE (stomate)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: flam              !! flamability : critical fraction of water holding 
                                                                    !! capacity (0-1, unitless)
!$OMP THREADPRIVATE(flam)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: resist            !! fire resistance (0-1, unitless)
!$OMP THREADPRIVATE(resist)


  !
  ! FLUX - LUC (Land Use Change)
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: coeff_lcchange_s   !! Coeff of biomass export for the year (unitless)
!$OMP THREADPRIVATE(coeff_lcchange_s)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: coeff_lcchange_m  !! Coeff of biomass export for the decade (unitless)
!$OMP THREADPRIVATE(coeff_lcchange_m)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: coeff_lcchange_l !! Coeff of biomass export for the century (unitless)
!$OMP THREADPRIVATE(coeff_lcchange_l)
 
 
  !
  ! PHENOLOGY
  !
  !-
  ! 1. Stomate
  !-
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: lai_max           !! maximum LAI, PFT-specific @tex $(m^2.m^{-2})$ @endtex
!$OMP THREADPRIVATE(lai_max)

  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pheno_type     !! type of phenology (0-4, unitless)
                                                                    !! 0=bare ground 1=evergreen,  2=summergreen, 
                                                                    !! 3=raingreen,  4=perennial
                                                                    !! For the moment, the bare ground phenotype is not managed, 
                                                                    !! so it is considered as "evergreen"
!$OMP THREADPRIVATE(pheno_type)

  !-
  ! 2. Leaf Onset
  !-
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:,:) :: pheno_gdd_crit   !! critical gdd,tabulated (C), used in the code
!$OMP THREADPRIVATE(pheno_gdd_crit)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pheno_gdd_crit_c   !! critical gdd,tabulated (C), 
                                                                     !! constant c of aT^2+bT+c (unitless)
!$OMP THREADPRIVATE(pheno_gdd_crit_c)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pheno_gdd_crit_b   !! critical gdd,tabulated (C), 
                                                                     !! constant b of aT^2+bT+c (unitless)
!$OMP THREADPRIVATE(pheno_gdd_crit_b)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: pheno_gdd_crit_a   !! critical gdd,tabulated (C), 
                                                                     !! constant a of aT^2+bT+c (unitless)
!$OMP THREADPRIVATE(pheno_gdd_crit_a)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: ngd_crit           !! critical ngd,tabulated. Threshold -5 degrees (days)
!$OMP THREADPRIVATE(ngd_crit)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: opti_kpheno_crit   !! multiplicative factor to use optimised gdd_crit (Natasha MacBean)
                                                                     !! (unitless)
!$OMP THREADPRIVATE(opti_kpheno_crit)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: ncdgdd_temp        !! critical temperature for the ncd vs. gdd function
                                                                     !! in phenology (C)
!$OMP THREADPRIVATE(ncdgdd_temp)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: hum_frac           !! critical humidity (relative to min/max) for phenology
                                                                     !! (0-1, unitless)
!$OMP THREADPRIVATE(hum_frac)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: hum_min_time       !! minimum time elapsed since moisture minimum (days)
!$OMP THREADPRIVATE(hum_min_time)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tau_sap            !! turnover sapwood -> heartwood conversion time (1/days)
!$OMP THREADPRIVATE(tau_sap)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tau_fruit          !! fruit turnover (1/days)
!$OMP THREADPRIVATE(tau_fruit)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tau_root           !! root turnover (1/days)
!$OMP THREADPRIVATE(tau_root)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tau_leaf           !! leaf turnover (1/years)
!$OMP THREADPRIVATE(tau_leaf)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: ecureuil           !! fraction of primary leaf and root allocation put
                                                                     !! into reserve (0-1, unitless)
!$OMP THREADPRIVATE(ecureuil)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alloc_min          !! NEW - allocation above/below = f(age) - 30/01/04 NV/JO/PF
!$OMP THREADPRIVATE(alloc_min)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alloc_max          !! NEW - allocation above/below = f(age) - 30/01/04 NV/JO/PF
!$OMP THREADPRIVATE(alloc_max)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: demi_alloc         !! NEW - allocation above/below = f(age) - 30/01/04 NV/JO/PF
!$OMP THREADPRIVATE(demi_alloc)


  !-
  ! 3. Senescence
  !-
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: leaffall              !! length of death of leaves,tabulated (days)
!$OMP THREADPRIVATE(leaffall)

  CHARACTER(len=6), ALLOCATABLE, SAVE, DIMENSION(:) :: senescence_type  !! type of senescence,tabulated (unitless)
                                                                        !! List of avaible types of senescence :
                                                                        !! 'cold  ', 'dry   ', 'mixed ', 'none  '
!$OMP THREADPRIVATE(senescence_type)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: senescence_hum        !! critical relative moisture availability for senescence
                                                                        !! (0-1, unitless)
!$OMP THREADPRIVATE(senescence_hum)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: nosenescence_hum      !! relative moisture availability above which there is
                                                                        !! no humidity-related senescence (0-1, unitless)
!$OMP THREADPRIVATE(nosenescence_hum)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: max_turnover_time     !! maximum turnover time for grasses (days)
!$OMP THREADPRIVATE(max_turnover_time)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: min_turnover_time     !! minimum turnover time for grasses (days)
!$OMP THREADPRIVATE(min_turnover_time)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: min_leaf_age_for_senescence  !! minimum leaf age to allow senescence g (days)
!$OMP THREADPRIVATE(min_leaf_age_for_senescence)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:,:) :: senescence_temp     !! critical temperature for senescence (C),
                                                                        !! used in the code
!$OMP THREADPRIVATE(senescence_temp)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: senescence_temp_c     !! critical temperature for senescence (C), 
                                                                        !! constant c of aT^2+bT+c , tabulated (unitless)
!$OMP THREADPRIVATE(senescence_temp_c)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: senescence_temp_b     !! critical temperature for senescence (C), 
                                                                        !! constant b of aT^2+bT+c , tabulated (unitless)
!$OMP THREADPRIVATE(senescence_temp_b)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: senescence_temp_a     !! critical temperature for senescence (C),
                                                                        !! constant a of aT^2+bT+c , tabulated (unitless)
!$OMP THREADPRIVATE(senescence_temp_a)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: gdd_senescence        !! minimum gdd to allow senescence of crops (days)
!$OMP THREADPRIVATE(gdd_senescence)

  !
  ! DGVM
  !
  ! added by yitong yao 07 Jan 08:37 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: plc_kill_frac     !! fraction 
  ! added by yitong yao 07 Jan 08:37 above line 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: mor_kill_frac     !! fraction
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: residence_time    !! residence time of trees (y) 
!$OMP THREADPRIVATE(residence_time)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tmin_crit         !! critical tmin, tabulated (C)
!$OMP THREADPRIVATE(tmin_crit)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tcm_crit          !! critical tcm, tabulated (C)
!$OMP THREADPRIVATE(tcm_crit)

REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)   :: mortality_min     !! Asymptotic mortality if plant growth exceeds long term
                                                                    !! NPP @tex $(year^{-1})$ @endtex
!$OMP THREADPRIVATE(mortality_min) 

REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)   :: mortality_max     !! Maximum mortality if plants hardly grows
                                                                    !! @tex $(year^{-1})$ @endtex
!$OMP THREADPRIVATE(mortality_max) 

REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)   :: ref_mortality     !! Reference mortality rate used to calculate mortality
                                                                    !! as a function of the plant vigor @tex $(year^{-1})$ @endtex
!$OMP THREADPRIVATE(ref_mortality) 

  !
  ! Seasonal average
  !
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: tau_hum_growingseason !! Time integral to calculate the mean growingseason
                                                                        !! plant available soilmoisture (days)
!$OMP THREADPRIVATE(tau_hum_growingseason)


  !
  ! Biogenic Volatile Organic Compounds
  !

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_isoprene       !! Isoprene emission factor
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_isoprene)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_monoterpene    !! Monoterpene emission factor
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_monoterpene)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_ORVOC          !! ORVOC emissions factor
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_ORVOC)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_OVOC           !! OVOC emissions factor
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_OVOC)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_MBO            !! MBO emissions factor 
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_MBO)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_methanol       !! Methanol emissions factor
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_methanol)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_acetone        !! Acetone emissions factor 
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_acetone)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_acetal         !! Acetaldehyde emissions factor
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_acetal)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_formal         !! Formaldehyde emissions factor
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_formal)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_acetic         !! Acetic Acid emissions factor 
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_acetic)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_formic         !! Formic Acid emissions factor 
                                                                           !! @tex $(\mu gC.g^{-1}.h^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_formic)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_no_wet         !! NOx emissions factor soil emissions and 
                                                                           !! exponential dependancy factor for wet soils
                                                                           !! @tex $(ngN.m^{-2}.s^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_no_wet)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: em_factor_no_dry         !! NOx emissions factor soil emissions and
                                                                           !! exponential dependancy factor for dry soils
                                                                           !! @tex $(ngN.m^{-2}.s^{-1})$ @endtex
!$OMP THREADPRIVATE(em_factor_no_dry)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: Larch                    !! Larcher 1991 SAI/LAI ratio (unitless)
!$OMP THREADPRIVATE(Larch)

  !
  ! INTERNAL PARAMETERS USED IN STOMATE_DATA
  !

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: lai_initmin   !! Initial lai for trees/grass 
                                                                !! @tex $(m^2.m^{-2})$ @endtex
!$OMP THREADPRIVATE(lai_initmin)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: bm_sapl_old   !! sapling biomass for the OLD allocation
                                                                    !! @tex $(gC.ind^{-1})$ @endtex
!$OMP THREADPRIVATE(bm_sapl_old)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: migrate       !! migration speed @tex $(m.year^{-1})$ @endtex
!$OMP THREADPRIVATE(migrate)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: maxdia        !! maximum stem diameter from which on crown area no longer 
                                                                !! increases (m)
!$OMP THREADPRIVATE(maxdia)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: cn_sapl       !! crown of tree when sapling  @tex $(m^2$)$ @endtex
!$OMP THREADPRIVATE(cn_sapl)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: leaf_timecst  !! time constant for leaf age discretisation (days)
!$OMP THREADPRIVATE(leaf_timecst)
 
  !
  ! FOREST MANAGEMENT
  !

  LOGICAL, ALLOCATABLE, SAVE, DIMENSION(:)     :: plantation        !!
!$OMP THREADPRIVATE(plantation)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fm_allo_a         !!
!$OMP THREADPRIVATE(fm_allo_a)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fm_allo_c         !! 
!$OMP THREADPRIVATE(fm_allo_c)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fm_allo_d         !!
!$OMP THREADPRIVATE(fm_allo_d)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fm_allo_p         !!
!$OMP THREADPRIVATE(fm_allo_p)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fm_allo_q         !!
!$OMP THREADPRIVATE(fm_allo_q)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: allo_crown_a0     !!
!$OMP THREADPRIVATE(fm_allo_a0)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: allo_crown_a1     !!
!$OMP THREADPRIVATE(fm_allo_a1)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: allo_crown_a2     !!
!$OMP THREADPRIVATE(fm_allo_a2)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: h_first           !!
!$OMP THREADPRIVATE(h_first)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: nmaxtrees      !! Intial number of seedlings per hectare. Used 
                                                                    !! in prescribe to initialize the model and after 
                                                                    !! every clearcut
!$OMP THREADPRIVATE(nmaxtrees)

! The following two variables are used to define the range of sapling heights for a newly cleared plot
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: height_init_min   !! The minimum height of a tree sapling when a forest 
                                                                    !! stand is established. Owing to the allometric 
                                                                    !! relationship this setting determines all
                                                                    !! biomass components of a newly establised stand
                                                                    !! @tex $(m)$ @endtex
!$OMP THREADPRIVATE(height_init_min)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: height_init_max   !! The maximum height of a tree sapling when a forest 
                                                                    !! stand is established. 
                                                                    !! @tex $(m)$ @endtex
!$OMP THREADPRIVATE(height_init_max)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alpha_self_thinning !! Coefficient of the self-thinning relationship D=alpha*N^beta 
                                                                    !! estimated from German, French, Spanish and Swedish 
                                                                    !! forest inventories
!$OMP THREADPRIVATE(alpha_self_thinning)
 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: beta_self_thinning!! Exponent of the self-thinning relationship D=alpha*N^beta 
                                                                    !! estimated from German, French, Spanish and swedish
                                                                    !! forest inventories
!$OMP THREADPRIVATE(beta_self_thinning)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: fuelwood_diameter !! Diameter below which the wood harvest is used as fuelwood (m)
                                                                    !! Affects the way the wood is used in the dim_product_use
                                                                    !! subroutine         
!$OMP THREADPRIVATE(fuelwood_diameter)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: coppice_kill_be_wood !! Diameter below which the wood harvest is used as fuelwood (m)
!$OMP THREADPRIVATE(coppice_kill_be_wood)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: thinstrat         !! The thinning strategy used for forest management.
                                                                    !! Comes from Eq. 12 of Bellassen et al (2010)
                                                                    !! @tex $(unitless)$ @endtex
!$OMP THREADPRIVATE(thinstrat) 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: taumin            !! Minimum tree death probability. stomate_forest.f90
                                                                    !! Comes from Eq. 12 of Bellassen et al (2010)
                                                                    !! @tex $(unitless)$ @endtex
!$OMP THREADPRIVATE(taumin) 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: taumax            !! Maximum tree death probability. stomate_forest.f90
                                                                    !! Comes from Eq. 12 of Bellassen et al (2010)
                                                                    !! @tex $(unitless)$ @endtex
!$OMP THREADPRIVATE(taumax) 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alpha_rdi_upper   !! Coefficient of the yield-table derived thinning relationship
                                                                    !! D=alpha*N^beta estimated from JRC yield table database
!$OMP THREADPRIVATE(alpha_rdi_upper)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: beta_rdi_upper    !! Coefficient of the yield-table derived thinning relationship
                                                                    !! D=alpha*N^beta estimated from JRC yield table database
!$OMP THREADPRIVATE(beta_rdi_upper)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: alpha_rdi_lower   !! Coefficient of the yield-table derived thinning relationship
                                                                    !! D=alpha*N^beta estimated from JRC yield table database
!$OMP THREADPRIVATE(alpha_rdi_lower) 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: beta_rdi_lower    !! Coefficient of the yield-table derived thinning relationship
                                                                    !! D=alpha*N^beta estimated from JRC yield table database
!$OMP THREADPRIVATE(beta_rdi_lower)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: dens_target       !! The minimum density of trees in a stand before
                                                                    !! they all die off and we replant.  This is to prevent
                                                                    !! the stand from becoming just one large tree.
                                                                    !! @tex $(trees ha{-1})$ @endtex
!$OMP THREADPRIVATE(dens_target) 
   REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: largest_tree_dia !! The diameter at which we decide to clearcut
                                                                    !! a stand because our equipment cannot handle
                                                                    !! trees larger than this.
                                                                    !! @tex $(cm)$ @endtex
!$OMP THREADPRIVATE(largest_tree_dia)
                                 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: branch_ratio      !! branches/total aboveground biomass ratio
                                                                    !! (cf carbofor for CITEPA inventory, these 
                                                                    !! Guerric, Lim 2004, Peischl 2007, 
                                                                    !! Schulp 2008: 15-30% slash after harvest,
                                                                    !! Zaehle 2007: 30% slash after harvest)
!$OMP THREADPRIVATE(branch_ratio)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: branch_harvest    !! The fraction of branches which are harvested
                                                                    !! during thinning and clearcut operations on 
                                                                    !! forests.  1.0 means all branches are taken offsite,
                                                                    !! 0.0 means all branches are left onsite and go
                                                                    !! into the litter pool.  This number is not
                                                                    !! based on any data.
!$OMP THREADPRIVATE(branch_harvest)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:) :: decl_factor       !! Age_decline factor in fraction of vmax decline per year
                                                                    !! (yield tables > 130 years : inc90=0.8inc50, 
                                                                    !! inc130=0.55inc50, 
                                                                    !! same for broadleaves and coniferous. 
                                                                    !! For temperate pfts, calibration on one site to get a 0.55 
                                                                    !! increment decrease. 
                                                                    !! For boreal pfts, calibration to get an average 0.55 
                                                                    !! increment decrease over 25,7 and 2 sites: Adam Wolf dataset)
!$OMP THREADPRIVATE(decl_factor)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)    :: opt_factor     !! Optimisation factor for vcmax and vjmax
!$OMP THREADPRIVATE(opt_factor)                    

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)    :: coppice_diameter !! The trunk diameter at which a coppice will be cut.
                                                                    !! @tex $(m)$ @endtex
!$OMP THREADPRIVATE(coppice_diameter)  
  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: shoots_per_stool !! The number of shoots that regrow per stool after
                                                                    !! the first coppice cut
                                                                    !! @tex $-$ @endtex
!$OMP THREADPRIVATE(shoots_per_stool) 
  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: src_rot_length !! The number of years between cuttings for short
                                                                    !! rotation coppices.
                                                                    !! @tex $-$ @endtex
!$OMP THREADPRIVATE(src_rot_length) 
  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: src_nrots      !! The number of rotations for short rotations coppices
                                                                    !! before the roots are killed and replanted.
                                                                    !! @tex $-$ @endtex
!$OMP THREADPRIVATE(src_nrots) 

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)    :: deleuze_a      !! intercept of the intra-tree competition within a stand
                                                                    !! based on the competion rule of Deleuze and Dhote 2004
                                                                    !! Used when n_circ > 6
!$OMP THREADPRIVATE(deleuze_a)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)    :: deleuze_b      !! slope of the intra-tree competition within a stand
                                                                    !! based on the competion rule of Deleuze and Dhote 2004
                                                                    !! Used when n_circ > 6
!$OMP THREADPRIVATE(deleuze_b)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)    :: deleuze_p_all  !! Percentile of the circumferences that receives photosynthates
                                                                    !! based on the competion rule of Deleuze and Dhote 2004
                                                                    !! Used when n_circ > 6 for FM1, FM2 and FM4 
!$OMP THREADPRIVATE(deleuze_p_all)

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)    :: deleuze_p_coppice  !! Percentile of the circumferences that receives photosynthates
                                                                    !! based on the competion rule of Deleuze and Dhote 2004
                                                                    !! Used when n_circ > 6 for FM3
!$OMP THREADPRIVATE(deleuze_p_coppice)


! SAPIENS - CROP MANAGEMENT

  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION(:)    :: harvest_ratio  !! Share of biomass that is removed from the site during harvest
                                                                    !! A high value indicates a high harvest efficiency and thus a 
                                                                    !! input of residuals. (unitless, 0-1).

!$OMP THREADPRIVATE(harvest_ratio)


! STOMATE - Age classes

  INTEGER(i_std), SAVE                            :: nvmap          !! The number of PFTs we have if we ignore age classes.
                                                                    !! @tex $-$ @endtex
!$OMP THREADPRIVATE(nvmap) 
  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: agec_group     !! The age class group that this PFT belongs to.
                                                                    !! If you're not using age classes, this will just be
                                                                    !! set to the number of the PFT and should be ignored
                                                                    !! in the code.
                                                                    !! @tex $-$ @endtex
!$OMP THREADPRIVATE(agec_groups) 
! I do not like the location of these next two variables.  They are computed
! after agec_group is read in.  Ideally, they would be passed around
! as arguments or in a structure, since they are not really
! parameters read in from the input file.
  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: start_index    !! Gives the index that this real PFT starts
                                                                    !! on, ignoring age classes
                                                                    !! @tex $-$ @endtex
!$OMP THREADPRIVATE(start_index) 
  INTEGER(i_std), ALLOCATABLE, SAVE, DIMENSION(:) :: nagec_pft      !! The number of age classes for each PFT.
                                                                    !! Only 1 or nagec are supported right now.
                                                                    !! @tex $-$ @endtex
!$OMP THREADPRIVATE(nagec_pft) 


END MODULE pft_parameters_var
