! ================================================================================================================================
! MODULE       : sapiens_agriculture
!
! CONTACT      : orchidee-help _at_ ipsl.jussieu.fr
!
! LICENCE      : IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF       Simple approach to harvesting croplands
!!
!!\n DESCRIPTION: None
!!
!! RECENT CHANGE(S): None
!!
!! REFERENCE(S) : None
!!
!! SVN          :
!! $HeadURL: svn://forge.ipsl.jussieu.fr/orchidee/branches/ORCHIDEE-DOFOCO/ORCHIDEE/src_stomate/stomate_lpj.f90 $
!! $Date: 2013-08-28 16:34:04 +0200 (Wed, 28 Aug 2013) $
!! $Revision: 1438 $
!! \n
!_ ================================================================================================================================

MODULE sapiens_agriculture

  ! modules used:
  USE stomate_data
  USE constantes
  USE pft_parameters

  IMPLICIT NONE

  ! private & public routines

  PRIVATE
  PUBLIC crop_planting, crop_harvest

  ! Variable declaration 

  LOGICAL, SAVE             :: firstcall = .TRUE.                !! first call flag
  !$OMP THREADPRIVATE(firstcall)

CONTAINS


  !! ================================================================================================================================
  !! SUBROUTINE   : crop_planting
  !!
  !>\BRIEF        Plant croplands
  !!
  !! DESCRIPTION  : Plant the crops when the weather is suitable. Uses begin_leaves to decide
  !! when to plant a crop. To be used within the DOFOCO branch.
  !!
  !! RECENT CHANGE(S) : 
  !!
  !! MAIN OUTPUT VARIABLE(S): 
  !!
  !! REFERENCE(S) :
  !!
  !! FLOWCHART    : None
  !! \n
  !_ =============================================================================================================================

  SUBROUTINE crop_planting(npts, dt, ipts, ivm, &
       veget_max, PFTpresent, c0_alloc, when_growthinit, &
       time_hum_min, everywhere, senescence, ind, &
       circ_class_n, KF, leaf_frac, age, &
       npp_longterm, lm_lastyearmax, biomass, circ_class_biomass, &
       co2_to_bm, k_latosa_adapt)


  !! 0. Variable and parameter declaration
  
  !! 0.1 Input variables
  
    INTEGER(i_std), INTENT(in)                         :: npts                 !! Domain size - number of grid cells (unitless)
    INTEGER(i_std), INTENT(in)                         :: ipts                 !! specific pixel to plant (unitless)
    INTEGER(i_std), INTENT(in)                         :: ivm                  !! specific pft to plant in the specific pixel
                                                                               !! (unitless)
    REAL(r_std), INTENT(in)                            :: dt                   !! time step (dt_days)  
    REAL(r_std), DIMENSION(:,:), INTENT(in)            :: veget_max            !! "maximal" coverage fraction of a 
                                                                               !! PFT (LAI -> infinity) on ground 
                                                                               !! (0-1, unitless)
    REAL(r_std), DIMENSION(:,:), INTENT(in)            :: c0_alloc             !! Root to sapwood tradeoff parameter


  !! 0.2 Ouput variables


  !! 0.3 Modified variables
    
    LOGICAL, DIMENSION(:,:), INTENT(inout)             :: PFTpresent           !! PFT exists (true/false)
    LOGICAL, DIMENSION(:,:), INTENT(inout)             :: senescence           !! is the plant senescent? (only 
                                                                               !! for deciduous trees - 
                                                                               !! carbohydrate reserve) (true/false)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: when_growthinit      !! how many days since the 
                                                                               !! beginning of the growing season (days) 
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: time_hum_min         !! time elapsed since strongest 
                                                                               !! moisture availability (days)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: everywhere           !! is the PFT everywhere in the grid box or 
                                                                               !! very localized (after its introduction) (?)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: ind                  !! Stand level number of individuals
                                                                               !! @tex $(ind m^{-2})$ @endtex 
    REAL(r_std), DIMENSION(:,:,:), INTENT(inout)       :: circ_class_n         !! Number of individuals in each circ class
                                                                               !! @tex $(ind m^{-2})$ @endtex
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: KF                   !! Scaling factor to convert sapwood mass
                                                                               !! into leaf mass (m)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: k_latosa_adapt       !! Leaf to sapwood area adapted for long 
                                                                               !! term water stress (m)
    REAL(r_std), DIMENSION(:,:,:), INTENT(inout)       :: leaf_frac            !! fraction of leaves in leaf age 
                                                                               !! class (0-1, unitless)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: age                  !! mean age (years)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: npp_longterm         !! "long term" net primary productivity
                                                                               !! @tex ($gC m^{-2} year^{-1}$) @endtex
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: lm_lastyearmax       !! last year's maximum leaf mass for each PFT 
                                                                               !! @tex ($gC m^{-2}$) @endtex
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: co2_to_bm            !! co2 taken up by carbohydrate 
                                                                               !! reserve at the beginning of the 
                                                                               !! growing season @tex ($gC m^{-2} 
                                                                               !! of total ground/day$) @endtex
    REAL(r_std), DIMENSION(:,:,:,:), INTENT(inout)     :: biomass              !! biomass @tex ($gC m^{-2} of 
                                                                               !! ground$) @endtex
    REAL(r_std), DIMENSION(:,:,:,:,:), INTENT(inout)   :: circ_class_biomass   !! Biomass components of the model tree  
                                                                               !! within a circumference class
                                                                               !! class @tex $(g C ind^{-1})$ @endtex
    
  !! 0.4 Local variables
    
    REAL(r_std), DIMENSION(npts,nvm)                   :: LF                   !! Scaling factor to convert sapwood mass
                                                                               !! into root mass (unitless)
    REAL(r_std), DIMENSION(npts,nvm)                   :: k_latosa             !! Height dependent base value to calculate 
                                                                               !! KF (-) 
    REAL(r_std), DIMENSION(npts,nvm)                   :: histvar              !! controls the history output 
                                                                               !! level - 0: nothing is written; 
                                                                               !! 10: everything is written 
                                                                               !! (0-10, unitless)
    REAL(r_std), DIMENSION(npts,nvm)                   :: lstress_fac          !! Light stress factor, based on total
                                                                               !! transmitted light (unitless, 0-1)
    REAL(r_std)                                        :: Cs_grass             !! Individual plant, sapwood compartment
                                                                               !! @tex $(gC. ind^{-1})$ @endtex
    REAL(r_std)                                        :: Cl_init              !! Initial leaf carbon required to start
                                                                               !! the growing season
                                                                               !! @tex $(gC tree^{-1})$ @endtex
    REAL(r_std)                                        :: Cr_init              !! Initial root carbon required to start
                                                                               !! the growing season
                                                                               !! @tex $(gC tree^{-1})$ @endtex
!_ ================================================================================================================================

    IF (bavard.GE.2) WRITE(numout,*) 'Entering sapiens_crop_planting'

    IF ( veget_max(ipts,ivm) .GT. min_stomate .AND. ind(ipts,ivm) .LT. min_stomate) THEN

       !! 1. Prescribe the crops
 
       ! Prescribe the crops - should move to an agricultural routine
       ! Lightstress varies from 0 to 1 and is calculated from the canopy structure (veget)
       ! Given that there is no vegetation at this point, the lightstress cannot be 
       ! calculated and is set to 1. However as soon as we grow a canopy it will 
       ! experience light stress and so KF should be adjusted. If this is not done, we 
       ! can't prescribe tall vegetation which is a useful feature to speed up 
       ! optimisation and testing. We will have iterate over light stress and KF to 
       ! prescribe vegetation that is in balance with its light environment. 
       lstress_fac(ipts,ivm) = un

       ! For crops we assume that an individual crop is 1 m2 of crop. This is set
       ! in nmaxtrees in pft_parameters.f90. It could be set to another value but 
       ! with the current code this should not have any meaning. The cropland
       ! does not necessarily covers the whole 1 m2 so adjust for the canopy cover
       ind(ipts,ivm) = nmaxtrees(ivm) * ha_to_m2 * canopy_cover(ivm)
       
       ! Now we generate the size of a single crop sapling. We do not deal with 
       ! circumference classes for crops, but we want to keep the arrays the 
       ! same as for the trees so we put the sapling information into the first 
       ! circumference class

       ! Calculate the sapwood to leaf mass in a similar way as has been done for trees.
       ! For trees this approach had been justified by observations. For crops such
       ! justification is not supported by observations but we didn't try to find it.
       ! Needs more work by someone interested in crops. There might be a more elegant
       ! solution making use of a well observed parameter. 
       k_latosa(ipts,ivm) = (k_latosa_adapt(ipts,ivm) + (lstress_fac(ipts,ivm) * &
            (k_latosa_max(ivm)-k_latosa_min(ivm))))

       ! The mass of the structural carbon relates to the mass of the leaves through
       ! a prescribed parameter ::k_latosa
       KF(ipts,ivm) = k_latosa(ipts,ivm)

       ! Calculate leaf to root area 
       LF(ipts,ivm) = c0_alloc(ipts,ivm) * KF(ipts,ivm)

       !---TEMP---
       IF(ld_presc .AND. test_pft == ivm)THEN
          WRITE(numout,*) 'KF, ', k_latosa(ipts,ivm), KF(ipts,ivm)
          WRITE(numout,*) 'LF, c0_alloc, ', c0_alloc(ipts,ivm) * KF(ipts,ivm), &
               c0_alloc(ipts,ivm)
       ENDIF
       !----------

       ! initialize everything to make sure there are not random values floating around
       ! for ncirc = 1
       circ_class_biomass(ipts,ivm,:,:,icarbon) = zero
       circ_class_biomass(ipts,ivm,1,:,icarbon) = val_exp
       
       ! Similar as for trees, the initial height of the vegetation can be calculated 
       ! from prescribed parameters
       circ_class_biomass(ipts,ivm,1,ileaf,icarbon) = height_init_min(ivm) / &
            lai_to_height(ivm) / sla(ivm)
       
       ! Use allometric relationships to define the root mass based on leaf mass. Some 
       ! sapwood mass is needed to store the reserves.
       circ_class_biomass(ipts,ivm,1,iroot,icarbon) = &
            circ_class_biomass(ipts,ivm,1,ileaf,icarbon) / LF(ipts,ivm)
       circ_class_biomass(ipts,ivm,1,isapabove,icarbon) = &
            circ_class_biomass(ipts,ivm,1,ileaf,icarbon) / KF(ipts,ivm)
       
       ! Some of the biomass components that exist for trees are undefined for grasses
       circ_class_biomass(ipts,ivm,1,isapbelow,icarbon) = zero
       circ_class_biomass(ipts,ivm,1,iheartabove,icarbon) = zero
       circ_class_biomass(ipts,ivm,1,iheartbelow,icarbon) = zero
       circ_class_biomass(ipts,ivm,1,ifruit,icarbon) = zero
       circ_class_biomass(ipts,ivm,1,icarbres,icarbon) = zero
       
       ! Pools that are defined in the same way for trees and grasses      
       circ_class_biomass(ipts,ivm,1,ilabile,icarbon) = labile_to_total * &
            ( circ_class_biomass(ipts,ivm,1,ileaf,icarbon) + &
            fcn_root(ivm) *  circ_class_biomass(ipts,ivm,1,iroot,icarbon) + &
            fcn_wood(ivm) * ( circ_class_biomass(ipts,ivm,1,isapabove,icarbon) +  &
            circ_class_biomass(ipts,ivm,1,isapbelow,icarbon) + &
            circ_class_biomass(ipts,ivm,1,icarbres,icarbon)))
       
       ! Write initial values
       IF (ld_presc) THEN
          WRITE(numout,*) 'Crop prescribed biomass: ', &
               circ_class_biomass(ipts,ivm,1,:,icarbon)
       ENDIF

       ! Initial biomass (g C m-2)
       biomass(ipts,ivm,:,icarbon) = circ_class_biomass(ipts,ivm,1,:,icarbon) * &
            ind(ipts,ivm)
       
       ! Synchronize biomass and circ_class_biomass (gC tree-1). This 
       ! allows to more easily check the mass balance closure
       circ_class_n(ipts,ivm,1) = ind(ipts,ivm)
       
       ! Set leaf age classes -> all leaves will be current year leaves
       leaf_frac(ipts,ivm,:) = zero
       leaf_frac(ipts,ivm,1) = un
       
       ! Set time since last beginning of growing season but only
       ! for the first day of the whole simulation. When the model
       ! is initialized when_growthinit is set to undef. In subsequent
       ! time steps it should have a value.
       IF (when_growthinit(ipts,ivm) .EQ. undef) THEN
          when_growthinit(ipts,ivm) = 200
          time_hum_min(ipts,ivm) = 200
       ENDIF
       
       ! The biomass to build the saplings is taken from the atmosphere, keep track of
       ! amount to calculate the C-balance closure
       co2_to_bm(ipts,ivm) = co2_to_bm(ipts,ivm) + &
            ( SUM(biomass(ipts,ivm,:,icarbon))  / dt )

       !! 2.3 Declare PFT present 
       !! Now that the PFT has biomass it should be declared 'present'
       !! everywhere in that grid box. Assign some additional properties
       PFTpresent(ipts,ivm) = .TRUE.
       everywhere(ipts,ivm) = un
       age(ipts,ivm) = zero
       npp_longterm(ipts,ivm) = npp_longterm_init
       lm_lastyearmax(ipts,ivm) = zero

       !! 4.3 reset when_growthinit counter: start of the growing season
       when_growthinit(ipts,ivm) = zero
       senescence(ipts,ivm) = .FALSE.

    ! PFT is not present, initialize the variables
    ELSE

       ! At the tree level
       circ_class_n(ipts,ivm,:) = zero
       circ_class_biomass(ipts,ivm,:,:,icarbon) = zero
       
       ! At the stand level
       biomass(ipts,ivm,:,icarbon) = zero
       ind(ipts,ivm) = zero
       
    ENDIF ! veget_max gt min_stomate

    IF (bavard.GE.2) WRITE(numout,*) 'Leaving sapiens_crop_planting'

  END SUBROUTINE crop_planting


  !! ================================================================================================================================
  !! SUBROUTINE   : crop_harvest
  !!
  !>\BRIEF        Harvest of croplands
  !!
  !! DESCRIPTION  : To take into account biomass harvest from crop (mainly to take 
  !! into account for the reduced litter input and then decreased soil carbon. it is a 
  !! constant (40\%) fraction of turnover. To be used within the DOFOCO branch.
  !!
  !! RECENT CHANGE(S) : Harvest is stored in harvest_pool for further modelling of product use 
  !!
  !! MAIN OUTPUT VARIABLE(S): ::harvest_pool
  !!
  !! REFERENCE(S) :
  !! - Piao, S., P. Ciais, P. Friedlingstein, N. de Noblet-Ducoudre, P. Cadule, N. Viovy, and T. Wang. 2009. 
  !!   Spatiotemporal patterns of terrestrial carbon cycle during the 20th century. Global Biogeochemical 
  !!   Cycles 23:doi:10.1029/2008GB003339.
  !!
  !! FLOWCHART    : None
  !! \n
  !_ ================================================================================================================================

  SUBROUTINE crop_harvest(npts, ipts, ivm, dt_days, &
       veget_max, turnover, harvest_pool, harvest_type, &
       harvest_cut, harvest_area, resolution, biomass, &
       ind, leaf_meanage) 


    !! 0. Variable and parameter declaration

    !! 0.1 Input variables

    INTEGER, INTENT(in)                                :: npts            !! Domain size (unitless)
    INTEGER(i_std), INTENT(in)                         :: ipts            !! specific pixel to plant (unitless)
    INTEGER(i_std), INTENT(in)                         :: ivm             !! specific pft to plant in the specific pixel
                                                                          !! (unitless)
    REAL(r_std), INTENT(in)                            :: dt_days         !! Time step (days)
    REAL(r_std),DIMENSION(npts,2), INTENT(in)          :: resolution      !! The length in m of each grid-box in X and Y
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)       :: veget_max       !! Fraction of the pixel covered by a PFT 
                                                                          !! @tex $(m^2 m^{-2})$ @endtex

    !! 0.2 Output variables


    !! 0.3 Modified variables

    REAL(r_std), DIMENSION(:,:,:,:), INTENT(inout)    :: biomass          !! biomass @tex ($gC m^{-2}$) @endtex
    REAL(r_std), DIMENSION(:,:,:,:),INTENT(inout)     :: turnover         !! Turnover rates 
                                                                          !! @tex $(gC m^{-2} dtslow^{-1})$ @endtex
    REAL(r_std), DIMENSION(:,:,:,:), INTENT(inout)    :: harvest_pool     !! The wood and biomass that have been
                                                                          !! havested by humans @tex $(gC)$ @endtex
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: harvest_type     !! Type of management that resulted
                                                                          !! in the harvest (unitless)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: harvest_cut      !! Type of cutting that was used for the harvest
                                                                          !! (unitless)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: harvest_area     !! Harvested area (m^{2})
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: ind              !! Density of individuals 
                                                                          !! @tex $(m^{-2})$ @endtex
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: leaf_meanage     !! mean age of the leaves (days)


    !! 0.4 Local variables
               
    REAL(r_std)                                       :: pixel_area       !! surface area of the pixel @tex ($m^{2}$) @endtex

 !_ ================================================================================================================================

    IF (bavard.GE.2) WRITE(numout,*) 'Entering sapiens_crop_harvest'

    !! 1. Initialize
    !  Reset harvest pool
    IF(ld_trnov .AND. ipts == test_grid .AND. ivm == test_pft)THEN
       WRITE(numout,*) "Entering the crop_harvest routine: ",harvest_pool(ipts,ivm,:,icarbon)
    ENDIF
    !!! We should not reset!  Sometimes there is harvest in the harvest pool, and our
    ! mass balance will not be closed if we eliminate it here.  It seems possible that we hit
    ! senesence twice in a single year.  This happened on a grid point near the equator in the
    ! Pacific ocean.
    !harvest_pool(ipts,ivm,:,icarbon) = zero

    !  Surface area (m2) of the pixel
    pixel_area = resolution(ipts,1) * resolution(ipts,2)
   

    !! 2. Harvest croplands

    ! NOTE that this is a quick fix rather than a final solution. The turnover
    ! of crop biomass has for long be calculated and was assumed to entirely 
    ! return to the litter pools. This approach ignored crop harvest. Rather 
    ! than harvesting the aboveground biomass (or below ground for some
    ! crops i.e. potatoes, beet, etc which is currently not accounted for) this
    ! routine makes use of the turnover and diverts part of the turnover into 
    ! the harvest pool. By doing so it does not end up in the litter.

    ! Assume all aboveground biomass is harvested and put it all in the first 
    ! diameter class.
    harvest_pool(ipts,ivm,1,icarbon) =  harvest_pool(ipts,ivm,1,icarbon) + &
         harvest_ratio(ivm) * ( biomass(ipts,ivm,ileaf,icarbon) + &
         biomass(ipts,ivm,icarbres,icarbon) + biomass(ipts,ivm,ilabile,icarbon) + &
         biomass(ipts,ivm,ifruit,icarbon) + biomass(ipts,ivm,isapabove,icarbon) ) * &
         veget_max(ipts,ivm) * pixel_area

    ! Associated harvest variables
    harvest_type(ipts,ivm) = ifm_crop
    harvest_cut(ipts,ivm) = icut_crop
    harvest_area(ipts,ivm) = veget_max(ipts,ivm) * pixel_area

    ! The belowground becomes litter. All roots remain on site. Half (::harvest_ratio) 
    ! of the other biomas pools was harvested.
    turnover(ipts,ivm,iroot,icarbon) = turnover(ipts,ivm,iroot,icarbon) + &
         biomass(ipts,ivm,iroot,icarbon) 
    turnover(ipts,ivm,ileaf,icarbon) = turnover(ipts,ivm,ileaf,icarbon) + &
         (un - harvest_ratio(ivm)) * biomass(ipts,ivm,ileaf,icarbon)
    turnover(ipts,ivm,icarbres,icarbon) = turnover(ipts,ivm,icarbres,icarbon) + &
         (un - harvest_ratio(ivm)) * biomass(ipts,ivm,icarbres,icarbon)
    turnover(ipts,ivm,ilabile,icarbon) = turnover(ipts,ivm,ilabile,icarbon) + &
         (un - harvest_ratio(ivm)) * biomass(ipts,ivm,ilabile,icarbon)
    turnover(ipts,ivm,ifruit,icarbon) = turnover(ipts,ivm,ifruit,icarbon) + &
         (un - harvest_ratio(ivm)) * biomass(ipts,ivm,ifruit,icarbon)
    turnover(ipts,ivm,isapabove,icarbon) = turnover(ipts,ivm,isapabove,icarbon) + &
         (un - harvest_ratio(ivm)) * biomass(ipts,ivm,isapabove,icarbon) 

    ! Account for the pools that should not contain biomass for the moment
    ! Do so to make sure the mass balance will be closed 
    turnover(ipts,ivm,isapbelow,icarbon) = turnover(ipts,ivm,isapbelow,icarbon) +  &
         biomass(ipts,ivm,isapbelow,icarbon)
    turnover(ipts,ivm,iheartabove,icarbon) = turnover(ipts,ivm,iheartabove,icarbon) +  &
         biomass(ipts,ivm,iheartabove,icarbon)
    turnover(ipts,ivm,iheartbelow,icarbon) = turnover(ipts,ivm,iheartbelow,icarbon) +  &
         biomass(ipts,ivm,iheartbelow,icarbon)

    ! Reset the biomass pools
    biomass(ipts,ivm,isapabove,icarbon) = zero
    biomass(ipts,ivm,ileaf,icarbon) = zero
    biomass(ipts,ivm,iroot,icarbon) = zero
    biomass(ipts,ivm,ifruit,icarbon) = zero
    biomass(ipts,ivm,icarbres,icarbon) = zero
    biomass(ipts,ivm,ilabile,icarbon) = zero
                
    ! These pools should always be empty for crops - just to be sure
    biomass(ipts,ivm,iheartbelow,icarbon) = zero
    biomass(ipts,ivm,iheartabove,icarbon) = zero
    biomass(ipts,ivm,isapbelow,icarbon) = zero

    ! No individuals left
    ind(ipts,ivm) = zero

    ! reset leaf age
    leaf_meanage(ipts,ivm) = zero

    IF (bavard.GE.2) WRITE(numout,*) 'Leaving sapiens_crop_harvest'

  END SUBROUTINE crop_harvest

END MODULE sapiens_agriculture
