!==================================================================================================================================
!  MODULE 	: sechiba_hydrol_arch
! 
!  CONTACT      : orchidee-help _at_ ipsl.jussieu.fr
!
!  LICENCE      : IPSL (2006)
!  This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF This module calculates the amount of water that is available for the leaves for transpiration,
!        accounting for effects of hydraulic architecture following (Hickler et al. 2006)      
!!
!!\n DESCRIPTION  : (1) Calculate soil water potential from soil water content as calculated in hydrol.f90
!!                  according to van Genuchten (1980). Soil water potential is weighted by the relative share of the
!!                  of theroots in each layer.
!!                  (2) Calculate pressure difference between leaves and soil (Whitehead 1998)
!!                  (3) Calculate root (Weatherly 1998), sapwood (Magnani et al. 2000, Tyree et al. 1994,
!!                  Sperry et al. 1998) and leave resistances (Sitch et al. 2003.
!!                  (4) Calculate the supply of water for transpiration by the leaves using Darcy's law (Whitehead 1998)
!! 
!! RECENT CHANGE(S): None 
!! 
!! REFERENCE(S) : None
!!   
!! SVN     :
!! $HeadURL: svn://forge.ipsl.jussieu.fr/orchidee/branches/ORCHIDEE-DOFOCO/ORCHIDEE/src_sechiba/sechiba.f90 $ 
!! $Date: 2013-05-06 14:14:36 +0200 (Mon, 06 May 2013) $
!! $Revision: 1295 $
!! \n
!_ ================================================================================================================================
 
MODULE sechiba_hydrol_arch
 
  USE ioipsl
  
  ! modules used :
  USE ioipsl   
  USE xios_orchidee
  USE ioipsl_para 
  USE constantes
  USE constantes_soil
  USE pft_parameters
 ! USE function_library, ONLY: wood_to_height_eff, biomass_to_lai, biomass_to_coupled_lai, stem_volume_f
  USE function_library ! load all for now
  USE qsat_moisture

  IMPLICIT NONE

  ! Private and public routines

  PRIVATE
  PUBLIC hydrol_arch, jdiffuco_trans_co2


  LOGICAL, SAVE                              :: l_first_sechiba = .TRUE.      !! Flag controlling the intialisation (true/false)
!$OMP THREADPRIVATE(l_first_sechiba)

  INTEGER(i_std)                             :: jst          ! tzj

  LOGICAL, SAVE                              :: l_first_inih = .TRUE.      !! Flag controlling the intialisation of hydrolarch  (true/false)
!$OMP THREADPRIVATE(l_first_inih)

  LOGICAL, SAVE                              :: rsoilroot = .TRUE.         !! tzjh Flag to activate/deactivate dynamic roots scheme (true/false) 
!$OMP THREADPRIVATE(rsoilroot)
  LOGICAL, SAVE                               :: ok_joetzjer_hydro=.TRUE. 
CONTAINS

!! ================================================================================================================================
!! SUBROUTINE 	: hydrol_arch
!!
!>\BRIEF        Calculate the amount of water that is available for the leaves for transpiration,
!               accounting for effects of hydraulic architecture following (Hickler et al. 2006)    
!!
!!\n DESCRIPTION : (1) Calculate soil water potential from soil water content as calculated in hydrol.f90 
!!   according to van Genuchten (1980). Soil water potential is weighted by the relative share of the
!!   roots in each layer.
!!   (2) Calculate pressure difference between leaves and soil (Whitehead 1998)
!!   (3) Calculate root (Weatherly 1998), sapwood (Magnani et al. 2000, Tyree et al. 1994, Sperry et al. 1998)
!!   and leave resistances (Sitch et al. 2003).
!!   (4) Calculate the supply of water for transpiration by the leaves using Darcy's law (Whitehead 1998)
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLE(S): :: transpir_supply   
!!
!! REFERENCE(S)	: +++COMPLETE+++
!!                Hickler et al. 2006
!!                van Genuchten (1980)
!!                Whitehead 1998
!!                Weatherly 1998
!!                Magnani et al. 2000
!!                Tyree et al. 1994
!!                Sperry et al. 1998
!!                Sitch et al. 2003
!!
!! FLOWCHART    : 
!!
!! tzj modif
!! -   correction du calcul de R_sap following Magnani et al. 2000
!! -   ecriture des variables phi_soil et phi_soilroot dans les outputs de sechiba
!! -   implementation de rsoilroot avec flag (idem dans hydrol.f90)
!! -   new hydraulic architecture is implemented but NOT activate (commented for now)
!_ ================================================================================================================================
! tzj add arguments, tzjhrestart ldrestart
  SUBROUTINE hydrol_arch (kjpindex,rest_id, ldrestart_read, ldrestart_write, circ_class_biomass, circ_class_n, temp_sol_new, &
       temp_air, swc, transpir_supply, dtradia, njsc, biomass, ind, soiltile, &
       vir_transpir_supply, veget, kjit, indexveg, hist_id, indexlayer,qsurf, pb, vl, vx, vr, &
       psi_leaf, psi_stem, psi_root,swdown, ksave,stem_plc,transpir_tot,VPD_tzj,gsh,tzj_supply) 


    !! 0. Variable declaration

    !! 0.1 Input variables
    INTEGER(i_std),INTENT (in)                               :: rest_id
    INTEGER(i_std), INTENT(in)                      :: kjit                !! tzj : Time step number (unitless)
    INTEGER(i_std), INTENT(in)                      :: kjpindex            !! Domain size - terrestrial pixels only (unitless)
    INTEGER(i_std),DIMENSION(kjpindex*nvm), INTENT(in)   :: indexveg       !! tzj : Indeces of the points on the 3D map
    INTEGER(i_std),INTENT(in)                       :: hist_id             !! tzj : Access to history file(unitless)
    INTEGER(i_std),DIMENSION (kjpindex*nslm), INTENT (in):: indexlayer     !! tzj : Indeces of the points on the 3D map for soil layers
    CHARACTER(LEN=80) , SAVE                        :: var_name            !! tzj : To store variables names for I/O

!tzjhrestart
   LOGICAL, INTENT(in)                              :: ldrestart_read   !!  Logical for _restart_ file to read
   LOGICAL, INTENT(in)                              :: ldrestart_write  !! Logical for _restart_ file to write

    REAL(r_std), INTENT (in)                        :: dtradia             !! Time step (s) 
    INTEGER(i_std), DIMENSION(:), INTENT (in)       :: njsc                !! Index of the dominant soil textural class 
                                                                           !! in the grid cell used for hydrology 
                                                                           !! (1-nscm, unitless)
    REAL(r_std),DIMENSION (:), INTENT (in)          :: temp_sol_new        !! New ground temperature (K)
    REAL(r_std),DIMENSION (:), INTENT (in)          :: temp_air            !! Air temperature (K)   
    REAL(r_std),DIMENSION (:,:), INTENT (in)        :: ind                 !! Number of individuals at the stand level
                                                                           !! @tex $(m^{-2})$ @endtex
    REAL(r_std),DIMENSION (:,:), INTENT (in)        :: soiltile            !! Fraction of each soiltile (-)
    REAL(r_std),DIMENSION (:,:,:), INTENT (in)      :: swc                 !! Volumetric soil water content
    REAL(r_std),DIMENSION (:,:,:), INTENT (in)      :: ksave               !! Hydraulic conductivity mm/d (copy from hydrol.f90)
    REAL(r_std),DIMENSION (:,:,:), INTENT (in)      :: circ_class_n        !! number of trees within a circumference class (tree m-2)
    REAL(r_std), DIMENSION(:,:,:,:,:),  INTENT(in)  :: circ_class_biomass  !! Biomass components of the model tree  
                                                                           !! within a circumference class
                                                                           !! class @tex $(g C ind^{-1})$ @endtex  
    REAL(r_std), DIMENSION(:,:,:,:), INTENT(in)     :: biomass             !! PFT total biomass 
                                                                           !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std),DIMENSION (:,:), INTENT (in)        :: veget               !! Fraction of the vegetation that covers the soil
                                                                           !! also project canopy cover - calculated by Pgap
    REAL(r_std),DIMENSION (:), INTENT (in)          :: pb             !! tzjh Lowest level pressure (hPa)
    REAL(r_std),DIMENSION (:), INTENT (in)          :: swdown         !! tzjh short wave down
    REAL(r_std),DIMENSION (:), INTENT (in)          :: qsurf          !! tzjh  Near surface specific humidity !! @tex ($kg kg^{-1}$) @endtex 
  
    !! 0.2 Output variables

    REAL(r_std), DIMENSION(:,:), INTENT (out)       :: transpir_supply     !! Supply of water for transpiration 
                                                                           !! @tex $(mm dt^{-1})$ @endtex
    REAL(r_std), DIMENSION(:,:), INTENT(out)        :: vir_transpir_supply !! Supply of water for transpiration 
                                                                           !! @tex $(mm dt^{-1})$ @endtex

    !! 0.3 Modified variables

   REAL(r_std), DIMENSION(:,:,:),INTENT(inout)      :: vx     !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(:,:,:),INTENT(inout)      :: vr     !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(:,:,:),INTENT(inout)      :: vl     !! Vegetation height per circ_class_biomass (m)
 
   REAL(r_std), DIMENSION(:,:,:),INTENT(inout)      :: psi_leaf     !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(:,:,:),INTENT(inout)      :: psi_stem     !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(:,:,:),INTENT(inout)      :: psi_root     !! Vegetation height per circ_class_biomass (m)

 
   !! 0.4 Local variables

   INTEGER(i_std)                                  :: ipts,ivm,icirc      !! indices
   INTEGER(i_std)                                  :: ibdl,istm           !! indices
   INTEGER(i_std)                                  :: tmp_ncirc           !! indices
   
    
    REAL(r_std)                                     :: R_root              !! Hydraulic resistance of the roots
    REAL(r_std)                                     :: R_leaf              !! Hydraulic resistance of the leaves
    REAL(r_std)                                     :: R_sap               !! Hydraulic resistance of sapwood 
    REAL(r_std)                                     :: R_shoot             !! Hydraulic resistance of shoot corrected for temperature
    REAL(r_std), DIMENSION(ncirc)                   :: height              !! Vegetation height per circ_class_biomass (m)
    REAL(r_std), DIMENSION(kjpindex,nbdl,nstm)      :: phi_soil            !! Soil water potential per soil layer per soiltile higher 
                                                                           !! than -5 MPa (threshold for hygroscopic water) (MPa)
  
    REAL(r_std), DIMENSION(kjpindex,nbdl,nstm)      :: e_frac            !! fraction of water transpired by layers no units
    REAL(r_std), DIMENSION(kjpindex,nbdl,nstm)      :: e_max             !! maximum amoount of available water for transpiration per layer mmol m2 s-1 

    REAL(r_std), DIMENSION(kjpindex,nbdl,nstm)      :: res_soil          !! Soil water resistance per layers
    REAL(r_std), DIMENSION(kjpindex,nbdl,nstm)      :: ksaveUNIT         !! Hydraulic conductivity (from hydrol.90)

    REAL(r_std), DIMENSION(nbdl)                   :: lr     !! root length per unit of soil volume
    REAL(r_std), DIMENSION(nbdl)                   :: rs     !! mean distance between roots (m) 

    REAL(r_std), DIMENSION(ncirc)                   :: circ_class_transpir_supply     !! @tex $(m^{3}s^{-1}tree^{-1})$ @endtex
    REAL(r_std), DIMENSION(ncirc)                   :: vir_circ_class_transpir_supply !! @tex $(m^{3}s^{-1}tree^{-1})$ @endtex
    REAL(r_std)                                     :: delta_P             !! Pressure difference between leaves and soil
    REAL(r_std)                                     :: vir_delta_P         !! Virtual pressure difference between leaves and soil

    REAL(r_std), SAVE, ALLOCATABLE, DIMENSION(:)    :: z_soil             !! Soil levels (m) - dimension nbdl+1
    !$OMP THREADPRIVATE(z_soil)

    INTEGER(i_std)                                  :: ier                 !! Error handling
    REAL(r_std), DIMENSION(nvm)                     :: k_sap_cav           !! sapwood conductivity decreased by cavitation
    REAL(r_std), DIMENSION(nbdl,nvm)                :: root_dens           !! root density per layer
    REAL(r_std), DIMENSION(nvm)                     :: rpc                 !! scaling factor for integral
    REAL(r_std),DIMENSION(kjpindex,nbdl,nstm)       :: phi_soiltile        !! soil water potentential per soil layer per soil tile 
    REAL(r_std),DIMENSION (kjpindex,nbdl,nstm)      :: swc_adj             !! Volumetric soil water content, adjusted when it is lower 
                                                                           !! than or equal to the residual soil water content
    REAL(r_std),DIMENSION(kjpindex,nvm)             :: phi_soilroot        !! Sum of soil water potential in each soil layer weighted 
                                                                           !! by the share of the roots in each layer (MPa)
    REAL(r_std),DIMENSION(kjpindex,nvm)             :: vir_phi_soilroot    !! Virtual transpir supply to be used in land cover change
                                                                           !! Sum of soil water potential in each soil layer weighted 
   ! Compute VPD 
   REAL(r_std), DIMENSION(kjpindex)      :: VPD                            !! Vapor Pressure Deficit (kPa)
   REAL(r_std), DIMENSION(kjpindex)      :: light                          !! 
   REAL(r_std), DIMENSION(kjpindex)      :: qsatt                          !! surface saturated humidity at 2m (??)
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc) :: phi_soilroot_circ
!!!
!-----------------------------------------------------------------------------------------------------------
!-----------------------------------------------------------------------------------------------------------
!!! declaration for the new hydraulic architecture scheme - code commented for now
   ! Hydraulic potentials of each organ (Mpa)
   REAL(r_std), DIMENSION(ncirc)      :: new_psi_leaf     !!    
   REAL(r_std), DIMENSION(ncirc)      :: new_psi_stem     !!
   REAL(r_std), DIMENSION(ncirc)      :: new_psi_root     !! 

   REAL(r_std), DIMENSION(:,:,:),INTENT(inout)                   :: gsh   !!
   REAL(r_std), DIMENSION(:,:,:),INTENT(inout)                  :: tzj_supply
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc)                   :: Et    !!

   !Hydraulic conductivities (mmol m-2 s-1 MPa-1)
   REAL(r_std), DIMENSION(ncirc)      :: kleaf     !! 
   REAL(r_std), DIMENSION(ncirc)      :: kstem     !!
   REAL(r_std), DIMENSION(ncirc)      :: kroot     !!
   REAL(r_std), DIMENSION(ncirc)      :: ktrunk    !!
   REAL(r_std), DIMENSION(ncirc)      :: kupper    !!
   
 
   ! Water storage
   REAL(r_std), DIMENSION(ncirc)     :: vdot_leaf     !! 
   REAL(r_std), DIMENSION(ncirc)     :: vdot_xylem    !! 
   REAL(r_std), DIMENSION(ncirc)     :: vdot_root     !! 

   REAL(r_std), DIMENSION(ncirc)                   :: vxmax              !! 
   REAL(r_std), DIMENSION(ncirc)                   :: vrmax              !!
   REAL(r_std), DIMENSION(ncirc)                   :: vmax_l             !!

   REAL(r_std), DIMENSION(ncirc)                   :: new_vl             !!
   REAL(r_std), DIMENSION(ncirc)                   :: new_vx             !!
   REAL(r_std), DIMENSION(ncirc)                   :: new_vr             !!


!! Rate of changes from soil and storage : to simplify  
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc) :: vdot_storage_leaf
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc) :: vdot_hydr_leaf
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc) :: vdot_hydr_stem
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc) :: vdot_storage_stem
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc) :: vdot_storage_root

   ! for output vertical water flow
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc) :: vdot_hydr_leaf_vert

   !

! Environmental variables

   REAL(r_std), DIMENSION(nvm)                   :: psi_soil    !! hydrolic protential of the soil (use for hydrol-arch)
   REAL :: limit                                                !! optimization
   REAL :: diff                                                 !! optimization
   REAL :: timestep                                             !! link to ORCHIDEE now set a 1800
   REAL*8 ::  mm                                                !! need a double precision (sinon loop dans le vide) 
   REAL :: atm  

! Structural variables
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc)     :: stem_volume                      !! sapwood conductivity decreased by cavitation
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc)     :: root_volume                      !! sapwood conductivity decreased by cavitation
   REAL(r_std), DIMENSION(ncirc)     :: dbh                !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc)     :: canopy_leaf_area   !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(ncirc)     :: grav_potential     !! Vegetation height per circ_class_biomass (m)
  
   REAL(r_std), DIMENSION(ncirc)     :: transpir_class    !! Vegetation height per circ_class_biomass (m)
   REAL(r_std)                       :: tmp    !! useful

   REAL(r_std),DIMENSION(kjpindex,nvm),INTENT(out)       :: transpir_tot    !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(kjpindex),INTENT(out)          :: VPD_tzj   

   REAL(r_std), DIMENSION(ncirc)                   :: tmp2    !! Vegetation height per circ_class_biomass (m)
!  
   REAL ::  klight            ! light curve parameter
   REAL, PARAMETER ::  zero =0.0             ! maximum vapor pressure deficit, kPa
   REAL ::  rr             ! maximum vapor pressure deficit, kPa
   REAL ::  srl             ! maximum vapor pressure deficit, kPa

   REAL(r_std), DIMENSION(:,:,:), INTENT (inout)                :: stem_plc    !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc)                   :: optileaf    !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc)                   :: optistem    !! Vegetation height per circ_class_biomass (m)
   REAL(r_std), DIMENSION(kjpindex,nvm,ncirc)                   :: optiroot    !! Vegetation height per circ_class_biomass (m)

   


   INTEGER :: M,N,INFO
   REAL(r_std) :: FNORM
   REAL(r_std) :: ENORM !,DPMPAR
   REAL(r_std),ALLOCATABLE,DIMENSION(:) :: X,FVEC,PARS
   REAL(r_std)    :: inew_psi_leaf, inew_psi_stem,inew_psi_root, &
                     ikmax_leaf, iP50_leaf, ia_leaf, ikstem, &
                     icl, ipsi_leaf, ipsi_stem, igrav_potential, &
                     igsh, iVPD, icanopy_leaf_area, &
                     ikmax_stem, iP50_stem, ia_stem, &
                     ikroot, icxyl, istem_volume, &
                     ikmax_root, iP50_root, ia_root, &
                     icr, ipsi_root, iroot_volume, ivl, &
                     iEt, ikupper, ivdot_storage_leaf, ivdot_hydr_leaf, &
                     iktrunk, ivdot_storage_stem, ivdot_hydr_stem, &
                     inew_kroot, ivdot_storage_root, ivdot_hydr_root,&
                     ipsi_soil, &
                     inew_kstem
         LOGICAL, ALLOCATABLE, SAVE                 :: iniok(:,:,:)     !!Vegetation
!  height per circ_class_biomass (m)
!        IF (.NOT. ALLOCATED(iniok)) ALLOCATE(iniok(kjpindex,nvm,ncirc))
!-----------------------------------------------------------------------------------------------------------
!-----------------------------------------------------------------------------------------------------------
  CHARACTER(LEN=10)                                      :: part_str 
  REAL(r_std), DIMENSION(kjpindex,nvm)                   :: biomass_root    !! Roots biomass

  ! Values per soil type
  REAL(r_std)    :: tnvan                !! Van Genuchten coeficients n (unitless) ! 1/n=1-m
  REAL(r_std)   :: tavan                !! Van Genuchten coeficients a
  REAL(r_std)   :: tmcr                 !! Residual volumetric water content
  REAL(r_std)   :: tmcs                 !! Saturated volumetric water content
  REAL(r_std)   :: tks                 !! Saturated volumetric water content

!  ! one dimension array allocated, computed, saved and got in hydrol module
  ! Values per soil type
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION (:)   :: nvan                !! Van Genuchten coeficients n (unitless) ! RK:
!$OMP THREADPRIVATE(nvan)                                                 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION (:)   :: avan                !! Van Genuchten coeficients a!@tex!$(mm^{-1})$!@endtex
!$OMP THREADPRIVATE(avan)                                                
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION (:)   :: mcr                 !! Residual volumetric water content !! !@tex !$(m^{3} !m^{-3})$!@endtex
!$OMP THREADPRIVATE(mcr)                                                 
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION (:)   :: mcs                 !!Saturated volumetric water content !@tex !$(m^{3} !m^{-3})$!@endtex
!$OMP THREADPRIVATE(mcs)
  REAL(r_std), ALLOCATABLE, SAVE, DIMENSION (:)   :: ks !!Saturated volumetric water content
!$OMP THREADPRIVATE(ks)
  REAL(r_std)  :: which_layers
  IF (.NOT. ALLOCATED(iniok)) ALLOCATE(iniok(kjpindex,nvm,ncirc))

   IF (.NOT. ALLOCATED(z_soil)) THEN  
       ALLOCATE(z_soil(nbdl+1), stat=ier)
       IF ( ier /= 0 ) CALL ipslerr_p(3,'sechibaHA','Pb in allocate of z_soil','','')
       z_soil(1)= 0.
       z_soil(2:nbdl+1) = diaglev(1:nbdl)
   ENDIF
!_ =================================================================================================================================

        !write(numout,*) "phi_soilroot is initialized"

        phi_soilroot=zero    
        stem_plc = zero
        optileaf = zero
        optistem = zero
        optiroot = zero
        e_frac = zero
        e_max=zero
        phi_soilroot_circ=zero
    ! Set Transpir_supply to a value that is definitely larger than transpir
    ! that way the plant will not experience water stress in the first 
    ! day of the simulation when there Transpir_supply is calculated before 
    ! there is any biomass available. Biomass is prescribed in 
    ! stomate_prescribe.f90 
    ! We need this line, if only for PFT type 1, which otherwise will
    ! not be initialized.
    transpir_supply(:,:) = val_exp
    phi_soiltile(:,:,:) = -un
    ! tzj initialize transpir_to tzj initialize transpir_tot  (hydraulic
    ! architecture)
    transpir_tot(:,:)=-un
    VPD_tzj(:)=-un
    !gsh(:,:)=zero

    !! 1. Calculate plant soil water potential 
    !! First get the soil properties 

    ! Soil water potential for each soiltile in each layer from 
    ! soil water content according to Van Genuchten (1980)

    IF (.NOT. ALLOCATED(nvan)) ALLOCATE (nvan(nscm),stat=ier)
    IF (ier /= 0) CALL ipslerr_p(3,'hydrol_arch','Problem in allocate of variable nvan','','')

    IF (.NOT. ALLOCATED(avan)) ALLOCATE (avan(nscm),stat=ier)
    IF (ier /= 0) CALL ipslerr_p(3,'hydrol_arch','Problem in allocate of variable avan','','')

    IF (.NOT. ALLOCATED(mcr)) ALLOCATE (mcr(nscm),stat=ier)
    IF (ier /= 0) CALL ipslerr_p(3,'hydrol_arch','Problem in allocate of variable mcr','','')

    IF (.NOT. ALLOCATED(mcs)) ALLOCATE (mcs(nscm),stat=ier)
    IF (ier /= 0) CALL ipslerr_p(3,'hydrol_arch','Problem in allocate of variable mcs','','')

    IF (.NOT. ALLOCATED(ks)) ALLOCATE (ks(nscm),stat=ier)
    IF (ier /= 0) CALL ipslerr_p(3,'hydrol_arch','Problem in allocate of variable mcs','','')
!    DO ipts = 1,kjpindex

    SELECTCASE (nscm)
    CASE (3)
  nvan(:) = nvan_fao(:)
  avan(:) = avan_fao(:)
  mcr(:) = mcr_fao(:)
  mcs(:) = mcs_fao(:)
    CASE (12)
  nvan(:) = nvan_usda(:)
  avan(:) = avan_usda(:)
  mcr(:) = mcr_usda(:)
  mcs(:) = mcs_usda(:)
    CASE DEFAULT
       !WRITE (numout,*) 'Unsupported soil type classification. Choose betweenzobler and usda according to the map'
       CALL ipslerr_p(3,'hydrol_init','Unsupported soil type classification. ',&
            'Choose between zobler and usda according to the map','')
    ENDSELECT

! Read in the run.def the parameters values defined by the user
! NO CHECK on the values (as it is done in hydrol.f90)

 !Config Key   = CWRR_N_VANGENUCHTEN
    !Config Desc  = Van genuchten coefficient n
    !Config If    = HYDROL_CWRR
    !Config Def   = 1.89, 1.56, 1.31
    !Config Help  = This parameter will be constant over the entire 
    !Config         simulated domain, thus independent from soil
    !Config         texture.   
    !Config Units = [-]
    CALL getin_p("CWRR_N_VANGENUCHTEN",nvan)

    !Config Key   = CWRR_A_VANGENUCHTEN
    !Config Desc  = Van genuchten coefficient a
    !Config If    = HYDROL_CWRR
    !Config Def   = 0.0075, 0.0036, 0.0019
    !Config Help  = This parameter will be constant over the entire 
    !Config         simulated domain, thus independent from soil
    !Config         texture.   
    !Config Units = [1/mm]  
    CALL getin_p("CWRR_A_VANGENUCHTEN",avan)

   !Config Key   = VWC_RESIDUAL
    !Config Desc  = Residual soil water content
    !Config If    = HYDROL_CWRR
    !Config Def   = 0.065, 0.078, 0.095
    !Config Help  = This parameter will be constant over the entire 
    !Config         simulated domain, thus independent from soil
    !Config         texture.   
    !Config Units = [m3/m3]  
    CALL getin_p("VWC_RESIDUAL",mcr)

   !Config Key   = VWC_SAT
    !Config Desc  = Saturated soil water content
    !Config If    = HYDROL_CWRR
    !Config Def   = 0.41, 0.43, 0.41
    !Config Help  = This parameter will be constant over the entire 
    !Config         simulated domain, thus independent from soil
    !Config         texture.   
    !Config Units = [m3/m3]  
    CALL getin_p("VWC_SAT",mcs)

   !Config Key   = RSOILROOT
    CALL getin_p('rsoilroot',rsoilroot)  !
!WRITE(*,*) "test flagtzj hydrolARC", rsoilroot
    CALL getin_p('ok_joetzjer_hydro',ok_joetzjer_hydro)
    CALL getin_p('VPD_k1',vpd_k1)
    CALL getin_p('VPD_b1',vpd_b1)
    !write(*,*) 'VPD_k1',vpd_k1
    !write(*,*) 'VPD_b1',vpd_b1 

     CALL qsatcalc (kjpindex, temp_air, pb, qsatt)
     VPD(:) = ( qsatt(:)*pb(:) / (Tetens_1+qsatt(:)*Tetens_2 ) ) &
          - ( qsurf(:) * pb(:) / (Tetens_1+qsurf(:)* Tetens_2) )
     ! VPD is needed in kPa
     ! We limit the impact of VPD in the range of [0:6] kPa
     ! This seems to be the typical range of values
     ! that the vapor pressure difference can take, although
     ! there is a paper by Mott and Parkhurst, Plant, Cell & Environment,
     ! Vol. 14, pp. 509--519 (1991) which gives a value of 15 kPa.
     VPD(:) = MAX(zero,MIN(VPD(:)/10.,6.))
    ! VPD(:) = VPD(:)*1.038+0.132
    ! VPD(:) = VPD(:)*1.038291 + 0.1315685

     VPD(:) = VPD(:)*vpd_k1+vpd_b1
N=1
M=27
ALLOCATE(X(N))
ALLOCATE(FVEC(N))
ALLOCATE(PARS(M))

IF (ok_joetzjer_hydro) THEN
IF (ldrestart_read) THEN
            psi_stem(:,:,:) = val_exp
            DO icirc = 1,ncirc
               !write(numout,*) 'fail psi_stem',icirc
               !write(*,*) 'fail in psi stem', icirc
               WRITE(part_str,'(I2)') icirc
               IF ( icirc < 10 ) part_str(1:1) = '0'
               var_name = 'psi_stem_'//part_str(1:LEN_TRIM(part_str))
               CALL restget_p (rest_id, var_name, nbp_glo,nvm,1,kjit,.TRUE.,psi_stem(:,:,icirc), "gather", nbp_glo, index_g)
            ENDDO

            psi_leaf(:,:,:) = val_exp
            DO icirc = 1,ncirc
               WRITE(part_str,'(I2)') icirc
               IF ( icirc < 10 ) part_str(1:1) = '0'
              var_name = 'psi_leaf_'//part_str(1:LEN_TRIM(part_str))
               CALL restget_p (rest_id, var_name,nbp_glo,nvm,1,kjit,.TRUE.,psi_leaf(:,:,icirc), "gather", nbp_glo, index_g)
            ENDDO

           psi_root(:,:,:) = val_exp
            DO icirc = 1,ncirc
               WRITE(part_str,'(I2)') icirc
               IF ( icirc < 10 ) part_str(1:1) = '0'
               var_name = 'psi_root_'//part_str(1:LEN_TRIM(part_str))
               CALL restget_p (rest_id, var_name,nbp_glo,nvm,1,kjit,.TRUE.,psi_root(:,:,icirc), "gather", nbp_glo, index_g)
            ENDDO
   ENDIF
ENDIF

DO ipts = 1,kjpindex  ! loop on land points 

   tmcr=mcr(njsc(ipts))
   tmcs=mcs(njsc(ipts))
   tnvan=nvan(njsc(ipts))
   tavan=avan(njsc(ipts))

   WRITE(*,*) "tmcr", tmcr
!----------------------------------------------------------------------------------
! tzjh : compute light and VPD (for hydraulic architecture)
 !CALL qsatcalc (kjpindex, temp_air, pb, qsatt)
 !    VPD(:) = ( qsatt(:)*pb(:) / (Tetens_1+qsatt(:)*Tetens_2 ) ) &
 !         - ( qsurf(:) * pb(:) / (Tetens_1+qsurf(:)* Tetens_2) )
     ! VPD is needed in kPa
     ! We limit the impact of VPD in the range of [0:6] kPa
     ! This seems to be the typical range of values
     ! that the vapor pressure difference can take, although
     ! there is a paper by Mott and Parkhurst, Plant, Cell & Environment,
     ! Vol. 14, pp. 509--519 (1991) which gives a value of 15 kPa.
 !    VPD(:) = MAX(zero,MIN(VPD(:)/10.,6.))
    ! VPD(:) = VPD(:)*1.038+0.132
    ! VPD(:) = VPD(:)*1.038291 + 0.1315685
    
  !   VPD(:) = VPD(:)*vpd_k1+vpd_b1
     light(ipts) = swdown(ipts) * 2.3
!----------------------------------------------------------------------------------

      !---TEMP---
       IF (ld_hydrolarch) THEN
          !WRITE(numout,*) 'soil texture',njsc
          !WRITE(numout,*) 'swc', swc(ipts,:,:)  
          !WRITE(numout,*)'soiltile',soiltile(ipts,:)
       ENDIF
       !----------

       !! 2.1 Calculate soil water potential
       !  Swc calculated in hydrol.f90 cannot be lower than or equal 
       !  to the residual soil water content for each soiltile.
       DO ibdl = 1, nbdl

          DO istm = 1,nstm
             ! tmcr is mcr(njsc(ipts)) - this can be simplified 
             IF (swc(ipts,ibdl,istm) .LE. tmcr)  THEN

                    IF (istm .EQ. 2) THEN
                                  WRITE(*,*) "LOWER than tmcr", ibdl, istm
                                  WRITE(*,*) "SWC", swc(ipts,ibdl,istm)
                    ENDIF


     !+++CHECK+++
                !Explain why you do this
                swc_adj(ipts,ibdl,istm) = tmcr  + .00001
!               swc_adj(ipts,ibdl,istm) = mcr_usda(nstm) + .00001
                !+++++++++++
             ELSE
                swc_adj(ipts,ibdl,istm) = swc(ipts,ibdl,istm)
             IF (l_first_sechiba) THEN
                   swc_adj(ipts,ibdl,istm) = min_sechiba
             ENDIF

             ENDIF

           ENDDO !ENDDO loop istm soil type


          !! 2. Initialize variables on first call
          ! Soil water potential for each soiltile in each layer from 
          ! soil water content according to Van Genuchten (1980). Convert 
          ! unit avan from mm-1 to m-1. Convert units soil matric potential
          ! from m to MPa by multiplying with cte_grav and rho_h2o. 
          ! Soiltile = fraction of each soil column 
          ! (three soil columns=bare soil, tree, grass)
             DO istm = 1,nstm
               IF (swc(ipts,ibdl,istm) .GE. tmcs) THEN
               !WRITE(*,*) "sup a field capacity"
               ENDIF

               IF (swc_adj(ipts,ibdl,istm) .GT. min_stomate .AND. &
                  (swc_adj(ipts,ibdl,istm) - tmcr) .GT. min_stomate) THEN

                phi_soiltile(ipts,ibdl,istm) = &
                     - ( cte_grav * rho_h2o * kilo_to_unit * & 
                     ( 1/(tavan*kilo_to_unit) ) * &
                     ( ( (swc_adj(ipts,ibdl,istm) - tmcr ) / &
                     ( tmcs - tmcr ) ) ** &
                     ( -1 / (1-1/tnvan) ) - 1) ** &
                     (1/tnvan ) ) / mega_to_unit
                              IF (istm .EQ. 2) THEN
                                  WRITE(*,*) "soil water content (adjusted)", swc_adj(ipts,ibdl,istm),ibdl
                                 ! WRITE(*,*) "phi", phi_soiltile(ipts,ibdl,istm),ibdl
                              ENDIF
! ( -1 / (1-1/tnvan) ) - 1) ** & original
!  ( -(1+(1/tnvan)) ) - 1) ** &

                ELSE

                phi_soiltile(ipts,ibdl,istm) = zero
WRITE(*,*) "no compute phi_soiltile", ibdl, istm
                ENDIF
                ENDDO !soil type 

          ! Threshold for soil water potential: it cannot be lower than the 
          ! soil water potential for hygroscopic water (= -5 MPa, Larcher 2001)
          phi_soil(ipts,ibdl,:) = MAX(phi_soiltile(ipts,ibdl,:),pres_soil_potential_min)
          ! Calculate soil water potential per layer by multiplying with 
          ! the fraction of each soiltile
!!$       phi_soil(ipts,ibdl) = SUM(soiltile(ipts,:) * phi_soiltile(ipts,ibdl,:))
         ENDDO ! loop on soil layers

       ! following initialisation of swc
       l_first_sechiba = .FALSE.

       !---TEMP---
       IF (ld_hydrolarch) THEN
          !WRITE(numout,*) 'phi_soiltile', phi_soiltile(ipts,:,:)
          !WRITE(numout,*) 'phi_soil', phi_soil
       ENDIF
       !----------

       !! 3. Calculate plant resistance

       !! 3.1 Calculate root profile 
       !  Weighting soil water potential with root profile


       ! Scaling factor for integration
       rpc(:) = un / ( un - EXP( -z_soil(nbdl) / humcste(:) ) )

!WRITE(*,*) "SECH_HYDROL zsoil", z_soil(nbdl) 
!WRITE(*,*) "SECH_HYDROL hum", humcste
!WRITE(*,*) "SECH_HYDROL rpc", rpc

       ! Calculate root density per layer per pft
       !+++CHECK+++
       ! what is the root density for layer one ?
       DO ibdl = 1, nbdl ! Loop over # soil layers
          root_dens(ibdl,:) = rpc(:) * &
               ( EXP( -z_soil(ibdl)/humcste(:)) - &
               EXP( -z_soil(ibdl+1)/humcste(:)) )
          !write(*,*) 'root_density ',ibdl,' ',root_dens(ibdl,2)
       ENDDO ! Loop over # soil layers
       !++++++++++

       !! 3.2 Calculate plant resistance to water transport 
       !  Calculate plant resistance to water transport according to following
       !  the principle of an electric circuit. The code is largely based on
       !  Hickler et al. 2006
       DO ivm = 2,nvm ! loop on pft 

          !! 3.2.1 Calculate PFT-specific characteristics
          IF (is_tree(ivm)) THEN

             ! Calculate for each circumference classes
             tmp_ncirc = ncirc

             ! Calculate the effective height (m) from biomass. The effective
             ! value is used here because the water needs to be transported
             ! through both the belowground and aboveground biomass. Using the 
             ! height (thus not the effective height) would only account for the 
             ! height due to the aboveground biomass.
             height(:) = wood_to_height_eff(circ_class_biomass(ipts,ivm,:,:,icarbon),ivm)
             dbh(:)=wood_to_dia(circ_class_biomass(ipts,ivm,:,:,icarbon),ivm) !tzjh
             ! Calculate soil water potential weighted for root density
             ! Note that the second soiltile in swc is for trees.
             !+++CHECK+++
             ! This implementation relies on two strong assumptions. First,
             ! roots are assumed to follow a rigid distribution irrespective 
             ! of how the water is distributed in the soil. So even if on 
             ! average lots of water is available in deeper layer, the modeled 
             ! plants will grow most roots in the top layers. Second it is 
             ! assumed that the root_potential is identical to the soil_potential
             ! With these assumptions it was found to be impossible to grow
             ! oak, beech and birch even in central Europe because those species
             ! experienced too much water stress. To overcome this problem
             ! a tuning factor has been introduced. In the future this tuning factor
             ! should be removed by a morec mechanistic model for root-soil
             ! interface.
             !+++++ TEMP ++++++

! If rsoilroot is activated AND PFT2 

               IF ((rsoilroot) .AND. (ivm .EQ. 2)) THEN
               !WRITE(*,*) "rsoilroot ON"
               ! THIS CONCERN only ISTM (soiltype=2)  
               !Define some parameters (hard coded for now, only for PFT2) 
                rr=0.29E-3 !rr fine root radius (m) ; in Bonan et al., 2014 GMD rr ≃ 0.29
                srl=10 ! (m/g specific roots lenght value from Metcalfe et al., 2008)

                  DO ibdl = 1, nbdl ! loop over soil layers 
                  !consider a constant biomass to compute lr
                  lr(ibdl)=root_dens(ibdl,ivm)*2*60* srl !  
           !lr(ibdl)=root_dens(ibdl,ivm)*2*biomass(ipts,ivm,iroot,icarbon)* srl !  
           !rs(ibdl)=(1/(3.14*lr(ibdl)*z_soil(ibdl+1)))**(1/2)
           !rs(ibdl)=(1/(3.14*lr(ibdl)*dlh(ibdl)))**(1/2)
                  rs(ibdl)=(1/(3.14*lr(ibdl)))**(1/2)

                  ! k save is in mm per day we need in in m/s , mpa *g)
                  ! -3 is the psiRootmin (Bonan et al., 2014) 
                  ! mm/d to m/s
                  ksaveUNIT(ipts,ibdl,2)=ksave(ipts,ibdl,2)*1000/(60*60*24)
                  !res_soil(:,ibdl,2)=(LOG(rs(ibdl)/rr))/(dlh(ibdl)*2*3.14*lr(ibdl)*(ksaveUNIT(ipts,ibdl,2)/(9.8*18E-5*1E-3)))
                  res_soil(ipts,ibdl,2)=(LOG(rs(ibdl)/rr))/(dlh(ibdl)*2*3.14*lr(ibdl)*(ksaveUNIT(ipts,ibdl,2)/(9.8*18E-5*1E-3)))
                  e_max(ipts,ibdl,2)= (phi_soil(ipts,ibdl,2)-psi_soil_min)/res_soil(ipts,ibdl,2)

                         IF (e_max(ipts,ibdl,2) .LT. min_sechiba)  e_max(ipts,ibdl,2) = 0
                  END DO  ! loop on soil layers

                  ! tmp=SUM(e_max(ipts,:,2))  ! comment this line now April 19
                  ! 22:45 2020 
                  DO icirc=1,ncirc
                     IF (icirc .LT. 10) THEN
                         which_layers=icirc
                     ELSE
                         which_layers=10
                     ENDIF
                     tmp=SUM(e_max(ipts,1:which_layers,2)) 
                     e_frac=zero
                     phi_soilroot = zero
                     IF (tmp .GT. min_sechiba) THEN          
                         DO ibdl = 1, which_layers
                            e_frac(ipts,ibdl,2)=e_max(ipts,ibdl,2)/SUM(e_max(ipts,1:which_layers,2))
                     
                         ENDDO
                    !write(*,*) 'e_frac',e_frac(ipts,ibdl,2), 'e_max',e_max(ipts,ibdl,2), 'sum_e_max', SUM(e_max(ipts,:,2))
                    !write(numout,*) "sechibahydrol1::", phi_soil(ipts,:,2), e_frac(ipts,:,2) 
                     phi_soilroot(ipts,ivm) = SUM( phi_soil(ipts,1:which_layers,2)*e_frac(ipts,1:which_layers,2))
                     ELSE
                          phi_soilroot(ipts,2)=psi_soil_min    !-3 before
                     END IF
                    ! DO ibdl=1, nbdl
                    !    write(*,*) 'e_frac',e_frac(ipts,ibdl,2),'e_max',e_max(ipts,ibdl,2), 'sum_e_max', SUM(e_max(ipts,:,2))
                    ! ENDDO
                    phi_soilroot_circ(ipts,ivm,icirc)=phi_soilroot(ipts,ivm)      
                ENDDO
         
             ELSE ! no rsoil and pft2 
                    !write(numout,*) "sechibahydrol2::", root_dens(:,ivm), phi_soil(ipts,:,2)
                  phi_soilroot(ipts,ivm) = SUM(root_dens(:,ivm) * phi_soil(ipts,:,2)) + &
                  phi_soil_tune(ivm)
                  DO icirc=1,ncirc
                        phi_soilroot_circ(ipts,ivm,icirc)=phi_soilroot(ipts,ivm)
                  ENDDO
               ENDIF !rsoilroot and pft2


          ELSE ! no trees condition
             ! There are no circumference classes for grasses
             ! and crops. Biomasses are stored in first circumference
             ! class
             tmp_ncirc = 1

             ! Calculate height (m) from biomass
             height(1) = circ_class_biomass(ipts,ivm,1,ileaf,icarbon) * &
                  sla(ivm) * lai_to_height(ivm)

             ! Calculate soil water potential weighted for root density. Note 
             ! that the third soiltile in swc is for grasses and crops.
             !write(numout,*) "sechibahydrol3::", root_dens(:,ivm), phi_soil(ipts,:,3),  phi_soil_tune(ivm)
             phi_soilroot(ipts,ivm) = SUM(root_dens(:,ivm) * phi_soil(ipts,:,3)) + &
                  phi_soil_tune(ivm)
             !+++++++++++ 

          ENDIF ! tree or no tree condition

          !! 3.2.2 Calculate general characteristics
          !  Calculate soil water potential weighted for root density
          !  Note that the second soiltile in swc is for trees. Calculate
          !  for both the relevant soil water column i.e. tall vegetation
          !  and a vertual soil water colum i.e. bare soil. The latter is
          !  needed in land cover change because we may establish vegetation
          !  on PFT1 and then need to know the water stress the plants will
          !  experience on this new soil column.
          !+++CHECK+++
          !  should this be sum of soil water potential or the average? The
          !  virtual_phi_soilroot may need to be revised once the water 
          !  columns are getting merged in LCC. There are no plants so we 
          !  should not account for the assumptions and thus not implement the
          !  tuning factor. 
          vir_phi_soilroot(ipts,ivm) = SUM(root_dens(:,ivm) * phi_soil(ipts,:,1))
          !+++++++++++

          !---TEMP---
          IF (ld_hydrolarch .AND. ivm .EQ. test_pft) THEN 
             !WRITE(numout,*) 'circ_class_biomass in hydrolic architecture,icirc', &
             !     circ_class_biomass(1,test_pft,:,:,icarbon)
            ! WRITE(numout,*) 'vegetation height, pft', height(:), ivm
             !WRITE(numout,*) 'z_soil',z_soil(1:nbdl+1)
             !WRITE(numout,*) 'rpc', ivm, rpc(ivm)
!!$             WRITE(numout,*) 'phi_soilrootlayer',root_dens*phi_soil
             !WRITE(numout,*) 'phi_soilroot', phi_soilroot(:,test_pft)
            ! WRITE(numout,*) 'vir_phi_soilroot', vir_phi_soilroot(:,test_pft)
          ENDIF
          !----------

          !! 3.2.3 Calculate plant resistences
          IF ( biomass(ipts,ivm,ileaf,icarbon) .GT. min_sechiba .AND. &
               biomass(ipts,ivm,iroot,icarbon) .GT. min_sechiba ) THEN
             
             DO icirc = 1,tmp_ncirc

                ! This ensures that the loop goes over all circ_classes for trees and only
                ! the first circ_class for grasses and crops
                IF (circ_class_biomass(ipts,ivm,icirc,ileaf,icarbon) .GT. min_sechiba .AND. &
                     circ_class_biomass(ipts,ivm,icirc,iroot,icarbon) .GT. min_sechiba ) THEN 

                   !! 3.2.3.1 Root resistance
                   !  Root resistance is in the first order related to root mass 
                   !  and expression was proposed by Weatherly, 1982). Convert
                   !  units of circ_class_biomss i.e. gC/ind to kg/ind
                   R_root = un / (k_root(ivm) * 2 * &
                        circ_class_biomass(ipts,ivm,icirc,iroot,icarbon) &
                        / kilo_to_unit)

                   !! 3.2.3.2 Sapwood resistance
                   !  Calculate k_sap_cav as a function of water stress following 
                   !  Tyree et al. (1994) and Sperry et al. (1998)
                   IF (is_tree(ivm)) THEN

                      IF( (phi_soilroot(ipts,ivm) == zero) .AND. (phi_50(ivm) .LE. zero) )THEN

                         ! This seems to cause a strange numerical issue, even though we should
                         ! just be taking the exponential of zero (i.e., one).  
                         k_sap_cav(ivm) = k_sap(ivm)

                      ELSE
                         !++++ TEMP +++++
                         IF((phi_soilroot(ipts,ivm)/phi_50(ivm)) .LT. zero)THEN
                            !++++++ CHECK +++++++++
                            ! If this is true, we generally try to take this ratio to
                            ! an odd power, which results in an imaginary number.  So
                            ! we use this simple solution for the moment.
                         !   WRITE(numout,*) 'phi_soilroot', phi_soilroot(ipts,ivm)
                         !   WRITE(numout,*) 'ipts', ipts
                         !   WRITE(numout,*) 'ivm', ivm
                         !   CALL ipslerr_p (3,'sechiba_hydrol_arch', &
                         !        'this quantity should never be negative', &
                         !        'See the output file for more details.','')
                            ! A temporary fix.  We cannot have the stop statement anymore,
                            ! since capping phi_soilroot at 0.0 above results in many PFTs
                            ! dying.  This needs to be addressed.
                            k_sap_cav(ivm) = k_sap(ivm)
                         ELSE
                            k_sap_cav(ivm) = k_sap(ivm) * &
                                 EXP(-((phi_soilroot(ipts,ivm)/phi_50(ivm)) ** &
                                 c_cavitation(ivm)))
                         ENDIF

                      ENDIF

                      ! If k_sap_cav is too low, we can get a divide by zero
                      ! error in the next couple lines.  So this is a protection
                      ! against that.
                      IF(k_sap_cav(ivm) .LE. min_sechiba)THEN

                         k_sap_cav(ivm) = min_sechiba

                      ENDIF

                      !  Following the expression by Magnani et al 2000, sapwood resistance
                      !  is given as a function of sapwood area. Convert Sapwood mass to 
                      !  sapwood area
                      !  tzj :  correction bug in R_sap 
                     ! R_sap = height(icirc) / (k_sap_cav(ivm) * &
                     !      (( circ_class_biomass(ipts,ivm,icirc,isapabove,icarbon) + &
                     !      circ_class_biomass(ipts,ivm,icirc,isapbelow,icarbon)) / & 
                     !      (tree_ff(ivm)*pipe_density(ivm) / height(icirc))) )
                       R_sap = (height(icirc)**2* tree_ff(ivm)*pipe_density(ivm)) / (k_sap_cav(ivm) *&
                        (circ_class_biomass(ipts,ivm,icirc,isapabove,icarbon) + &
                        circ_class_biomass(ipts,ivm,icirc,isapbelow,icarbon)))

                   ELSE

                      !+++CHECK+++
                      ! We have about the same leaf and root restistances and masses
                      ! as for tress but lack a resistance in the sapwood. This is resulting
                      ! in a huge supply because we lack part of the resistance. This was 
                      ! the motivation to create an R_sap for grasses and roots. This equation 
                      ! is made up and should be carefully checked against physiological
                      ! studies for grasses and crops on the issue.
!!$                         R_sap = zero
                      ! R_sap = height(icirc) / (k_sap(ivm) * &
                      !     (circ_class_biomass(ipts,ivm,icirc,isapabove,icarbon) / & 
                      !     (pipe_density(ivm) / height(icirc))) )
                      ! tzj idem R_sap
                      R_sap = (height(icirc)**2 * pipe_density(ivm)) / (k_sap(ivm) *  &
                      circ_class_biomass(ipts,ivm,icirc,isapabove,icarbon))


                      !+++++++++++

                   ENDIF

                   !! 3.2.3.3 Leaf resistance
                   !  Leaf resistance related to foliar projective area (Hickler 2006) or 
                   !  LAI (more consistent with pipe model)? fpc instead of lai because 
                   !  it is assumed that only sunlit leaves contribute to transpiration
                   !  Initialy fpc = 1-e**(-0.5*LAI) but it was replaxced by veget which
                   !  in itseld is calculated in Pgap and thus accounts for LAI and canopy
                   !  structure. This was still inconsistent with the calculation of the
                   ! atmospheric demand for transpiration, to improve consistency the coupled
                   ! lai was used as was done in the energy budget calculations.
                   ! R_leaf = 1/(k_leaf * fpc)
!!$                   R_leaf = un / (k_leaf(ivm) * &
!!$                        (un - EXP(-0.5 * circ_class_biomass(ipts,ivm,icirc,ileaf,icarbon) * &
!!$                        sla(ivm))))
                   R_leaf = un / (k_leaf(ivm) * &
                        biomass_to_coupled_lai(circ_class_biomass(ipts,ivm,icirc,ileaf,icarbon), &
                        veget(ipts,ivm),ivm))

                   !! 3.2.3.4 Temperature dependance of resistance
                   !  Decrease root resistance with soil temperature as a result of 
                   !  changes in water viscosity (Cochard et al 2000)
                   !  Decrease shoot resistance with air temperature (Cochard et al. 2000)
                   R_root = R_root / (a_viscosity(1) + a_viscosity(2) * &
                        (temp_sol_new(ipts) - zeroCelsius))               
                   R_shoot = (R_leaf + R_sap) / (a_viscosity(1) + a_viscosity(2) * &
                        (temp_air(ipts) - zeroCelsius))

                   !! 3.2.3.5 Calculate pressure difference between leaves and soil 
                   !  Defined by Whitehead 1998. Convert units to MPa.
                   !+++CHECK+++
                   ! If height is kept as a variable the delta_P gets out of bounds
                   ! this seems to be one of the places where the static approach
                   ! by Hickler fails. Could this be overcome by Sperry et al?
                   ! As a quick fix we limit the height. This might have been acceptable
                   ! if we would not have had to limit it at only 8m!
!!$                   IF (height(icirc) .GT. 8.) height(icirc) = 8.
                   delta_P = phi_leaf(ivm) - phi_soilroot(ipts,ivm) + &
                        (height(icirc)*cte_grav*rho_h2o) / kilo_to_unit
                   vir_delta_P = phi_leaf(ivm) - vir_phi_soilroot(ipts,ivm) + &
                        (height(icirc)*cte_grav*rho_h2o) / kilo_to_unit
                   !++++++++++

                   !! 3.2.3.6 Calculate water supply for transpiration in m/s
                   ! Using Dracy's law (Slatyer 1967, Whitehead 1998)
                   circ_class_transpir_supply(icirc) = (-delta_P) / (R_root + R_shoot)
                   vir_circ_class_transpir_supply(icirc) = (-vir_delta_P) / (R_root + R_shoot)

                ELSE  
                      
                   !set transpir_supply to zero if there is no leaf or root biomass in the circ_class 
                   circ_class_transpir_supply(icirc) = zero
                   vir_circ_class_transpir_supply(icirc) = zero

             ENDIF

             !---TEMP--- 
             IF (ld_hydrolarch .AND. ivm .EQ. test_pft) THEN
                !WRITE(numout,*) 'root_dens', root_dens(:,test_pft)
                !WRITE(numout,*) 'k_sap_cavitation, biomass(iroot)', k_sap_cav(ivm), &
                !     2 * circ_class_biomass(ipts,ivm,icirc,iroot,icarbon) / 1000.
                !WRITE(numout,*) 'sapwood area, ', ( circ_class_biomass(ipts,ivm,icirc,isapabove,icarbon) + &
                     !circ_class_biomass(ipts,ivm,icirc,isapbelow,icarbon)) / (tree_ff(ivm) * pipe_density(ivm)) / &
                     !height(icirc)
                !WRITE(numout,*) 'fpc, ',(1-EXP(-0.5*circ_class_biomass(ipts,ivm,icirc,ileaf,icarbon)*sla(ivm)))
                !WRITE(numout,*) 'R_root, R_sap, R_leaf', R_root, R_sap, R_leaf
                !WRITE(numout,*) 'R_shoot', R_shoot 
                !WRITE(numout,*) 'delta_P', delta_P
             ENDIF
             !----------

          ENDDO ! ncirc


          !+++CHECK+++
          ! Just to be sure that we are not double counting for grasses and crops
          IF (is_tree(ivm)) THEN
             ! transpir_supply per PFT (sum of diameter classes) per timestep
             transpir_supply(ipts,ivm) = &
                  (SUM(circ_class_transpir_supply(:) * circ_class_n(ipts,ivm,:))) * &
                  dtradia * kilo_to_unit
             vir_transpir_supply(ipts,ivm) = &
                  (SUM(vir_circ_class_transpir_supply(:) * circ_class_n(ipts,ivm,:))) * &
                  dtradia * kilo_to_unit
          ELSE
             transpir_supply(ipts,ivm) = &
                  (circ_class_transpir_supply(1) * circ_class_n(ipts,ivm,1)) * &
                  dtradia * kilo_to_unit
             vir_transpir_supply(ipts,ivm) = &
                  (vir_circ_class_transpir_supply(1) * circ_class_n(ipts,ivm,1)) * &
                  dtradia * kilo_to_unit
          ENDIF
          !+++++++++++

          ! Set transpir_supply to zero when negative.
          ! (When phisoilroot becomes very low, delta_P becomes positive and transpir_supply negative)
          IF (transpir_supply(ipts,ivm) .LT. zero) then
             IF(ld_warn)THEN
                !WRITE(numout,*) 'transpir_supply before set to zero when negative', transpir_supply(ipts,ivm), ivm
                !WRITE(numout,*) 'ipts, ivm:', ipts,ivm
                !WRITE(numout,*) 'transpir_supply: ', transpir_supply(ipts,ivm)
                !WRITE(numout,*) 'phisoilroot: ', phi_soilroot(ipts,ivm)
             ENDIF
             transpir_supply(ipts,ivm) = MAX(transpir_supply(ipts,ivm), zero)
             vir_transpir_supply(ipts,ivm) = MAX(vir_transpir_supply(ipts,ivm), zero)
          ELSE
             !do nothing
          ENDIF   

          ! transpir_supply is in m/s. Convert to mm/dt
          ! transpir_supply(ipts,ivm) = transpir_supply(ipts,ivm) * dtradia * 1000
!!$             WRITE(numout,*) 'transpir_supply', transpir_supply

          !---TEMP--- 
          IF (ld_hydrolarch .AND. ivm .EQ. test_pft .AND. ipts == test_grid) THEN
             WRITE(numout,*) 'transpir_supply, PFT, ', transpir_supply(ipts,test_pft), ivm
             WRITE(numout,*) 'vir_transpir_supply, PFT, ', vir_transpir_supply(ipts,test_pft), ivm
          ENDIF
          !----------

          ! Calculate daily water stress for use in stomate
!!$             IF (transpir_supply .LE. transpir) THEN
!!$                hydrol_stress(ipts,ivm) = transpir_supply(ipts,ivm)/transpir(ipts,ivm)
!!$             ELSE IF (transpir_supply .GT. transpir) THEN
!!$                hydrol_stress(ipts,ivm) = 1.
!!$             ENDIF

          ! Hydraulic architecure is not defined i.e. no biomass
       ELSE

          transpir_supply(ipts,ivm) = zero
          phi_soilroot(ipts,ivm) = zero

       ENDIF ! biomass leaves and roots.gt.zero
          

    ENDDO ! nvm

!ENDDO ! DO ipts = 1,kjpindex
!-----------------------------------------------------------------------------------------------------------------
! tzjh hydraulic architecture
!-----------------------------------------------------------------------------------------------------------------
!control%ok_joetzjer_hydro=control_in%ok_joetzjer_hydro
IF (ok_joetzjer_hydro) THEN
!   IF (ldrestart_read) THEN
!            psi_stem(:,:,:) = val_exp
!            DO icirc = 1,ncirc
!               !write(numout,*) 'fail psi_stem',icirc
!               !write(*,*) 'fail in psi stem', icirc
!               WRITE(part_str,'(I2)') icirc
!               IF ( icirc < 10 ) part_str(1:1) = '0'
!               var_name = 'psi_stem_'//part_str(1:LEN_TRIM(part_str))
!               CALL restget_p (rest_id, var_name, nbp_glo,nvm,1,kjit,.TRUE.,psi_stem(:,:,icirc), "gather", nbp_glo, index_g)
!            ENDDO

 !           psi_leaf(:,:,:) = val_exp
 !           DO icirc = 1,ncirc
 !              WRITE(part_str,'(I2)') icirc
 !              IF ( icirc < 10 ) part_str(1:1) = '0'
 !             var_name = 'psi_leaf_'//part_str(1:LEN_TRIM(part_str))
 !              CALL restget_p (rest_id, var_name, nbp_glo,nvm,1,kjit,.TRUE.,psi_leaf(:,:,icirc), "gather", nbp_glo, index_g)
 !           ENDDO

 !          psi_root(:,:,:) = val_exp
 !           DO icirc = 1,ncirc
 !              WRITE(part_str,'(I2)') icirc
 !              IF ( icirc < 10 ) part_str(1:1) = '0'
 !              var_name = 'psi_root_'//part_str(1:LEN_TRIM(part_str))
 !              CALL restget_p (rest_id, var_name, nbp_glo,nvm,1,kjit,.TRUE.,psi_root(:,:,icirc), "gather", nbp_glo, index_g)
  !          ENDDO
  ! ENDIF
  

!DO ipts = 1,kjpindex

!N=1
!M=27
!ALLOCATE(X(N))
!ALLOCATE(FVEC(N))
!ALLOCATE(PARS(M))


DO ivm = 2,nvm ! loop over pft - put a flag after to be able to choose the hydraulic architecture

! set general variables values  
limit = 0.00001

!-----------------------------------------------------------------
! variable en dur but to change
timestep = 1800
klight = 100           ! light curve parameter
atm = 101.3            ! atmospheric pressure, kPa
!----------------------------------------------------------------

! Need to know when it's the first time to initialize (maybe there is a simpler
! way to do, at least this work) - make sure it works when several pft. 

   IF (l_first_inih .EQ. .TRUE.) THEN  ! flag1 for initialization = TRUE when
                                              ! ready for initialization
   iniok(ipts,ivm,:) = .TRUE. ! flag2 for initialization (per circ)
          WRITE(*,*) 'tzjh iniok', iniok(ipts,ivm,:)
   ENDIF
   l_first_inih= .FALSE.
          
       DO icirc = 1,tmp_ncirc ! loop over tree classes 
!!!!!!!       DO icirc = 1,1 ! loop over tree classes 

            IF (iniok(ipts,ivm,icirc) .EQ. .TRUE.) THEN     !initialization per class
            WRITE(*,*) 'tzjh inialize',icirc

                

!!! Define the initial conditions           
                stem_volume(ipts,ivm,icirc)=stem_volume_f(height(icirc),dbh(icirc))
                root_volume(ipts,ivm,icirc)=root_volume_f(stem_volume(ipts,ivm,icirc), wood_density(ivm),root_shoot_ratio(ivm),root_density(ivm)) ! the volume of the root system

                canopy_leaf_area(ipts,ivm,icirc) = canopy_leaf_area_f(dbh(icirc), sla_hydro(ivm))
                grav_potential = grav_potential_f(height(icirc))
                !write(*,*) 'flag_flow 1'
!!! Calculate the size of the stored water reserves
                vxmax(icirc) = vxmax_f(stem_volume(ipts,ivm,icirc), w_density_stem(ivm))
                vrmax(icirc) = vrmax_f(stem_volume(ipts,ivm,icirc), wood_density(ivm), root_shoot_ratio(ivm), rwc_root(ivm))
                vmax_l(icirc) = vmax_l_f(dbh(icirc), LDMC(ivm))* cut_limit
!!!!WRITE(*,*)"vrmax ", vrmax(icirc),vmax_l(icirc),vxmax(icirc)
                !write(*,*) 'flag_flow 2'
!!!! start off by assuming the tree equilibrated with the soil 
!!!!!!!!!!!!!!!!psi_soil(ivm)=phi_soilroot(ipts,ivm)

                   IF (ALL(psi_stem(:,:,icirc) == val_exp) .AND. ALL(psi_leaf(:,:,icirc) == val_exp)) THEN

                         psi_root(ipts,ivm,icirc)=phi_soilroot_circ(ipts,ivm,icirc)
                         psi_stem(ipts,ivm,icirc)=phi_soilroot_circ(ipts,ivm,icirc)
                         psi_leaf(ipts,ivm,icirc)=phi_soilroot_circ(ipts,ivm,icirc)
                   ENDIF
!!Determine the water storage volume consistent with this initial water potential
                   vx(ipts,ivm,icirc) = vxmax(icirc) + cxyl(ivm)*psi_stem(ipts,ivm,icirc)*stem_volume(ipts,ivm,icirc)*1000.*1000./18.
                   vr(ipts,ivm,icirc) = vrmax(icirc) + cr(ivm)*psi_root(ipts,ivm,icirc)*root_volume(ipts,ivm,icirc)*1000.*1000./18.
                   vl(ipts,ivm,icirc) = vmax_l(icirc) + cl(ivm)*psi_leaf(ipts,ivm,icirc)*canopy_leaf_area(ipts,ivm,icirc)
!
                 !  write(*,*) 'flag_flow 3'
!! and the conductances 
                   kstem(icirc) = kstem_f(kmax_stem(ivm), P50_stem(ivm), a_stem(ivm), psi_stem(ipts,ivm,icirc))
                   kleaf(icirc) = kleaf_f(kmax_leaf(ivm), P50_leaf(ivm), a_leaf(ivm), psi_leaf(ipts,ivm,icirc))
                   kroot(icirc) = kroot_f(kmax_root(ivm), P50_root(ivm), a_root(ivm), psi_root(ipts,ivm,icirc))
                
!!
                 iniok(ipts,ivm,icirc)= .FALSE.
!!
!!WRITE(*,*)"stem_volume ", icirc,  stem_volume(icirc)
!!WRITE(*,*)"root_volume ", icirc,  root_volume(icirc)
!!WRITE(*,*)" CAN_LA ", canopy_leaf_area(icirc)
!!WRITE(*,*)" gravpot ", grav_potential(icirc)
!!WRITE(*,*)"psi_root ", psi_root(ipts,ivm,icirc)
!!WRITE(*,*)"psi_stem ", psi_stem(ipts,ivm,icirc)
!!WRITE(*,*)"psi_leaf ", psi_leaf(ipts,ivm,icirc)
!!WRITE(*,*)"psi_soil ", psi_soil(ivm)
!!WRITE(*,*)"kroot ", kroot(icirc)
!!WRITE(*,*)"kstem ", kstem(icirc)
!!WRITE(*,*)"kleaf ", kleaf(icirc)
!!WRITE(*,*)"vx ", vx(ipts,ivm,icirc)
!!WRITE(*,*)"vr ", vr(ipts,ivm,icirc)
!!WRITE(*,*)"vl ", vl(ipts,ivm,icirc)
!
!
           ELSEIF (iniok(ipts,ivm,icirc) .EQ. .FALSE.) THEN ! run 
!!write(*,*) 'tzjh runok',iniok(ipts,ivm,icirc)
!!
!!! compute needed local variable (otherwise need to set them as in/out)
                stem_volume(ipts,ivm,icirc)=stem_volume_f(height(icirc),dbh(icirc))
                root_volume(ipts,ivm,icirc)=root_volume_f(stem_volume(ipts,ivm,icirc), wood_density(ivm),root_shoot_ratio(ivm),root_density(ivm)) ! the volume of the root system
                canopy_leaf_area(ipts,ivm,icirc) = canopy_leaf_area_f(dbh(icirc), sla_hydro(ivm))
                grav_potential = grav_potential_f(height(icirc))

                vxmax(icirc) = vxmax_f(stem_volume(ipts,ivm,icirc), w_density_stem(ivm))
                vrmax(icirc) = vrmax_f(stem_volume(ipts,ivm,icirc), wood_density(ivm), root_shoot_ratio(ivm), rwc_root(ivm))
                vmax_l(icirc) = vmax_l_f(dbh(icirc), LDMC(ivm)) * cut_limit
!!WRITE(*,*)"vmax_l ", icirc,  vmax_l(icirc)
!!WRITE(*,*)"vrmax ", vrmax(icirc)
!!RITE(*,*)"LMDC ", icirc,  vmax_l(icirc)
                !write(*,*) 'flag_flow 4'
!
                vx(ipts,ivm,icirc) = vxmax(icirc) + cxyl(ivm)*psi_stem(ipts,ivm,icirc)*stem_volume(ipts,ivm,icirc)*1000.*1000./18.
                vr(ipts,ivm,icirc) = vrmax(icirc) + cr(ivm)*psi_root(ipts,ivm,icirc)*root_volume(ipts,ivm,icirc)*1000.*1000./18.
                vl(ipts,ivm,icirc) = vmax_l(icirc) + cl(ivm)*psi_leaf(ipts,ivm,icirc)*canopy_leaf_area(ipts,ivm,icirc)
!
                !write(*,*) 'flag_flow 5'
                kstem(icirc) = kstem_f(kmax_stem(ivm), P50_stem(ivm), a_stem(ivm), psi_stem(ipts,ivm,icirc))
                kleaf(icirc) = kleaf_f(kmax_leaf(ivm), P50_leaf(ivm), a_leaf(ivm), psi_leaf(ipts,ivm,icirc))
                kroot(icirc) = kroot_f(kmax_root(ivm), P50_root(ivm), a_root(ivm), psi_root(ipts,ivm,icirc))
!
!!WRITE(*,*)"stem_volume 2 ", icirc,  stem_volume(icirc)
!!WRITE(*,*)"root_volume ", icirc,  root_volume(icirc)
!!WRITE(*,*)" CAN_LA ", canopy_leaf_area(icirc)
!!WRITE(*,*)" gravpot ", grav_potential(icirc)
!!WRITE(*,*)"psi_root ", psi_root(ipts,ivm,icirc)
!!WRITE(*,*)"psi_stem ", psi_stem(ipts,ivm,icirc)
!!WRITE(*,*)"psi_leaf ", psi_leaf(ipts,ivm,icirc)
!!WRITE(*,*)"kroot ", kroot(icirc)
!!WRITE(*,*)"kstem ", kstem(icirc)
!!WRITE(*,*)"kleaf ", kleaf(icirc)
!!WRITE(*,*)"vx ", vx(ipts,ivm,icirc)
!!WRITE(*,*)"vr ", vr(ipts,ivm,icirc)
!!WRITE(*,*)"vl ", vl(ipts,ivm,icirc)
!               ! added by yitong yao to solve the problem of jump in psi in the
!               1st day of the year 
                !DO m=1,ncirc
                !       WRITE(part_str,'(I2)') m
                !        IF (m < 10) part_str(1:1) = '0'
                !        var_name = 'circ_class_n_'//part_str(1:LEN_TRIM(part_str))
                !        CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
            !&            circ_class_n(:,:,m), 'scatter', nbp_glo, index_g)
             !   ENDDO


                ! added by yitong yao Jan 30 18:00 
!! 
                gsh(ipts,ivm,icirc) = stomatal_conductance_hydro_f(gmax(ivm), light(ipts), klight, gpsi(ivm),psi_leaf(ipts,ivm,icirc),gpsi_50(ivm), gmin(ivm))
!!!WRITE(*,*)"gsh ", icirc,  gsh(icirc)
!
                !write(*,*) 'flag_flow 6'
                X(1)=psi_stem(ipts,ivm,icirc)
!! parameters for leaf
                PARS(1)=kmax_leaf(ivm);PARS(2)=P50_leaf(ivm);PARS(3)=a_leaf(ivm)
                PARS(4)=kstem(icirc);PARS(5)=cl(ivm);PARS(6)=psi_leaf(ipts,ivm,icirc)
                PARS(7)=psi_stem(ipts,ivm,icirc);PARS(8)=grav_potential(icirc);PARS(9)=gsh(ipts,ivm,icirc)
                PARS(10)=VPD(ipts);PARS(11)=timestep;PARS(12)=canopy_leaf_area(ipts,ivm,icirc)
!! parameters for stem
                PARS(13)=kmax_stem(ivm);PARS(14)=P50_stem(ivm);PARS(15)=a_stem(ivm)
                PARS(16)=kroot(icirc);PARS(17)=cxyl(ivm);PARS(18)=stem_volume(ipts,ivm,icirc)
!! parameters for root
                PARS(19)=kmax_root(ivm);PARS(20)=P50_root(ivm);PARS(21)=a_root(ivm)
                PARS(22)=cr(ivm);PARS(23)=psi_root(ipts,ivm,icirc);PARS(24)=root_volume(ipts,ivm,icirc)
                PARS(25)=phi_soilroot_circ(ipts,ivm,icirc);PARS(26)=vl(ipts,ivm,icirc)
                PARS(27)=0
!!!!!!!!!!!!!!print*,'IIIIIIIIII',PARS
                CALL HYBRD1(FCN1,N,X,M,PARS,FVEC,limit,INFO)
                  new_psi_leaf(icirc)=X(1)
                   IF (new_psi_leaf(icirc) .LT. minpsi) THEN 
                         new_psi_leaf(icirc)=minpsi
                   ENDIF
                  vdot_storage_leaf(ipts,ivm,icirc) = (cl(ivm)*(new_psi_leaf(icirc)-psi_leaf(ipts,ivm,icirc)))*canopy_leaf_area(ipts,ivm,icirc)
                ! write(*,*) 'flag_flow 7'
                 !write(*,*) 'vdot_storage_leaf_hybrd1',icirc,vdot_storage_leaf(ipts,ivm,icirc)
                 !write(*,*) 'psi_leaf_hybrd1',icirc,psi_leaf(ipts,ivm,icirc)
                 !write(*,*) 'new_psi_leaf_hybrd1',icirc,new_psi_leaf(icirc)
                 IF ((vdot_storage_leaf(ipts,ivm,icirc) .LE. 0)  .AND. (vdot_storage_leaf(ipts,ivm,icirc) .LE. -1*vl(ipts,ivm,icirc) )) THEN
!    print*,'FCN1_VL!!!!!!!!!!!!!!!!!!!!'
                    CALL HYBRD1(FCN1_VL,N,X,M,PARS,FVEC,limit,INFO)
                    new_psi_leaf(icirc)=X(1)
                    IF (new_psi_leaf(icirc) .LT. minpsi) THEN 
                        new_psi_leaf(icirc)=minpsi
                    ENDIF
                    vdot_storage_leaf(ipts,ivm,icirc) = (cl(ivm)*(new_psi_leaf(icirc)-psi_leaf(ipts,ivm,icirc)))*canopy_leaf_area(ipts,ivm,icirc)
                   ! write(*,*) 'new_psi_leaf_if_hybrd1',icirc,new_psi_leaf(icirc)
                   ! write(*,*) 'vdot_storage_leaf_if_hybrd1',icirc,vdot_storage_leaf(ipts,ivm,icirc)
                ENDIF
                ! added by yitong yao limit psi_leaf to -2.5 MPa here
                !IF (new_psi_leaf(icirc) .LT. (-1*2.5)) THEN
                !    new_psi_leaf(icirc) = -2.5
                   ! vdot_storage_leaf(ipts,ivm,icirc)=0

                !ENDIF
                ! added by yitong yao above lines 2020 April 19 20:05

                kupper(icirc) = kupper_f(kmax_leaf(ivm), P50_leaf(ivm), a_leaf(ivm),new_psi_leaf(icirc), kstem(icirc))
                Et(ipts,ivm,icirc)=gsh(ipts,ivm,icirc)*(VPD(ipts)/atm)*canopy_leaf_area(ipts,ivm,icirc)*timestep
                vdot_hydr_leaf(ipts,ivm,icirc) = (psi_stem(ipts,ivm,icirc) - new_psi_leaf(icirc) - grav_potential(icirc)/2)*kupper(icirc) *canopy_leaf_area(ipts,ivm,icirc)*timestep
!  write(*,*) "diff leaf", icirc,FVEC,INFO,X,vdot_storage_leaf(icirc),-1*vl(ipts,ivm,icirc)
!!!!!  write(*,*) "diff leaf", FVEC(:), FVEC(1:)
                optileaf(ipts,ivm,icirc)=INFO
                !write(*,*) 'flag_flow 8'
                X(1)=psi_root(ipts,ivm,icirc)
                PARS(27)=vdot_hydr_leaf(ipts,ivm,icirc)
                CALL HYBRD1(FCN2,N,X,M,PARS,FVEC,limit,INFO)
                new_psi_stem(icirc)=X(1)
                IF (vertical_limit .EQ. 1) THEN 
                 IF (new_psi_stem(icirc) .LT. new_psi_leaf(icirc)) THEN 
                            new_psi_stem(icirc) = new_psi_leaf(icirc)
                 ENDIF
                ENDIF
                vdot_storage_stem(ipts,ivm,icirc) = (cxyl(ivm)*(new_psi_stem(icirc) - psi_stem(ipts,ivm,icirc)))*stem_volume(ipts,ivm,icirc)*1000*1000/18
                !write(*,*) 'vdot_storage_stem_hybrd1',icirc,vdot_storage_stem(icirc)
                ! write(*,*) 'psi_stem_hybrd1',icirc,psi_stem(ipts,ivm,icirc)
                ! write(*,*) 'new_psi_stem_hybrd1',icirc,new_psi_stem(icirc)
                IF ((vdot_storage_stem(ipts,ivm,icirc) .LE. 0)  .AND. (vdot_storage_stem(ipts,ivm,icirc) .LE. -1*vl(ipts,ivm,icirc) )) THEN
!    print*,'FCN2_VL!!!!!!!!!!!!!!!!!!!!'
                    CALL HYBRD1(FCN2_VL,N,X,M,PARS,FVEC,limit,INFO)
                    new_psi_stem(icirc)=X(1)
                    IF (vertical_limit .EQ. 1) THEN 
                         IF (new_psi_stem(icirc) .LT. new_psi_leaf(icirc)) THEN
                         new_psi_stem(icirc)=new_psi_leaf(icirc) 
                         ENDIF
                    ENDIF
                    vdot_storage_stem(ipts,ivm,icirc) = (cxyl(ivm)*(new_psi_stem(icirc) - psi_stem(ipts,ivm,icirc)))*stem_volume(ipts,ivm,icirc)*1000*1000/18    
                   ! write(*,*) 'new_psi_stem_if_hybrd1',icirc,new_psi_stem(icirc)
                   ! write(*,*) 'vdot_storage_stem_if_hybrd1',icirc,vdot_storage_stem(icirc) 
                 ENDIF
                ! above added 
!!!!!!!!!!  !ktrunk(icirc)=1/((1/(2*kroot(icirc))) + (1/(2*kstem_f(kmax_stem(ivm), P50_stem(ivm), a_stem(ivm),new_psi_stem(icirc)))))
!!!!!!!!!!  !vdot_hydr_stem(icirc) = (psi_root(ipts,ivm,icirc) - new_psi_stem(icirc) - grav_potential(icirc)/2)*ktrunk(icirc)*canopy_leaf_area(icirc)*timestep
!  write(*,*) "diff stem", icirc,FVEC,INFO,X,vdot_storage_stem(icirc),-1*vl(ipts,ivm,icirc)
!!!!!!!!!!!optistem(ipts,ivm,icirc)=INFO
!
                vdot_hydr_leaf_vert(ipts,ivm,icirc) = (new_psi_stem(icirc) - new_psi_leaf(icirc) - grav_potential(icirc)/2)*kupper(icirc)* canopy_leaf_area(ipts,ivm,icirc)*timestep

                optistem(ipts,ivm,icirc)=INFO
                ! added by yitong yao 2020 April 19 21:00
                !IF (new_psi_stem(icirc) .LT. new_psi_leaf(icirc)) THEN 
                !   new_psi_stem(icirc) = new_psi_leaf(icirc)
                !   vdot_storage_stem(ipts,ivm,icirc) = (cxyl(ivm)*(new_psi_stem(icirc) - psi_stem(ipts,ivm,icirc)))*stem_volume(ipts,ivm,icirc)*1000*1000/18
                !ENDIF 
                ! above lines added by yitong yao 2020 April 19 20:59
                kstem(icirc)=kstem_f(kmax_stem(ivm), P50_stem(ivm), a_stem(ivm), new_psi_stem(icirc)) 
                ktrunk(icirc)=1/((1/(2*kroot(icirc))) + (1/(2*kstem(icirc))))
                vdot_hydr_stem(ipts,ivm,icirc) = (psi_root(ipts,ivm,icirc) - new_psi_stem(icirc) - grav_potential(icirc)/2)*ktrunk(icirc)&
            *canopy_leaf_area(ipts,ivm,icirc)*timestep
!
                X(1)=phi_soilroot_circ(ipts,ivm,icirc)
                PARS(27)=vdot_hydr_stem(ipts,ivm,icirc)
                CALL HYBRD1(FCN3,N,X,M,PARS,FVEC,limit,INFO)
                new_psi_root(icirc)=X(1) 

                IF (vertical_limit .EQ. 1) THEN 
                ! added by yitong yao 2020 April 19 21:07 
                 IF (new_psi_root(icirc) .LT. new_psi_stem(icirc))  THEN 
                     new_psi_root(icirc) = new_psi_stem(icirc)
                 ENDIF
                ENDIF
                ! added by yitong yao above lines 

!  write(*,*) "diff root", icirc, FVEC,INFO,X
!!!! Update water volume 
!!!!!!!!!!!!!!!!!!!!!!!vdot_storage_leaf(icirc) = (cl(ivm)*(new_psi_leaf(icirc) - psi_leaf(ipts,ivm,icirc)))*canopy_leaf_area(icirc)
                optiroot(ipts,ivm,icirc)=INFO
                !write(*,*) 'flag_flow 10'
                new_vl(icirc)=MAX(vl(ipts,ivm,icirc)+vdot_storage_leaf(ipts,ivm,icirc),zero)
!!!!!!!!!!!!!!!WRITE(*,*) 'vl ', vl(ipts,ivm,icirc), new_vl(icirc), vdot_storage_leaf(icirc)
!!!!!!!!!!!!!!!WRITE(*,*), 'vdot_storage_leaf test', cl(ivm),new_psi_leaf(icirc),psi_leaf(ipts,ivm,icirc),canopy_leaf_area(icirc)
!!!!!!!!!!!!!!!!vdot_storage_stem(icirc) = (cxyl(ivm)*(new_psi_stem(icirc) - psi_stem(ipts,ivm,icirc)))*stem_volume(icirc)*1000*1000/18
                new_vx(icirc)=MAX(vx(ipts,ivm,icirc)+vdot_storage_stem(ipts,ivm,icirc),zero)
!!!!!!!!!!!!!!WRITE(*,*) 'vx ', vx(ipts,ivm,icirc), new_vx(icirc), vdot_storage_stem(icirc)
!
                kroot(icirc)=kroot_f(kmax_root(ivm), P50_root(ivm), a_root(ivm),new_psi_root(icirc))
!!!!!!!!!!!!!!vdot_storage_root(icirc)=(phi_soilroot(ipts,ivm)-new_psi_root(icirc))*2*kroot(icirc)*canopy_leaf_area(icirc)*timestep
                vdot_storage_root(ipts,ivm,icirc)=(cr(ivm)*root_volume(ipts,ivm,icirc)*1000*1000/18)*(new_psi_root(icirc)-psi_root(ipts,ivm,icirc))
                !write(*,*) 'vdot_storage_root_hybrd1',icirc,vdot_storage_root(icirc)
                ! write(*,*) 'psi_root_hybrd1',icirc,psi_root(ipts,ivm,icirc)
                ! write(*,*) 'new_psi_root_hybrd1',icirc,new_psi_root(icirc)
                !write(*,*) 'flag_flow 11'
                new_vr(icirc)=MAX(vr(ipts,ivm,icirc)+vdot_storage_root(ipts,ivm,icirc),zero)
!!!!!!!!!WRITE(*,*) 'vr ', vr(ipts,ivm,icirc), new_vr(icirc), vdot_storage_root(icirc)
!!!WRITE(*,*), 'vdot_storage_root test',kroot(icirc), psi_soil(ivm), new_psi_root(icirc) 
!
!!! Set variable names for the next timestep
                psi_leaf(ipts,ivm,icirc)=new_psi_leaf(icirc)
                psi_stem(ipts,ivm,icirc)=new_psi_stem(icirc)
                psi_root(ipts,ivm,icirc)=new_psi_root(icirc)
!
!
!
                vl(ipts,ivm,icirc)=new_vl(icirc)
                vx(ipts,ivm,icirc)=new_vx(icirc)
                vr(ipts,ivm,icirc)=new_vr(icirc)
!
                stem_plc(ipts,ivm,icirc)=100 - 100*kstem(icirc)/kmax_stem(ivm)
                !write(*,*) 'stem_plc_hydrol',stem_plc(ipts,ivm,icirc)
!!
!!WRITE(*,*) 'test2 ', X(1)
!!WRITE(*,*) 'testoutput', PARS(30)
!!WRITE(*,*) 'stem_plc', kstem(icirc),stem_plc(ipts,ivm,icirc)
!!WRITE(*,*)"psi_root end tstep ", psi_root(ipts,ivm,icirc)
!!!WRITE(*,*)"psi_stem ", psi_stem(ipts,ivm,icirc)
!!WRITE(*,*)"psi_leaf ", psi_leaf(ipts,ivm,icirc)
!W!RITE(*,*)"kroot ", kroot(icirc)
!!WRITE(*,*)"kstem ", kstem(icirc)
!!WRITE(*,*)"kleaf ", kleaf(icirc)
!
                transpir_class(icirc)=gsh(ipts,ivm,icirc)*VPD(ipts)/atm*canopy_leaf_area(ipts,ivm,icirc)
                tzj_supply(ipts,ivm,icirc)=transpir_class(icirc)*circ_class_n(ipts,ivm,icirc)*dtradia*1.8E-5
               ! WRITE(*,*) "tzjRR circum ", icirc, " transpiration", transpir_class(icirc)
       
            ENDIF
           ! write(numout,*) 'gsh mmol/m^2/s^-1', gsh(ipts,ivm,icirc)
        ENDDO ! icirc ini


!        write(*,*) 'gsh mmol/m^2/s^-1', gsh(ipts,icirc)
!write(*,*) 'etzj mmol/s^-1', transpir_class(:)
!write(*,*) 'hickler ', circ_class_transpir_supply(:)

!!!!!!!!!!!!!transpir_tot =  SUM(transpir_class(:)* circ_class_n(ipts,ivm,:))*dtradia * 1.8E-5 
        transpir_tot(ipts,ivm) =  SUM(transpir_class(:)* circ_class_n(ipts,ivm,:))*dtradia*1.8E-5 
        !write(*,*) 'etzj3tot mm (kg/m^2 per dt-1)', transpir_tot(:,ivm)
        !write(*,*) 'dtradia yyt', dtradia
        !write(*,*) 'VPDyyt',VPD(ipts)
          IF (supply_flag .EQ. 1) THEN
             transpir_supply(ipts,ivm)=transpir_tot(ipts,ivm)
          ENDIF
!write(*,*) 'etzj3 mm (kg/m^2 per dt-1)', transpir_tot(:,ivm) 
!write(*,*) 'etzj2', tmp
!write(*,*) 'etzj3 mmol', transpir_tot
!write(*,*) 'etzj3 mmol/m^2 de sol', transpir_tot
!write(*,*) 'etzj3 mm (kg/m^2 per dt-1)', transpir_tot *1.8e-5

!write(*,*) 'hickler2 ', transpir_supply(:,:)

        ENDDO ! ivm for new hydraulic architecture
 
       !write(*,*) 'etzj3tot mm (kg/m^2 per dt-1)', transpir_tot(:,ivm)
     !ENDDO ! kjpindex

  !   IF (ldrestart_write) THEN
  !         DO icirc = 1,ncirc
  !            !write(numout,*) 'fail put  psi_stem',icirc
  !            !write(*,*) 'fail in put psi stem', icirc
  !            WRITE(part_str,'(I2)') icirc
  !            IF ( icirc < 10 ) part_str(1:1) = '0'
  !            var_name = 'psi_stem_'//part_str(1:LEN_TRIM(part_str))
  !            CALL restput_p(rest_id, var_name, nbp_glo,   nvm,1,kjit,psi_stem(:,:,icirc),'scatter',  nbp_glo, index_g)
   !        ENDDO

    !       DO icirc = 1,ncirc
    !          WRITE(part_str,'(I2)') icirc
    !          IF ( icirc < 10 ) part_str(1:1) = '0'
    !          var_name = 'psi_leaf_'//part_str(1:LEN_TRIM(part_str))
    !          CALL restput_p(rest_id, var_name, nbp_glo,   nvm,1,kjit,psi_leaf(:,:,icirc), 'scatter',  nbp_glo, index_g)
     !      ENDDO

      !     DO icirc = 1,ncirc
      !        WRITE(part_str,'(I2)') icirc
      !        IF ( icirc < 10 ) part_str(1:1) = '0'
      !        var_name = 'psi_root_'//part_str(1:LEN_TRIM(part_str))
      !        CALL restput_p(rest_id, var_name, nbp_glo,   nvm,1,kjit,psi_root(:,:,icirc),'scatter',  nbp_glo, index_g)
      !     ENDDO
     !ENDIF

 ENDIF !flag ok_joetzjer_hydro 


ENDDO ! kjpindexipts
IF (ok_joetzjer_hydro) THEN
IF (ldrestart_write) THEN
           DO icirc = 1,ncirc
              !write(numout,*) 'fail put  psi_stem',icirc
              !write(*,*) 'fail in put psi stem', icirc
              WRITE(part_str,'(I2)') icirc
              IF ( icirc < 10 ) part_str(1:1) = '0'
              var_name = 'psi_stem_'//part_str(1:LEN_TRIM(part_str))
              CALL restput_p(rest_id, var_name, nbp_glo, nvm,1,kjit,psi_stem(:,:,icirc),'scatter',  nbp_glo, index_g)
           ENDDO

           DO icirc = 1,ncirc
              WRITE(part_str,'(I2)') icirc
              IF ( icirc < 10 ) part_str(1:1) = '0'
              var_name = 'psi_leaf_'//part_str(1:LEN_TRIM(part_str))
              CALL restput_p(rest_id, var_name, nbp_glo,nvm,1,kjit,psi_leaf(:,:,icirc), 'scatter',  nbp_glo, index_g)
           ENDDO

           DO icirc = 1,ncirc
              WRITE(part_str,'(I2)') icirc
              IF ( icirc < 10 ) part_str(1:1) = '0'
              var_name = 'psi_root_'//part_str(1:LEN_TRIM(part_str))
              CALL restput_p(rest_id, var_name, nbp_glo,nvm,1,kjit,psi_root(:,:,icirc),'scatter',  nbp_glo, index_g)
           ENDDO
     ENDIF
ENDIF

 !---TEMP---
 IF (ld_hydrolarch) THEN
    !WRITE(numout,*) 'transpir_supply, ', transpir_supply(:,:)
    !WRITE(numout,*) 'vir_transpir_supply, ', vir_transpir_supply(:,:)
 ENDIF
 !----------


IF ( ALLOCATED (nvan)) DEALLOCATE (nvan)
IF ( ALLOCATED (avan)) DEALLOCATE (avan)
IF ( ALLOCATED (mcr)) DEALLOCATE (mcr)
IF ( ALLOCATED (mcs)) DEALLOCATE (mcs)

!! ############################################################################
!! Writing variables in Sechiba Outputs tzj
     !write(numout,*) 'sechibahydrol::gsh=', gsh(1,2)
     !write(numout,*) 'sechibahydrol::phi-soilroot=', phi_soilroot
     CALL histwrite_p(hist_id, 'phi_soilroot', kjit, phi_soilroot, kjpindex*nvm, indexveg)
     CALL histwrite_p(hist_id, 'transpir_tot_tzj', kjit, transpir_tot, kjpindex*nvm, indexveg)
     !CALL histwrite_p(hist_id, 'gsh', kjit, gsh, kjpindex*nvm, indexveg)
     
     VPD_tzj=VPD
     CALL histwrite_p(hist_id, 'VPD_tzj', kjit, VPD_tzj, kjpindex, indexveg)
     !write(numout,*) 'vpd_right'
  DO jst=1,nstm
        !  var_name= phi_soil_1" ... "phi_soil_3"
     WRITE (var_name,"('phi_soil_',i1)") jst
     CALL histwrite_p(hist_id, trim(var_name), kjit,phi_soil(:,:,jst),kjpindex*nslm, indexlayer)
  ENDDO
     !write(numout,*) 'right 2'
 IF (rsoilroot) THEN

!DO jst=1,nstm
        ! var_name= phi_soil_1" ... "phi_soil_3"
     jst=2
     WRITE (var_name,"('res_soil_',i1)") jst
     CALL histwrite_p(hist_id, trim(var_name), kjit,res_soil(:,:,jst),kjpindex*nslm, indexlayer)

 !    WRITE (var_name,"('ksave_',i1)") jst
 !    CALL histwrite_p(hist_id, trim(var_name), kjit, ksave(:,:,jst),kjpindex*nslm, indexlayer)
!
     jst=2
     WRITE (var_name,"('e_max_',i1)") jst
     CALL histwrite_p(hist_id, trim(var_name), kjit, e_max(:,:,jst),kjpindex*nslm, indexlayer)
!
     CALL histwrite_p(hist_id, 'e_frac_2', kjit, e_frac(:,:,2),kjpindex*nslm, indexlayer)
 END IF 

IF (ok_joetzjer_hydro) THEN 
  DO icirc = 1,tmp_ncirc

    WRITE (var_name,"('PHI_soilroot_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, phi_soilroot_circ(:,:,icirc),kjpindex*nvm,indexveg)
    
    WRITE (var_name,"('PSLeaf_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, psi_leaf(:,:,icirc),kjpindex*nvm,indexveg)
!
    WRITE (var_name,"('tzj_gsh_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, gsh(:,:,icirc),kjpindex*nvm,indexveg)
        
    WRITE (var_name,"('tzj_supply_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, tzj_supply(:,:,icirc),kjpindex*nvm,indexveg)

    WRITE (var_name,"('PSStem_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, psi_stem(:,:,icirc),kjpindex*nvm,indexveg)
!
    WRITE (var_name,"('PSRoot_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, psi_root(:,:,icirc),kjpindex*nvm,indexveg)
!
    WRITE (var_name,"('stemPLC_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, stem_plc(:,:,icirc),kjpindex*nvm,indexveg)
!
    WRITE (var_name,"('vl_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, vl(:,:,icirc),kjpindex*nvm,indexveg)
!
    WRITE (var_name,"('vx_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, vx(:,:,icirc),kjpindex*nvm,indexveg)
!
    WRITE (var_name,"('vr_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, vr(:,:,icirc),kjpindex*nvm,indexveg)
!
    WRITE (var_name,"('optileaf_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, optileaf(:,:,icirc),kjpindex*nvm,indexveg)
! 
    WRITE (var_name,"('v_storage_leaf_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, vdot_storage_leaf(:,:,icirc),kjpindex*nvm,indexveg)
    
    WRITE (var_name,"('v_hydr_leaf_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, vdot_hydr_leaf(:,:,icirc),kjpindex*nvm,indexveg)
   
    WRITE (var_name,"('v_hydr_leaf_vert_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, vdot_hydr_leaf_vert(:,:,icirc),kjpindex*nvm,indexveg)

 
    WRITE (var_name,"('v_storage_stem_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, vdot_storage_stem(:,:,icirc),kjpindex*nvm,indexveg)

    WRITE (var_name,"('v_hydr_stem_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit,vdot_hydr_stem(:,:,icirc),kjpindex*nvm,indexveg)
    
    WRITE (var_name,"('v_storage_root_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, vdot_storage_root(:,:,icirc),kjpindex*nvm,indexveg)


    WRITE (var_name,"('tzj_Et_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, Et(:,:,icirc),kjpindex*nvm,indexveg)

    WRITE (var_name,"('tzj_stem_volume_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, stem_volume(:,:,icirc),kjpindex*nvm,indexveg)

    WRITE (var_name,"('tzj_root_volume_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, root_volume(:,:,icirc),kjpindex*nvm,indexveg)

    WRITE (var_name,"('tzj_canopy_LAI_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, canopy_leaf_area(:,:,icirc),kjpindex*nvm,indexveg)


    WRITE (var_name,"('optistem_',i3.3)") icirc
    CALL histwrite_p(hist_id, var_name, kjit, optistem(:,:,icirc),kjpindex*nvm,indexveg)
!
    !WRITE (var_name,"('optiroot_',i3.3)") icirc
    !CALL histwrite_p(hist_id, var_name, kjit, optiroot(:,:,icirc),kjpindex*nvm,indexveg)
        !write(numout,*) 'write right in loop'
    ENDDO
ENDIF
    !write(numout,*) 'write right'


!! ############################################################################


END SUBROUTINE hydrol_arch

SUBROUTINE FCN1(N,X,M,PARS,FVEC,INFO)
  USE pft_parameters
  IMPLICIT NONE
  INTEGER(i_std) :: N,M,INFO
  REAL(r_std)    :: X(N), FVEC(N), PARS(M)
  REAL(r_std)    :: inew_psi_leaf, &
                    ikmax_leaf, iP50_leaf, ia_leaf, ikstem, &
                    icl, ipsi_leaf, ipsi_stem, igrav_potential, &
                    igsh, iVPD, timestep, icanopy_leaf_area, &
                    ivl, &
                    Et, ikupper, vdot_storage_leaf, vdot_hydr_leaf                  
                      
  REAL(r_std)    :: atm = 101.3            ! atmospheric pressure, kPa  
  inew_psi_leaf=X(1)
  ! parameters for leaf
  ikmax_leaf=PARS(1);iP50_leaf=PARS(2);ia_leaf=PARS(3)
  ikstem=PARS(4);icl=PARS(5);ipsi_leaf=PARS(6)
  ipsi_stem=PARS(7);igrav_potential=PARS(8);igsh=PARS(9)
  iVPD=PARS(10);timestep=PARS(11);icanopy_leaf_area=PARS(12)
  ! parameters for stem
 ! ikmax_stem=PARS(13); iP50_stem=PARS(14);  ia_stem=PARS(15)
 ! ikroot=PARS(16);  icxyl=PARS(17);  istem_volume=PARS(18)
  ! parameters for root
 ! ikmax_root=PARS(19); iP50_root=PARS(20);  ia_root=PARS(21)
 ! icr=PARS(22);  ipsi_root=PARS(23);  iroot_volume=PARS(24)
 ! ipsi_soil=PARS(25)
 ! ivl=PARS(26)
  ! parameters optimized before this loop
  ! none here, but some for stem and root


  ! leaf 
  ikupper = kupper_f(ikmax_leaf, iP50_leaf, ia_leaf, inew_psi_leaf, ikstem)
  Et=igsh*(iVPD/atm)*icanopy_leaf_area*timestep
  vdot_storage_leaf = (icl*(inew_psi_leaf - ipsi_leaf))*icanopy_leaf_area
  vdot_hydr_leaf = (ipsi_stem - inew_psi_leaf - igrav_potential/2)*ikupper&
                      *icanopy_leaf_area*timestep
!  print*, 'wyl check1.0~~~~~~~~~~',ikmax_leaf,iP50_leaf,ia_leaf,ikstem
!  print*, 'wyl check1.1~~~~~~~~~~',ikupper,Et,vdot_storage_leaf,vdot_hydr_leaf
!  print*, 'wyl check1.2~~~~~~~~~~',ivl,icl,inew_psi_leaf,ipsi_leaf
!  print*, 'wyl check1.3~~~~~~~~~~',ipsi_stem,igrav_potential,icanopy_leaf_area,timestep
!  IF ((vdot_storage_leaf .LT. 0)  .AND. (vdot_storage_leaf .LT. -1*ivl )) THEN
!    vdot_storage_leaf = -1*ivl
!  ENDIF
  FVEC(1) = Et-(vdot_hydr_leaf-vdot_storage_leaf)
!  print*, 'wyl check1.4~~~~~~~~~~',FVEC(1)
END SUBROUTINE FCN1

SUBROUTINE FCN1_VL(N,X,M,PARS,FVEC,INFO)
  USE pft_parameters
  IMPLICIT NONE
  INTEGER(i_std) :: N,M,INFO
  REAL(r_std)    :: X(N), FVEC(N), PARS(M)
  REAL(r_std)    :: inew_psi_leaf, &
                    ikmax_leaf, iP50_leaf, ia_leaf, ikstem, &
                    icl, ipsi_leaf, ipsi_stem, igrav_potential, &
                    igsh, iVPD, timestep, icanopy_leaf_area, &
                    ivl, &
                    Et, ikupper, vdot_storage_leaf, vdot_hydr_leaf
                      
  REAL(r_std)    :: atm = 101.3            ! atmospheric pressure, kPa  
  inew_psi_leaf=X(1)
  ! parameters for leaf
  ikmax_leaf=PARS(1);iP50_leaf=PARS(2);ia_leaf=PARS(3)
  ikstem=PARS(4);icl=PARS(5);ipsi_leaf=PARS(6)
  ipsi_stem=PARS(7);igrav_potential=PARS(8);igsh=PARS(9)
  iVPD=PARS(10);timestep=PARS(11);icanopy_leaf_area=PARS(12)
  ! parameters for stem
 ! ikmax_stem=PARS(13);iP50_stem=PARS(14);ia_stem=PARS(15)
 ! ikroot=PARS(16);icxyl=PARS(17);istem_volume=PARS(18)
  ! parameters for root
 ! ikmax_root=PARS(19);iP50_root=PARS(20);ia_root=PARS(21)
 ! icr=PARS(22);ipsi_root=PARS(23);iroot_volume=PARS(24)
 ! ipsi_soil=PARS(25)
  ivl=PARS(26)
  ! parameters optimized before this loop
  ! none here, but some for stem and root

  ! leaf 
  ikupper = kupper_f(ikmax_leaf, iP50_leaf, ia_leaf, inew_psi_leaf, ikstem)
  Et=igsh*(iVPD/atm)*icanopy_leaf_area*timestep
  vdot_storage_leaf = -1*ivl
  vdot_hydr_leaf = (ipsi_stem - inew_psi_leaf - igrav_potential/2)*ikupper&
                      *icanopy_leaf_area*timestep
  FVEC(1) = Et-(vdot_hydr_leaf-vdot_storage_leaf)
END SUBROUTINE FCN1_VL



SUBROUTINE FCN1_VL0(N,X,M,PARS,FVEC,INFO)
  USE pft_parameters
  IMPLICIT NONE
  INTEGER(i_std) :: N,M,INFO
  REAL(r_std)    :: X(N), FVEC(N), PARS(M)
  REAL(r_std)    :: inew_psi_leaf, &
                    ikmax_leaf, iP50_leaf, ia_leaf, ikstem, &
                    icl, ipsi_leaf, ipsi_stem, igrav_potential, &
                    igsh, iVPD, timestep, icanopy_leaf_area, &
                    ivl, &
                    Et, ikupper, vdot_storage_leaf, vdot_hydr_leaf
                      
  REAL(r_std)    :: atm = 101.3            ! atmospheric pressure, kPa  
  inew_psi_leaf=X(1)
  ! parameters for leaf
  ikmax_leaf=PARS(1);iP50_leaf=PARS(2);ia_leaf=PARS(3)
  ikstem=PARS(4);icl=PARS(5);ipsi_leaf=PARS(6)
  ipsi_stem=PARS(7);igrav_potential=PARS(8);igsh=PARS(9)
  iVPD=PARS(10);timestep=PARS(11);icanopy_leaf_area=PARS(12)
  ! parameters for stem
 ! ikmax_stem=PARS(13);iP50_stem=PARS(14);ia_stem=PARS(15)
 ! ikroot=PARS(16);icxyl=PARS(17);istem_volume=PARS(18)
  ! parameters for root
 ! ikmax_root=PARS(19);iP50_root=PARS(20);ia_root=PARS(21)
 ! icr=PARS(22);ipsi_root=PARS(23);iroot_volume=PARS(24)
 ! ipsi_soil=PARS(25)
  ivl=PARS(26)
  ! parameters optimized before this loop
  ! none here, but some for stem and root

  ! leaf 
  ikupper = kupper_f(ikmax_leaf, iP50_leaf, ia_leaf, inew_psi_leaf, ikstem)
  Et=igsh*(iVPD/atm)*icanopy_leaf_area*timestep
  !vdot_storage_leaf = -1*ivl
  vdot_storage_leaf = 0
  vdot_hydr_leaf = (ipsi_stem - inew_psi_leaf - igrav_potential/2)*ikupper&
                      *icanopy_leaf_area*timestep
  FVEC(1) = Et-(vdot_hydr_leaf-vdot_storage_leaf)
END SUBROUTINE FCN1_VL0

SUBROUTINE FCN2(N,X,M,PARS,FVEC,INFO)
  USE pft_parameters
  IMPLICIT NONE
  INTEGER(i_std) :: N,M,INFO
  REAL(r_std)    :: X(N), FVEC(N), PARS(M)
  REAL(r_std)    :: inew_psi_stem, &
                    ipsi_stem, igrav_potential, &
                    timestep, icanopy_leaf_area, &
                    ikmax_stem, iP50_stem, ia_stem, &
                    ikroot, icxyl, istem_volume, &
                    ipsi_root, ivl, &
                    iktrunk, vdot_storage_stem, vdot_hydr_stem, &
                    inew_kstem,ivdot_hydr_up
                      
  REAL(r_std)    :: atm = 101.3            ! atmospheric pressure, kPa  
  inew_psi_stem=X(1)
  ! parameters for leaf
!  ikmax_leaf=PARS(1);iP50_leaf=PARS(2);ia_leaf=PARS(3)
!  ikstem=PARS(4);icl=PARS(5);ipsi_leaf=PARS(6)
  ipsi_stem=PARS(7);igrav_potential=PARS(8)
!  igsh=PARS(9)
!  iVPD=PARS(10)
  timestep=PARS(11);icanopy_leaf_area=PARS(12)
  ! parameters for stem
  ikmax_stem=PARS(13);iP50_stem=PARS(14);ia_stem=PARS(15)
  ikroot=PARS(16);icxyl=PARS(17);istem_volume=PARS(18)
  ! parameters for root
!  ikmax_root=PARS(19);iP50_root=PARS(20);ia_root=PARS(21)
!  icr=PARS(22);
  ipsi_root=PARS(23)
!  iroot_volume=PARS(24)
!  ipsi_soil=PARS(25)
  ivl=PARS(26)
  ! parameters optimized before this loop
  ivdot_hydr_up=PARS(27)

  ! stem
  inew_kstem=kstem_f(ikmax_stem, iP50_stem, ia_stem, inew_psi_stem) 
  iktrunk=1/((1/(2*ikroot)) + (1/(2*inew_kstem)))

  vdot_storage_stem = (icxyl*(inew_psi_stem - ipsi_stem))*istem_volume*1000*1000/18
  vdot_hydr_stem = (ipsi_root - inew_psi_stem - igrav_potential/2)*iktrunk&
                      *icanopy_leaf_area*timestep
!  print*,'wyl check1.0',ikmax_stem,iP50_stem,ia_stem,inew_psi_stem
!  print*,'wyl check1.1',inew_kstem,ikroot,iktrunk
!  print*,'wyl check1.2',icxyl,ipsi_stem,istem_volume
!  print*,'wyl check1.3',ipsi_root,igrav_potential,icanopy_leaf_area
!  print*,'wyl check1.4',vdot_storage_stem,vdot_hydr_stem,ivl,ivdot_hydr_up
!  IF ((vdot_storage_stem .LT. 0)  .AND. (vdot_storage_stem .LT. -1*ivl)) THEN
!    vdot_storage_stem = -1*ivl
!  ENDIF
  FVEC(1) = ivdot_hydr_up-(vdot_hydr_stem-vdot_storage_stem)
!  print*,'wyl check1.5',FVEC
END SUBROUTINE FCN2

SUBROUTINE FCN2_VL(N,X,M,PARS,FVEC,INFO)
  USE pft_parameters
  IMPLICIT NONE
  INTEGER(i_std) :: N,M,INFO
  REAL(r_std)    :: X(N), FVEC(N), PARS(M)
  REAL(r_std)    :: inew_psi_stem, &
                    ipsi_stem, igrav_potential, &
                    timestep, icanopy_leaf_area, &
                    ikmax_stem, iP50_stem, ia_stem, &
                    ikroot, icxyl, istem_volume, &
                    ipsi_root, ivl, &
                    iktrunk, vdot_storage_stem, vdot_hydr_stem, &
                    inew_kstem,ivdot_hydr_up
                      
  REAL(r_std)    :: atm = 101.3            ! atmospheric pressure, kPa  
  inew_psi_stem=X(1)
  ! parameters for leaf
!  ikmax_leaf=PARS(1);iP50_leaf=PARS(2);ia_leaf=PARS(3)
!  ikstem=PARS(4);icl=PARS(5);ipsi_leaf=PARS(6)
  ipsi_stem=PARS(7);igrav_potential=PARS(8)
!  igsh=PARS(9)
!  iVPD=PARS(10)
  timestep=PARS(11);icanopy_leaf_area=PARS(12)
  ! parameters for stem
  ikmax_stem=PARS(13);iP50_stem=PARS(14);ia_stem=PARS(15)
  ikroot=PARS(16);icxyl=PARS(17);istem_volume=PARS(18)
  ! parameters for root
!  ikmax_root=PARS(19);iP50_root=PARS(20);ia_root=PARS(21)
!  icr=PARS(22);
  ipsi_root=PARS(23)
!  iroot_volume=PARS(24)
!  ipsi_soil=PARS(25)
  ivl=PARS(26)
  ! parameters optimized before this loop
  ivdot_hydr_up=PARS(27)

  ! stem
  inew_kstem=kstem_f(ikmax_stem, iP50_stem, ia_stem, inew_psi_stem) 
  iktrunk=1/((1/(2*ikroot)) + (1/(2*inew_kstem)))

  vdot_storage_stem = -1*ivl
  vdot_hydr_stem = (ipsi_root - inew_psi_stem - igrav_potential/2)*iktrunk&
                      *icanopy_leaf_area*timestep
  FVEC(1) = ivdot_hydr_up-(vdot_hydr_stem-vdot_storage_stem)
END SUBROUTINE FCN2_VL

SUBROUTINE FCN3(N,X,M,PARS,FVEC,INFO)
  USE pft_parameters
  IMPLICIT NONE
  INTEGER(i_std) :: N,M,INFO
  REAL(r_std)    :: X(N), FVEC(N), PARS(M)
  REAL(r_std)    :: inew_psi_root, &
                    timestep, icanopy_leaf_area,&
                    ikmax_root, iP50_root, ia_root, &
                    icr, ipsi_root, iroot_volume, &
                    inew_kroot, vdot_storage_root, &
                    vdot_hydr_root, ipsi_soil, ivdot_hydr_up
                      
  REAL(r_std)    :: atm = 101.3            ! atmospheric pressure, kPa  
  inew_psi_root=X(1)
  ! parameters for leaf
!  ikmax_leaf=PARS(1);iP50_leaf=PARS(2);ia_leaf=PARS(3)
!  ikstem=PARS(4);icl=PARS(5);ipsi_leaf=PARS(6)
!  ipsi_stem=PARS(7);igrav_potential=PARS(8);igsh=PARS(9)
!  iVPD=PARS(10)
  timestep=PARS(11);icanopy_leaf_area=PARS(12)
!  ! parameters for stem
!  ikmax_stem=PARS(13);iP50_stem=PARS(14);ia_stem=PARS(15)
!  ikroot=PARS(16);icxyl=PARS(17);istem_volume=PARS(18)
  ! parameters for root
  ikmax_root=PARS(19);iP50_root=PARS(20);ia_root=PARS(21)
  icr=PARS(22);ipsi_root=PARS(23);iroot_volume=PARS(24)
  ipsi_soil=PARS(25)
!  ivl=PARS(26)
  ! parameters optimized before this loop
  ivdot_hydr_up=PARS(27)

 ! root
  inew_kroot= kroot_f(ikmax_root, iP50_root, ia_root, inew_psi_root)
  vdot_hydr_root=(ipsi_soil-inew_psi_root)*2*inew_kroot&
                      *icanopy_leaf_area*timestep
  vdot_storage_root=(icr*iroot_volume*1000*1000/18)*(inew_psi_root-ipsi_root)
!  print*,'wyl check1.0',ikmax_root,iP50_root,ia_root,inew_psi_root
!  print*,'wyl check1.1',inew_kroot,ipsi_soil,icanopy_leaf_area
!  print*,'wyl check1.2',icr,iroot_volume
!  print*,'wyl check1.3',ivdot_hydr_up,vdot_storage_root,vdot_hydr_root
  FVEC(1) = ivdot_hydr_up-(vdot_hydr_root-vdot_storage_root)
!  print*,'wyl check1.4',FVEC
END SUBROUTINE FCN3
  

!! ==============================================================================================================================
!! SUBROUTINE   : jdiffuco_trans_co2
!!
!>\BRIEF        This subroutine computes carbon assimilation and stomatal 
!! conductance, following respectively Farqhuar et al. (1980) and Ball et al. (1987).
!!
!! DESCRIPTION  :\n
!! *** General:\n 
!! The equations are different depending on the photosynthesis mode (C3 versus C4).\n 
!! Assimilation and conductance are computed over 20 levels of LAI and then 
!! integrated at the canopy level.\n 
!! This routine also computes partial beta coefficient: transpiration for each 
!! type of vegetation.\n
!! There is a main loop on the PFTs, then inner loops on the points where 
!! assimilation has to be calculated.\n
!! This subroutine is called by diffuco_main only if photosynthesis is activated
!! for sechiba (flag STOMATE_OK_CO2=TRUE), otherwise diffuco_trans is called.\n
!! This subroutine is called at each sechiba time step by sechiba_main.\n
!! *** Details:
!! - Integration at the canopy level\n
!! \latexonly
!! \input{diffuco_trans_co2_1.1.tex}
!! \endlatexonly
!! - Light''s extinction \n
!! The available light follows a simple Beer extinction law. 
!! The extinction coefficients (ext_coef) are PFT-dependant constants and are defined in constant_co2.f90.\n
!! \latexonly
!! \input{diffuco_trans_co2_1.2.tex}
!! \endlatexonly
!! - Estimation of relative humidity of air (for calculation of the stomatal conductance)\n
!! \latexonly
!! \input{diffuco_trans_co2_1.3.tex}
!! \endlatexonly
!! - Calculation of the water limitation factor\n
!! \latexonly
!! \input{diffuco_trans_co2_2.1.tex}
!! \endlatexonly
!! - Calculation of temperature dependent parameters for C4 plants\n
!! \latexonly
!! \input{diffuco_trans_co2_2.2.tex}
!! \endlatexonly
!! - Calculation of temperature dependent parameters for C3 plants\n
!! \latexonly
!! \input{diffuco_trans_co2_2.3.tex}
!! \endlatexonly
!! - Vmax scaling\n 
!! Vmax is scaled into the canopy due to reduction of nitrogen 
!! (Johnson and Thornley,1984).\n
!! \latexonly
!! \input{diffuco_trans_co2_2.4.1.tex}
!! \endlatexonly
!! - Assimilation for C4 plants (Collatz et al., 1992)\n
!! \latexonly
!! \input{diffuco_trans_co2_2.4.2.tex}
!! \endlatexonly         
!! - Assimilation for C3 plants (Farqhuar et al., 1980)\n
!! \latexonly
!! \input{diffuco_trans_co2_2.4.3.tex}
!! \endlatexonly
!! - Estimation of the stomatal conductance (Ball et al., 1987)\n
!! \latexonly
!! \input{diffuco_trans_co2_2.4.4.tex}
!! \endlatexonly
!!
!! RECENT CHANGE(S): N. de Noblet          2006/06
!!                - addition of q2m and t2m as input parameters for the 
!!                calculation of Rveget
!!                - introduction of vbeta23
!!
!! MAIN OUTPUT VARIABLE(S): beta coefficients, resistances, CO2 intercellular 
!! concentration
!!
!! REFERENCE(S) :
!! - Ball, J., T. Woodrow, and J. Berry (1987), A model predicting stomatal 
!! conductance and its contribution to the control of photosynthesis under 
!! different environmental conditions, Prog. Photosynthesis, 4, 221– 224.
!! - Collatz, G., M. Ribas-Carbo, and J. Berry (1992), Coupled photosynthesis 
!! stomatal conductance model for leaves of C4 plants, Aust. J. Plant Physiol.,
!! 19, 519–538.
!! - Farquhar, G., S. von Caemmener, and J. Berry (1980), A biochemical model of 
!! photosynthesis CO2 fixation in leaves of C3 species, Planta, 149, 78–90.
!! - Johnson, I. R., and J. Thornley (1984), A model of instantaneous and daily
!! canopy photosynthesis, J Theor. Biol., 107, 531 545
!! - McMurtrie, R.E., Rook, D.A. and Kelliher, F.M., 1990. Modelling the yield of Pinus radiata on a
!! site limited by water and nitrogen. For. Ecol. Manage., 30: 381-413
!! - Yin, X. and Struik, P. C., 2009. C3 and C4 photosynthesis models: An overview from the perspective
!!   of crop modelling, NJAS - Wageningen Journal of Life Sciences, 57, 27--38.
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

SUBROUTINE jdiffuco_trans_co2 (kjpindex, dtradia, swdown, temp_sol, pb, qsurf, q2m, t2m, &
                                temp_growth, rau, u, v, q_cdrag, vegstress, &
                                assim_param, Ca, &
                                veget_max, lai, qsintveg, qsintmax, vbeta3, vbeta3pot, rveget, rstruct, &
                                cimean, gsmean, gpp, vbeta23, Isotrop_Abs_Tot_p,&
                                Isotrop_Tran_Tot_p, lai_per_level, new_leaf_ci, &
                                hydrol_flag2, hydrol_flag3, gs_distribution, &
                                gs_diffuco_output, james_netcdf_flag, gstot_component, gstot_frac, warnings, veget, biomass)

    !
    !! 0. Variable and parameter declaration
    !

    !
    !! 0.1 Input variables
    !
    INTEGER(i_std), INTENT(in)                               :: kjpindex         !! Domain size (unitless)
    REAL(r_std), INTENT (in)                                 :: dtradia          !! Time step (s)
    REAL(r_std),DIMENSION (:), INTENT (in)                   :: swdown           !! Downwelling short wave flux 
                                                                                 !! @tex ($W m^{-2}$) @endtex 
    REAL(r_std),DIMENSION (:), INTENT (in)                   :: temp_sol         !! Skin temperature (K)
    REAL(r_std),DIMENSION (:), INTENT (in)                   :: pb               !! Lowest level pressure (hPa)
    REAL(r_std),DIMENSION (:), INTENT (in)                   :: qsurf            !! Near surface specific humidity 
                                                                                 !! @tex ($kg kg^{-1}$) @endtex
! N. de Noblet - 2006/06 - addition of q2m and t2m
    REAL(r_std),DIMENSION (kjpindex), INTENT (in)            :: q2m              !! 2m specific humidity 
                                                                                 !! @tex ($kg kg^{-1}$) @endtex
! In off-line mode q2m and qair are the same.
! In off-line mode t2m and temp_air are the same.
    REAL(r_std),DIMENSION (kjpindex), INTENT (in)            :: t2m              !! 2m air temperature (K)
! N. de Noblet - 2006/06 - addition of q2m and t2m
    REAL(r_std),DIMENSION (kjpindex), INTENT (in)            :: temp_growth      !! Growth temperature (°C) - Is equal to t2m_month
    REAL(r_std),DIMENSION (kjpindex), INTENT (in)            :: rau              !! air density @tex ($kg m^{-3}$) @endtex
    REAL(r_std),DIMENSION (kjpindex), INTENT (in)            :: u                !! Lowest level wind speed 
                                                                                 !! @tex ($m s^{-1}$) @endtex
    REAL(r_std),DIMENSION (kjpindex), INTENT (in)            :: v                !! Lowest level wind speed 
                                                                                 !! @tex ($m s^{-1}$) @endtex
    REAL(r_std),DIMENSION (kjpindex), INTENT (in)            :: q_cdrag          !! Surface drag 
                                                                                 !! @tex ($m s^{-1}$) @endtex
    REAL(r_std),DIMENSION (:,:,:), INTENT (in)               :: assim_param      !! min+max+opt temps (K), vcmax, vjmax for 
                                                                                 !! photosynthesis 
                                                                                 !! @tex ($\mu mol m^{-2} s^{-1}$) @endtex 
    REAL(r_std),DIMENSION (kjpindex), INTENT (in)            :: Ca               !! CO2 concentration inside the canopy
                                                                                 !! @tex ($\mu mol mol^{-1}$) @endtex
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (in)        :: vegstress        !! Soil moisture stress (0-1,unitless) 
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (in)        :: veget_max        !! Maximum vegetation fraction of each PFT inside 
                                                                                 !! the grid box (0-1, unitless) 
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (in)        :: veget            !! Fraction of vegetation type (-)

    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (in)        :: lai              !! Leaf area index @tex ($m^2 m^{-2}$) @endtex
                                                                                 !! @tex ($m s^{-1}$) @endtex
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (in)        :: qsintveg         !! Water on vegetation due to interception 
                                                                                 !! @tex ($kg m^{-2}$) @endtex
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (in)        :: qsintmax         !! Maximum water on vegetation
                                                                                 !! @tex ($kg m^{-2}$) @endtex
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (in)        :: vbeta23          !! Beta for fraction of wetted foliage that will 
                                                                                 !! transpire (unitless) 
    REAL(r_std),DIMENSION (:,:,:), INTENT (in)               :: Isotrop_Abs_Tot_p !! Absorbed radiation per level for photosynthesis
    REAL(r_std),DIMENSION (:,:,:), INTENT (in)               :: Isotrop_Tran_Tot_p !! Absorbed radiation per level for photosynthesis
    REAL(r_std), DIMENSION(:,:,:), INTENT(in)                :: lai_per_level    !! This is the LAI per vertical level
                                                                                 !! @tex $(m^{2} m^{-2})$
                                                                                     
    REAL(r_std), DIMENSION(:,:,:,:), INTENT(in)              :: biomass          !! Stand level biomass @tex $(gC m^{-2})$ @endtex

    LOGICAL, DIMENSION (kjpindex), INTENT (in)               :: hydrol_flag2     !! flag that 'trips' the alternative energy budget for each grid square
    LOGICAL, DIMENSION (kjpindex, nvm), INTENT (in)          :: hydrol_flag3     !! flag that 'trips' the alternative energy budget for each grid square
    REAL(r_Std),DIMENSION (kjpindex,nvm,nlevels_tot), INTENT (in)        :: gs_distribution
    REAL(r_std),DIMENSION (kjpindex,nvm,nlevels_tot), INTENT (in)        :: gs_diffuco_output
    REAL(r_Std),DIMENSION (kjpindex,nvm,nlevels_tot), INTENT (in)        :: gstot_component
    REAL(r_Std),DIMENSION (kjpindex,nvm,nlevels_tot), INTENT (in)        :: gstot_frac    


    LOGICAL, INTENT(in)                                     :: james_netcdf_flag !! Flag that controls the netCDF output routine


    !
    !! 0.2 Output variables
    
    !! 0.3 Modified variables
    ! JR these are all defined as inout variables as we skip over PFTs and grid squares for which the hydrol stress constraint
    !       does not apply. We can to use the values the values previously calculated (within diffuco) for these cases.
    !
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (inout)       :: vbeta3         !! Beta for Transpiration (unitless)

    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (inout)       :: vbeta3pot      !! Beta for Potential Transpiration
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (inout)       :: rveget         !! stomatal resistance of vegetation 
                                                                                 !! @tex ($s m^{-1}$) @endtex
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (inout)       :: rstruct        !! structural resistance @tex ($s m^{-1}$) @endtex
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (inout)       :: cimean         !! mean intercellular CO2 concentration 
                                                                                 !! @tex ($\mu mol mol^{-1}$) @endtex
    REAL(r_std),DIMENSION (kjpindex,nvm), INTENT (inout)       :: gsmean         !! mean stomatal conductance to CO2 (umol m-2 s-1)
    REAL(r_Std),DIMENSION (kjpindex,nvm), INTENT (inout)       :: gpp            !! Assimilation ((gC m^{-2} s^{-1}), total area)
    REAL(r_std),DIMENSION(kjpindex,nvm,nwarns), INTENT(inout)  :: warnings       !! A warning counter
    !
    !
    REAL(r_std), DIMENSION (kjpindex,nvm,nlai)  :: new_leaf_ci                   !! intercellular CO2 concentration (ppm)
    !
    !! 0.4 Local variables
    !
    REAL(r_std), DIMENSION(kjpindex, nvm)                                :: coupled_lai
    REAL(r_std), DIMENSION(kjpindex, nvm)                                :: total_lai
      
    REAL(r_Std),DIMENSION (kjpindex,nvm,nlevels_tot)                     :: gs_output
    REAL(r_Std),DIMENSION (kjpindex,nvm,nlevels_tot)                     :: gstot_output
    REAL(r_std),DIMENSION (kjpindex,nvm,nlevels_tot)                     :: assimi_store

    REAL(r_std), DIMENSION (kjpindex)      :: jwind                              !! Wind module (m s^{-1})

    REAL(r_std),DIMENSION (kjpindex,nvm)  :: sum_rveget_rstruct

    REAL(r_std),DIMENSION (kjpindex,nvm)  :: vcmax                               !! maximum rate of carboxylation 
                                                                                 !! @tex ($\mu mol CO2 m^{-2} s^{-1}$) @endtex
    INTEGER(i_std)                        :: ji, jv, ilev, limit_photo            !! indices (unitless)
    !REAL(r_std), DIMENSION(kjpindex)      :: leaf_ci_lowest                      !! intercellular CO2 concentration at the lowest 
    !                                                                             !! LAI level
    !                                                                             !! @tex ($\mu mol mol^{-1}$) @endtex
    REAL(r_std), DIMENSION(kjpindex)      :: zqsvegrap                           !! relative water quantity in the water 
                                                                                 !! interception reservoir (0-1,unitless) 
    REAL(r_std)                           :: speed                               !! wind speed @tex ($m s^{-1}$) @endtex
    ! Assimilation
    LOGICAL, DIMENSION(kjpindex)          :: assimilate                          !! where assimilation is to be calculated 
                                                                                 !! (unitless) 
    INTEGER(i_std)                        :: nia,inia,nina,inina,iainia          !! counter/indices (unitless)
    INTEGER(i_std), DIMENSION(kjpindex)   :: index_assi,index_non_assi           !! indices (unitless)
    REAL(r_std), DIMENSION(kjpindex)      :: vc2                                 !! rate of carboxylation (at a specific LAI level) 
                                                                                 !! @tex ($\mu mol CO2 m^{-2} s^{-1}$) @endtex 
    REAL(r_std), DIMENSION(kjpindex)      :: vj2                                 !! rate of Rubisco regeneration (at a specific LAI 
                                                                                 !! level) @tex ($\mu mol e- m^{-2} s^{-1}$) @endtex 
    REAL(r_std), DIMENSION(kjpindex)      :: assimi                              !! assimilation (at a specific LAI level) 
                                                                                 !! @tex ($\mu mol m^{-2} s^{-1}$) @endtex
                                                                                 !! (temporary variables)
    REAL(r_std), DIMENSION(kjpindex)      :: gstop                               !! stomatal conductance to H2O at topmost level 
                                                                                 !! @tex ($m s^{-1}$) @endtex
    REAL(r_std), DIMENSION(kjpindex)      :: gs                                  !! stomatal conductance to CO2 
                                                                                 !! @tex ($\mol m^{-2} s^{-1}$) @endtex


    REAL(r_std), DIMENSION(kjpindex)      :: gamma_star                          !! CO2 compensation point (ppm)
                                                                                 !! @tex ($\mu mol mol^{-1}$) @endtex

    REAL(r_std), DIMENSION(kjpindex)      :: air_relhum                          !! air relative humidity at 2m 
                                                                                 !! @tex ($kg kg^{-1}$) @endtex
    REAL(r_std), DIMENSION(kjpindex)      :: VPD                                 !! Vapor Pressure Deficit (kPa)
    REAL(r_std), DIMENSION(kjpindex)      :: water_lim                           !! water limitation factor (0-1,unitless)

    REAL(r_std), DIMENSION(kjpindex)      :: gstot                               !! total stomatal conductance to H2O
                                                                                 !! Final unit is
                                                                                 !! @tex ($m s^{-1}$) @endtex
    REAL(r_std), DIMENSION(kjpindex)      :: assimtot                            !! total assimilation 
                                                                                 !! @tex ($\mu mol CO2 m^{-2} s^{-1}$) @endtex
    REAL(r_std), DIMENSION(kjpindex)      :: Rdtot                               !! Total Day respiration (respiratory CO2 release other than by photorespiration) (mumol CO2 m−2 s−1) 
    REAL(r_std), DIMENSION(kjpindex)      :: gs_top                              !! leaf stomatal conductance to H2O across all top levels
                                                                                 !! @tex ($\mol H2O m^{-2} s^{-1}$) @endtex
    REAL(r_std), DIMENSION(kjpindex)      :: qsatt                               !! surface saturated humidity at 2m (??) 
                                                                                 !! @tex ($g g^{-1}$) @endtex
    REAL(r_std), DIMENSION(kjpindex)      :: T_Vcmax                             !! Temperature dependance of Vcmax (unitless)
    REAL(r_std), DIMENSION(kjpindex)      :: S_Vcmax_acclim_temp                 !! Entropy term for Vcmax 
                                                                                 !! accounting for acclimation to temperature (J K-1 mol-1)
    REAL(r_std), DIMENSION(kjpindex)      :: T_Jmax                              !! Temperature dependance of Jmax
    REAL(r_std), DIMENSION(kjpindex)      :: S_Jmax_acclim_temp                  !! Entropy term for Jmax 
                                                                                 !! accounting for acclimation to temperature (J K-1 mol-1)
    REAL(r_std), DIMENSION(kjpindex)      :: T_Rd                                !! Temperature dependance of Rd (unitless)
    REAL(r_std), DIMENSION(kjpindex)      :: T_Kmc                               !! Temperature dependance of KmC (unitless)
    REAL(r_std), DIMENSION(kjpindex)      :: T_KmO                               !! Temperature dependance of KmO (unitless)
    REAL(r_std), DIMENSION(kjpindex)      :: T_gamma_star                        !! Temperature dependance of gamma_star (unitless)    
    REAL(r_std), DIMENSION(kjpindex)      :: vc                                  !! Maximum rate of Rubisco activity-limited carboxylation (mumol CO2 m−2 s−1)
    REAL(r_std), DIMENSION(kjpindex)      :: vj                                  !! Maximum rate of e- transport under saturated light (mumol CO2 m−2 s−1)
    REAL(r_std), DIMENSION(kjpindex)      :: Rd                                  !! Day respiration (respiratory CO2 release other than by photorespiration) (mumol CO2 m−2 s−1)
    REAL(r_std), DIMENSION(kjpindex)      :: Kmc                                 !! Michaelis–Menten constant of Rubisco for CO2 (mubar)
    REAL(r_std), DIMENSION(kjpindex)      :: KmO                                 !! Michaelis–Menten constant of Rubisco for O2 (mubar)
    REAL(r_std), DIMENSION(kjpindex)      :: gb                                  !! Boundary-layer conductance (mol m−2 s−1 bar−1)
    REAL(r_std), DIMENSION(kjpindex)      :: fvpd                                !! Factor for describing the effect of leaf-to-air vapour difference on gs (-)
    REAL(r_std), DIMENSION(kjpindex)      :: low_gamma_star                      !! Half of the reciprocal of Sc/o (bar bar-1)
    REAL(r_std)                           :: N_Vcmax                             !! Nitrogen level dependance of Vcmacx and Jmax 
    REAL(r_std)                           :: fcyc                                !! Fraction of electrons at PSI that follow cyclic transport around PSI (-)
    REAL(r_std)                           :: z                                   !! A lumped parameter (see Yin et al. 2009) ( mol mol-1)                          
    REAL(r_std)                           :: Rm                                  !! Day respiration in the mesophyll (umol CO2 m−2 s−1)
    REAL(r_std)                           :: Cs_star                             !! Cs -based CO2 compensation point in the absence of Rd (ubar)
    REAL(r_std), DIMENSION(kjpindex)      :: Iabs                                !! Photon flux density absorbed by leaf photosynthetic pigments (umol photon m−2 s−1)
    REAL(r_std), DIMENSION(kjpindex)      :: Jmax                                !! Maximum value of J under saturated light (umol e− m−2 s−1)
    REAL(r_std), DIMENSION(kjpindex)      :: JJ                                  !! Rate of e− transport (umol e− m−2 s−1)
    REAL(r_std)                           :: J2                                  !! Rate of all e− transport through PSII (umol e− m−2 s−1)
    REAL(r_std)                           :: VpJ2                                !! e− transport-limited PEP carboxylation rate (umol CO2 m−2 s−1)
    REAL(r_std)                           :: A_1, A_3                            !! Lowest First and third roots of the analytical solution for a general 
                                                                                 !! cubic equation (see Appendix A of Yin et al. 2009) (umol CO2 m−2 s−1)
    REAL(r_std)                           :: A_1_tmp, A_3_tmp                    !! Temporary First and third roots of the analytical solution for a general 
                                                                                 !! cubic equation (see Appendix A of Yin et al. 2009) (umol CO2 m−2 s−1)
    REAL(r_std)                           :: Obs                                 !! Bundle-sheath oxygen partial pressure (ubar)
    REAL(r_std)                           :: Cc                                  !! Chloroplast CO2 partial pressure (ubar)
    REAL(r_std)                           :: ci_star                             !! Ci -based CO2 compensation point in the absence of Rd (ubar)        
    REAL(r_std)                           :: a,b,c,d,m,f,j,g,h,i,l,p,q,r         !! Variables used for solving the cubic equation (see Yin et al. (2009))
    REAL(r_std)                           :: QQ,UU,PSI,x1,x2,x3                  !! Variables used for solving the cubic equation (see Yin et al. (2009))

    REAL(r_std),DIMENSION (kjpindex,nvm)  :: lai_total                           !! total LAI for column in question
                                        
    REAL(r_std)                           :: cresist                             !! coefficient for resistances (??)
    REAL(r_std)                           :: lai_min                             !! mininum lai to calculate photosynthesis       
                                                                                 !! coefficient for resistances (??)

    LOGICAL,DIMENSION(kjpindex,nlevels_tot)  :: top_level                        !! A flag to see if a given level is considered
                                                                                 !! a "top" level or not.  Must be done this way
                                                                                 !! because there could be several "top" levels.
    REAL(r_std)                           :: totlai_top                          !! The sum of the LAI in all the levels that we
                                                                                 !! declare as the "top".
    INTEGER(i_std)                        :: lev_count                           !! How many levels we have already taken for
                                                                                 !! the "top"
    INTEGER                               :: jij

! @defgroup Photosynthesis Photosynthesis
! @{   
    ! 1. Preliminary calculations\n
    REAL(r_std),DIMENSION (kjpindex,nvm)  :: rveget_min                          !! Minimal Surface resistance of vegetation
    REAL(r_std),DIMENSION (kjpindex,nvm,nlevels_tot)     &
                                          :: light_tran_to_level                 !! Cumulative amount of light transmitted
                                                                                 !! to a given level
    LOGICAL,DIMENSION (kjpindex)          :: lskip                               !! A flag to indicate we've hit an unusual
                                                                                 !! case were we may have numerical instability.
    INTEGER :: ipts
    LOGICAL :: llight
    LOGICAL :: llai
    INTEGER,SAVE :: istep=0
!_ ================================================================================================================================


    ! JR 211013 define wind speed (this is defined in full in the diffuco module, but not here, so need to replicate it)
    jwind(:) = SQRT (u(:)*u(:) + v(:)*v(:))
    gs_output = 0.0d0
    gstot_output = 0.0d0
    lai_total = 0.0d0
    assimi = 0.0d0
    assimi_store = zero
    !
    DO ji=1,kjpindex
        DO jv = 1, nvm
            DO ilev=1,nlevels_tot
                lai_total(ji,jv) = lai_total(ji,jv) + lai_per_level(ji,jv,ilev)   !! total LAI for column in question
            END DO ! ilev = 1, nlevels_tot
            !IF (test_grid == 1 .AND. jv ==test_pft) THEN
            !   WRITE(numout, '(A20, ES20.4)') 'GET limited Vbeta3:', vbeta3(ji, jv)
            !ENDIF       
        END DO ! jv = 1, nvm
    END DO ! ji = 1, klpindex
    !
    ! 1. Photosynthesis parameters
    !
    vcmax(:,:) = assim_param(:,:,ivcmax)
    !
    ! @addtogroup Photosynthesis
    ! @{   
    !
    ! 1.2 Estimate relative humidity of air (for calculation of the stomatal conductance).\n
    !! \latexonly
    !! \input{jdiffuco_trans_co2_1.3.tex}
    !! \endlatexonly
    ! @}
    !
    ! N. de Noblet - 2006/06 - We use q2m/t2m instead of qair.
    !    CALL qsatcalc (kjpindex, temp_air, pb, qsatt)
    !    air_relhum(:) = &
    !      ( qair(:) * pb(:) / (0.622+qair(:)*0.378) ) / &
    !      ( qsatt(:)*pb(:) / (0.622+qsatt(:)*0.378 ) )
    ! @codeinc

    ! WRITE(*,*) '181113a test, pre call to qsatcalc sechiba_hydrol_arch line 858; temp_sol is: ', temp_sol

    CALL qsatcalc (kjpindex, temp_sol, pb, qsatt)
    air_relhum(:) = &
      ( qsurf(:) * pb(:) / (Tetens_1+qsurf(:)* Tetens_2) ) / &
      ( qsatt(:)*pb(:) / (Tetens_1+qsatt(:)*Tetens_2 ) )


    VPD(:) = ( qsatt(:)*pb(:) / (Tetens_1+qsatt(:)*Tetens_2 ) ) &
         - ( qsurf(:) * pb(:) / (Tetens_1+qsurf(:)* Tetens_2) )
    ! VPD is needed in kPa
    ! We limit the impact of VPD in the range of [0:6] kPa
    ! This seems to be the typical range of values
    ! that the vapor pressure difference can take, although
    ! there is a paper by Mott and Parkhurst, Plant, Cell & Environment,
    ! Vol. 14, pp. 509--519 (1991) which gives a value of 15 kPa.
    VPD(:) = MAX(zero,MIN(VPD(:)/10.,6.))
   ! VPD(:) = VPD(:)*1.038+0.132
   
    ! VPD(:) = VPD(:)*1.038291 + 0.1315685
    VPD(:) = VPD(:)*vpd_k1+vpd_b1
    ! write(*,*) 'VPDyyt',VPD(:)
    ! @endcodeinc
    ! N. de Noblet - 2006/06 
    !
    !
    ! 2. beta coefficient for vegetation transpiration
    !
    rstruct(:,1) = rstruct_const(1)
    rveget(:,:) = undef_sechiba
    rveget_min(:,:) = undef_sechiba
    !
 
    ! JR 051113 need to preserve the value of vbeta3 modified by supply term constraint
    ! in addition other values of vbeta3 are passed back from the earlier call to this
    ! routine in sechiba, so no need to initialise again. It is an (inout) variable in
    ! this version of the routine.
    ! vbeta3(:,:) = zero

    vbeta3pot(:,:) = zero
    gsmean(:,:) = zero
    gpp(:,:) = zero
    light_tran_to_level(:,:,:)=un
    !
    cimean(:,1) = Ca(:)
    !
    ! @addtogroup Photosynthesis
    ! @{   
    ! 2. Loop over vegetation types\n
    ! @} 
    !
    DO jv = 2,nvm
      !
      ! @addtogroup Photosynthesis
      ! @{   
      !
      ! 2.1 Initializations\n
      !! \latexonly
      !! \input{diffuco_trans_co2_2.1.tex}
      !! \endlatexonly
      ! @}      
      !
      ! beta coefficient for vegetation transpiration
      !
      rstruct(:,jv) = rstruct_const(jv)
      cimean(:,jv) = Ca(:)
      !
      !! mask that contains points where there is photosynthesis
      !! For the sake of vectorisation [DISPENSABLE], computations are done only for convenient points.
      !! nia is the number of points where the assimilation is calculated and nina the number of points where photosynthesis is not
      !! calculated (based on criteria on minimum or maximum values on LAI, vegetation fraction, shortwave incoming radiation, 
      !! temperature and relative humidity).
      !! For the points where assimilation is not calculated, variables are initialized to specific values. 
      !! The assimilate(kjpindex) array contains the logical value (TRUE/FALSE) relative to this photosynthesis calculation.
      !! The index_assi(kjpindex) array indexes the nia points with assimilation, whereas the index_no_assi(kjpindex) array indexes
      !! the nina points with no assimilation.
      !          
      ! set minimum lai value to test if photosynthesis should be calculated
      ! 0.0001 is abitrary
      ! could be externalised 
      lai_min = 0.0001
      !
      nia=0
      nina=0
      index_assi=0
      index_non_assi=0
      !
      !      
      DO ji=1,kjpindex
         !
         ! This is tricky.  We need a certain amount of LAI to have photosynthesis.
         ! However, we divide our canopy up into certain levels, so even if we
         ! have a total amount that is sufficient, there might not be enough
         ! in any particular layer.  So we check each layer to see if there
         ! is one that has enough to give a non-zero photosynthesis.  In
         ! the worst-case scenario (small LAI in every other level), this becomes 
         ! our top level for the gs calculation.  If gs_top_level is zero below,
         ! we have a divide by zero issue.
         llai=.FALSE.
         DO ilev=1,nlevels_tot
            IF(lai_per_level(ji,jv,ilev) .GT. lai_min) llai=.TRUE.
         ENDDO

         IF ( llai .AND. &
              ( veget_max(ji,jv) .GT. min_sechiba ) ) THEN
            
            ! Here we need to do something different than in the previous model.
            ! We explicitly need to check for absorbed light.  This occurs
            ! because our albedo in the two stream model is a function
            ! of the solar angle.  If the sun has set, we have no
            ! light, and therefore we cannot have photosynthesis.
            llight=.FALSE.
            DO ilev=1,nlevels_tot
               IF(Isotrop_Abs_Tot_p(ji,jv,ilev) .GT. min_sechiba) llight=.TRUE.
            ENDDO
            IF ( ( swdown(ji) .GT. min_sechiba )   .AND. &
                 ( temp_growth(ji) .GT. tphoto_min(jv) ) .AND. &
                 llight .AND. &
                 ( temp_growth(ji) .LT. tphoto_max(jv) )) THEN
               !
               assimilate(ji) = .TRUE.
               nia=nia+1
               index_assi(nia)=ji
               !
            ELSE
               !
               assimilate(ji) = .FALSE.
               nina=nina+1
               index_non_assi(nina)=ji
               !
            ENDIF
         ELSE
            !
            assimilate(ji) = .FALSE.
            nina=nina+1
            index_non_assi(nina)=ji
            !
         ENDIF
        ! 
      ENDDO
      !

      IF(ld_photo .AND. jv == test_pft)THEN
         !WRITE(numout,*) 'index_non_assi(:): ',index_non_assi(:)
         !WRITE(numout,*) 'index_assi(:): ',index_assi(:)
         !WRITE(numout,*) 'nia: ',nia
      ENDIF


      top_level(:,:)=.FALSE.
      gstot(:) = zero
      assimtot(:) = zero
      Rdtot(:)=zero
      gs_top(:) = zero
      lskip(:)=.FALSE.
      !
      zqsvegrap(:) = zero
      WHERE (qsintmax(:,jv) .GT. min_sechiba)
         !! relative water quantity in the water interception reservoir
         zqsvegrap(:) = MAX(zero, qsintveg(:,jv) / qsintmax(:,jv))
      ENDWHERE
      !
      !! Calculates the water limitation factor.
      !!Not used when hydrol_arch is used, can be deleted
      WHERE ( assimilate(:) )
         ! water_lim(:) = MAX( min_sechiba, MIN( vegstress(:,jv)/0.5, un ))
         water_lim(:) = un
      ELSEWHERE
         water_lim(:) = zero
      ENDWHERE

      ! give a default value of ci for all pixel that do not assimilate
      DO ilev=1,nlevels_tot
         DO inina=1,nina
            new_leaf_ci(index_non_assi(inina),jv,ilev) = Ca(index_non_assi(inina)) 
         ENDDO
      ENDDO
      !
      !
      ! Here is the calculation of assimilation and stomatal conductance
      ! based on the work of Farquahr, von Caemmerer and Berry (FvCB model) 
      ! as described in Yin et al. 2009
      ! Yin et al. developed a extended version of the FvCB model for C4 plants
      ! and proposed an analytical solution for both photosynthesis pathways (C3 and C4)
      ! Photosynthetic parameters used are those reported in Yin et al. 
      ! Except For Vcmax25, relationships between Vcmax25 and Jmax25 for which we use 
      ! Medlyn et al. (2002) and Kattge & Knorr (2007)
      ! Because these 2 references do not consider mesophyll conductance, we neglect this term
      ! in the formulations developed by Yin et al. 
      ! Consequently, gm (the mesophyll conductance) tends to the infinite
      ! This is of importance because as stated by Kattge & Knorr and Medlyn et al.,
      ! values of Vcmax and Jmax derived with different model parametrizations are not 
      ! directly comparable and the published values of Vcmax and Jmax had to be standardized
      ! to one consistent formulation and parametrization

      ! See eq. 6 of Yin et al. (2009)
      ! Parametrization of Medlyn et al. (2002) - from Bernacchi et al. (2001)
      T_KmC(:)        = Arrhenius(kjpindex,temp_sol,298.,E_KmC(jv))
      T_KmO(:)        = Arrhenius(kjpindex,temp_sol,298.,E_KmO(jv))
      T_gamma_star(:) = Arrhenius(kjpindex,temp_sol,298.,E_gamma_star(jv))


      ! Parametrization of Yin et al. (2009) - from Bernacchi et al. (2001)
      T_Rd(:)         = Arrhenius(kjpindex,temp_sol,298.,E_Rd(jv))


      ! For C3 plants, we assume that the Entropy term for Vcmax and Jmax 
      ! acclimates to temperature as shown by Kattge & Knorr (2007) - Eq. 9 and 10
      ! and that Jmax and Vcmax respond to temperature following a modified Arrhenius function
      ! (with a decrease of these parameters for high temperature) as in Medlyn et al. (2002) 
      ! and Kattge & Knorr (2007).
      ! In Yin et al. (2009), temperature dependance to Vcmax is based only on a Arrhenius function
      ! Concerning this apparent unconsistency, have a look to the section 'Limitation of 
      ! Photosynthesis by gm' of Bernacchi (2002) that may provide an explanation

      ! Growth temperature tested by Kattge & Knorr range from 11 to 35°C
      ! So, we limit the relationship between these lower and upper limits
      S_Jmax_acclim_temp(:) = aSJ(jv) + bSJ(jv) * MAX(11., MIN(temp_growth(:),35.))      
      T_Jmax(:)  = Arrhenius_modified(kjpindex,temp_sol,298.,E_Jmax(jv),D_Jmax(jv),S_Jmax_acclim_temp)

      S_Vcmax_acclim_temp(:) = aSV(jv) + bSV(jv) * MAX(11., MIN(temp_growth(:),35.))   
      T_Vcmax(:) = Arrhenius_modified(kjpindex,temp_sol,298.,E_Vcmax(jv),D_Vcmax(jv),S_Vcmax_acclim_temp)
      !       
      vc(:) = vcmax(:,jv) * T_Vcmax(:)
      ! As shown by Kattge & Knorr (2007), we make use
      ! of Jmax25/Vcmax25 ratio (rJV) that acclimates to temperature for C3 plants
      ! rJV is written as a function of the growth temperature
      ! rJV = arJV + brJV * T_month 
      ! See eq. 10 of Kattge & Knorr (2007)
      ! and Table 3 for Values of arJV anf brJV 
      ! Growth temperature is monthly temperature (expressed in °C) - See first paragraph of
      ! section Methods/Data of Kattge & Knorr
      vj(:) = ( arJV(jv) + brJV(jv) *  MAX(11., MIN(temp_growth(:),35.)) ) * vcmax(:,jv) * T_Jmax(:)
      !
      ! @endcodeinc
      !
      KmC(:)=KmC25(jv)*T_KmC(:)
      KmO(:)=KmO25(jv)*T_KmO(:)
      gamma_star(:) = gamma_star25(jv)*T_gamma_star(:)
      ! low_gamma_star is defined by Yin et al. (2009)
      ! as the half of the reciprocal of Sco - See Table 2
      ! We derive its value from Equation 7 of Yin et al. (2009)
      ! assuming a constant O2 concentration (Oi)
      low_gamma_star(:) = gamma_star(:)/Oi
      ! VPD expressed in kPa
     ! fvpd(:) = 1. / ( 1. / (a1(jv) - b1(jv) * VPD(:)) - 1. ) 
      ! * water_lim(:)
      !IF (VPD(:) .LT. 0.1) THEN
      !   CALL getin_p('newA1',a1)
      !   CALL getin_p('newB1',b1)
      !   fvpd(:) = 1. / ( 1. / (a1(jv) - b1(jv) * VPD(:)) - 1. )
      !ELSE
      !   CALL getin_p('A1',a1)
      !   CALL getin_p('B1',b1)
      !   fvpd(:) = 1. / ( 1. / (a1(jv) - b1(jv) * VPD(:)) - 1. )
     ! ENDIF
! change a1 and b1 values according to vpd  yitong Yao
      DO ji=1,kjpindex
         IF (VPD(ji) .LT. 0.35) THEN
                 CALL getin_p('newA1',a1)
                 CALL getin_p('newB1',b1)
                 fvpd(ji) = 1. / ( 1. / (a1(jv) - b1(jv) * VPD(ji)) - 1. )
         ELSE
                 CALL getin_p('A1',a1)
                 CALL getin_p('B1',b1)
                 fvpd(ji) = 1. / ( 1. / (a1(jv) - b1(jv) * VPD(ji)) - 1. )
         ENDIF
         !write(*,*) 'vpdvpd_yyt1',VPD(ji)
         !write(*,*) 'fvpd_yyt1',fvpd(ji)
      ENDDO

      !write(*,*) 'vpdvpd',VPD(:)
      !write(*,*) 'cons_a1',a1(jv)
      !write(*,*) 'cons_b1',b1(jv)

        !???
      !leaf boundary layer conductance
      gb(:) = (1.0_r_std /25.0_r_std)/(22.4_r_std *temp_sol(:)/273._r_std/1000._r_std) 
      !???
      !
      ! @addtogroup Photosynthesis
      ! @{   
      !
      ! 2.4 Loop over LAI levels to estimate assimilation and conductance\n
      ! @}           
      !




      IF (nia .GT. 0) THEN
         gridloop1: DO inia=1,nia
            !
            iainia=index_assi(inia)

            ! JR we 'cycle' the LAI loop for those PFTs not subject to the hydrol stress for the grid square in question

            IF (hydrol_flag3(iainia, jv)) THEN
               !nothing              
            ELSE
               CYCLE gridloop1
            END IF !(hydrol_flag3)


            ! JR the first part of the routine is a copy of diffuco_trans_co2, so that we can 
            ! calculate values for fvpd, assimtot, Rdtot, new_leaf_ci and ci_star
            !
            ! Find the top layer that still contains lai.  We have also
            ! added a check in here to make sure this layer has absorbed
            ! light.  If there is no absorbed light, we will not calculate
            ! stomatal conductance for the top level, which means gstop
            ! will be zero later and we'll crash when we divide by it.
            ! Include a warning so we know how often this happens.
            ! Include a warning so we know how often this happens.
            ! The old system of chosing just one top level caused some bad results
            ! in the transpir, evidently due to the calculation of vbeta3 being
            ! too low due to too low of LAI in the top level.  Therefore, we are
            ! now going to take several top levels in an effort to make sure
            ! we have enough LAI.  We aim for an arbitrary amount of 0.1 or
            ! the top three levels.  This has not been rigoursly tested, but it
            ! is theoretically justified by the fact that if the LAI of the top
            ! level is very low, other leaves will be getting a lot of sun and
            ! well-exposed to the atmosphere, and therefore contribute equal
            ! to the resistence of the vegetation.
            totlai_top=zero
            lev_count=0
            !   
            DO ilev=nlevels_tot, 1, -1
               IF(lai_per_level(iainia,jv,ilev) .GT. lai_min)THEN
                  IF(Isotrop_Abs_Tot_p(iainia,jv,ilev) .GT. min_sechiba)THEN
                     IF(totlai_top .LT. lai_top(jv) .AND. lev_count .LT. nlev_top)THEN
                        lev_count=lev_count+1
                        top_level(iainia,ilev)=.TRUE.
                        totlai_top=totlai_top+lai_per_level(iainia,jv,ilev)
                     ELSE
                        ! We have enough levels now.
                        !WRITE(numout,*) 'Top levels ',totlai_top,lev_count
                        EXIT
                     ENDIF
                  ELSE
                     IF(ld_warn)THEN
                        WRITE(numout,*) 'WARNING: Found a level with LAI, ' // &
                             'but no absorbed light.'
                        WRITE(numout,*) 'WARNING: iainia,jv,ilev, ',iainia,jv,ilev
                        WRITE(numout,*) 'WARNING: Isotrop_Abs_Tot_p(iainia,jv,ilev),' //&
                             'lai_per_level(iainia,jv,ilev), ',iainia,jv,ilev
                     ENDIF
                  ENDIF
               ENDIF
            ENDDO
            IF(totlai_top .LT. min_sechiba)THEN
               ! There seem to be some fringe cases where this happens, usually
               ! at sunrise or sunset with low LAI levels.  Instead of stopping
               ! here, I'm going to issue a warning.  If this case happens,
               ! we produce no GPP, but we're not going to crash.  We need to
               ! be careful in one of the loops below, since a stomatal 
               ! conductance of zero will cause a crash.
                IF(ld_warn)THEN
                   WRITE(numout,*) 'WARNING: Did not find a level with LAI in diffuco!'
                   WRITE(numout,*) 'WARNING: iainia,ivm: ',iainia,jv
                ENDIF
               assimtot(iainia) = zero
               Rdtot(iainia) = zero
               gstot(iainia) = zero
               lskip(iainia)=.TRUE.
               CYCLE gridloop1
            ENDIF

            ! We need to know how much is transmitted to this level
            ! from the top of the canopy, since this aboslute number
            ! is what is actually used in the photosyntheis.  Right now
            ! Isotrop_Tran_Tot_p and Isotropic_Abs_Tot_p are the 
            ! relative quantities transmitted through and absorbed
            ! by the layer.
            DO ilev = nlevels_tot-1,1,-1
               light_tran_to_level(iainia,jv,ilev)=light_tran_to_level(iainia,jv,ilev+1)*Isotrop_Tran_Tot_p(iainia,jv,ilev+1)
            ENDDO
            IF(ld_photo .AND. jv == test_pft .AND. iainia == test_grid)THEN
               WRITE(numout,*) 'Absolute transmitted light to each level',jv,iainia
               DO ilev = nlevels_tot,1,-1
                  WRITE(numout,*) ilev,light_tran_to_level(iainia,jv,ilev)
               ENDDO
            ENDIF

            DO ilev = 1, nlevels_tot
               
               IF (Isotrop_Abs_Tot_p(iainia,jv,ilev) .GT. min_sechiba) THEN

                  IF(lai_per_level(iainia,jv,ilev) .LE. min_sechiba)THEN
                     ! This is not necessarily a problem.  LAI is updated in slowproc, while
                     ! absorbed light is updated in condveg, which is called after diffuco.
                     ! So we might be one timestep off.  It generally should be at night,
                     ! though, so there is no absorbed light.  If this persists, that
                     ! is a real problem.
                     IF(ld_warn)THEN
                        WRITE(numout,*) 'WARNING: We have absorbed light but no LAI ' // &
                             'in this level. Skipping.'
                        WRITE(numout,'(A,3I8)') 'WARNING: iainia,jv,ilev: ',iainia,jv,ilev
                        WRITE(numout,'(A,2F20.10)') 'WARNING: Isotrop_Abs_Tot_p(iainia,jv,ilev), ' // &
                             'lai_per_level(ji,jv,ilev): ',&
                             Isotrop_Abs_Tot_p(iainia,jv,ilev), lai_per_level(iainia,jv,ilev)
                     ENDIF
                     CYCLE
                  ENDIF
                  !
                  ! nitrogen is scaled according to the transmitted light
                  ! before the caclulation was (1 - exp(lai)) we replaced
                  ! it by the transmitted light calculated by the 2stream
                  ! model, maybe ( un - Isotrop_Tran_Tot_p(iainia,jv,ilev) )
                  ! could be replaced by the directly calculated absorbed
                  ! light Isotrop_Abs_Tot_p(iainia,jv,ilev).
                  ! Notice that light in the old code was the cumulative light transmitted to
                  ! the layer, while Isotrop_Tran_Tot_p is the relative light transmitted
                  ! through the layer.  Therefore, we use a different variable.
                  !
!                     N_Vcmax = ( un - .7_r_std * ( un - Isotrop_Tran_Tot_p(iainia,jv,ilev) ) )
                  N_Vcmax = ( un - .7_r_std * ( un - light_tran_to_level(iainia,jv,ilev) ) )
                  !
                 ! IF (control%ok_hydrol_arch) THEN
                 
                  !*********CHECK: only photsynthesis when day***************
                 ! WHERE (assimilate(:))
                 !    vc2(iainia) = vc(iainia) * N_Vcmax
                 !    vj2(iainia) = vj(iainia) * N_Vcmax 
                     ! see Comment in legend of Fig. 6 of Yin et al. (2009)
                     ! Rd25 is assumed to equal 0.01 Vcmax25 
                  !   Rd(iainia) = vcmax(iainia,jv) * N_Vcmax * 0.01 * T_Rd(iainia)
                  !ELSEWHERE
                  !   vc2(iainia) = zero
                  !   vj2(iainia) = zero
                  !   Rd(iainia) = zero
                  !ENDWHERE

                 ! ELSE
                     
                     vc2(iainia) = vc(iainia) * N_Vcmax 
                     vj2(iainia) = vj(iainia) * N_Vcmax 
                     
                     ! see Comment in legend of Fig. 6 of Yin et al. (2009)
                     ! Rd25 is assumed to equal 0.01 Vcmax25 
                     Rd(iainia) = vcmax(iainia,jv) * N_Vcmax * 0.01 * T_Rd(iainia)
                 
                  !ENDIF

                  !+++++ CHECK +++++
                  IF(jv == test_pft .AND. iainia == test_grid .AND. ld_photo)THEN
                     WRITE(numout,*) 'Iabs1: ',iainia,jv,ilev
                     WRITE(numout,'(A,10F20.10)') 'Iabs2: ',swdown(iainia),W_to_mmol,RG_to_PAR,&
                          Isotrop_Abs_Tot_p(iainia,jv,ilev),light_tran_to_level(iainia,jv,ilev) &
                          , lai_per_level(iainia,jv,ilev)
                  ENDIF
                  Iabs(iainia)=swdown(iainia)*W_to_mmol*RG_to_PAR*&
                       Isotrop_Abs_Tot_p(iainia,jv,ilev)*light_tran_to_level(iainia,jv,ilev) &
                       / lai_per_level(iainia,jv,ilev) ! need to convert to per m**2 of leaves to
                  ! be consistent with the units we use for Jmax
!                  WRITE(numout,*) 'Iabs ',jv,Iabs(iainia),lai_per_level(iainia,jv,ilev)
!                  Iabs(iainia)=swdown(iainia)*W_to_mmol*RG_to_PAR*Isotrop_Abs_Tot_p(iainia,jv,ilev)
                  !+++++++++++++++++
                  ! If we have a very dense canopy, the lower levels might
                  ! get almost no light.  If the light is close to zero, it
                  ! causes a numerical problem below, as x1 will be zero.  Of
                  ! course, if the absorbed light is really small photosynthesis will
                  ! not happen, so we can just skip this level.  This number is 
                  ! fairly arbitrary, but it should be as small as possible.
                  IF(Iabs(iainia) .LT. 1e-12)CYCLE

                  !
                  !
                  ! eq. 4 of Yin et al (2009)
                  Jmax(iainia)=vj2(iainia)
                  JJ(iainia) = ( alpha_LL(jv) * Iabs(iainia) + Jmax(iainia) - &
                       sqrt((alpha_LL(jv) * Iabs(iainia) + Jmax(iainia) )**2. &
                       - 4 * theta(jv) * Jmax(iainia) * alpha_LL(jv) * &
                       Iabs(iainia)) ) &
                       / ( 2 * theta(jv))

                  !

                  IF(ld_photo .AND. test_pft == jv)THEN
                     WRITE(numout,*) '*************************'
                     WRITE(numout,*) 'jv,ilev: ',jv,ilev
                     WRITE(numout,*) 'JJ(iainia),Jmax(iainia),Iabs(iainia),Rd(iainia): ',&
                          JJ(iainia),Jmax(iainia),Iabs(iainia),Rd(iainia)
                     WRITE(numout,*) 'vj2(iainia),vc2(iainia),N_Vcmax:',&
                          vj2(iainia),vc2(iainia),N_Vcmax
                     WRITE(numout,*) 'Isotrop_Abs_Tot_p(iainia,jv,ilev),Isotrop_Tran_Tot_p(iainia,jv,ilev):',&
                          Isotrop_Abs_Tot_p(iainia,jv,ilev),Isotrop_Tran_Tot_p(iainia,jv,ilev)
                     
                     WRITE(numout,*) 'water_lim(iainia),T_Rd(iainia):',water_lim(iainia),T_Rd(iainia)
                     WRITE(numout,*) 'vc(iainia),vj(iainia), vcmax(iainia,jv):',&
                          vc(iainia),vj(iainia),vcmax(iainia,jv)
                     WRITE(numout,*) '*************************'
                  ENDIF
                  IF ( is_c4(jv) )  THEN
                     !
                     ! @addtogroup Photosynthesis
                     ! @{   
                     !
                     ! 2.4.2 Assimilation for C4 plants (Collatz et al., 1992)\n
                     !! \latexonly
                     !! \input{jdiffuco_trans_co2_2.4.2.tex}
                     !! \endlatexonly
                     ! @}           
                     !
                     !
                     !
                     ! Analytical resolution of the Assimilation based Yin et al. (2009)
                     ! Eq. 28 of Yin et al. (2009)
                     fcyc= 1. - ( 4.*(1.-fpsir(jv))*(1.+fQ(jv)) + 3.*h_protons(jv)*fpseudo(jv) ) / &
                          ( 3.*h_protons(jv) - 4.*(1.-fpsir(jv)))

                     ! See paragraph after eq. (20b) of Yin et al.
                     Rm=Rd(iainia)/2.

                     ! We assume that cs_star equals ci_star (see Comment in legend of Fig. 6 of Yin et al. (2009)
                     ! Equation 26 of Yin et al. (2009)
                     Cs_star = (gbs(jv) * low_gamma_star(iainia) * Oi - ( 1. + &
                          low_gamma_star(iainia) * alpha(jv) / 0.047) * Rd(iainia) + Rm ) &
                          / ( gbs(jv) + kp(jv) ) 
                     

                     ! eq. 11 of Yin et al (2009)
                     J2 = JJ(iainia) / ( 1. - fpseudo(jv) / ( 1. - fcyc ) )

                     ! Equation right after eq. (20d) of Yin et al. (2009)
                     z = ( 2. + fQ(jv) - fcyc ) / ( h_protons(jv) * (1. - fcyc ))

                     VpJ2 = fpsir(jv) * J2 * z / 2.

                     A_3=9999.

                     ! See eq. right after eq. 18 of Yin et al. (2009)
                     ! The loop over limit_photo calculates the assimultion
                     ! rate of the Rubisco-limited CsO2 assimilation (Ac) and
                     ! the rate of electron transport-limited CO2 assimultion
                     ! (Aj).  The overall assimilation will be the slower
                     ! of these two processes.
                     DO limit_photo=1,2
                        ! Is Vc limiting the Assimilation
                        IF ( limit_photo .EQ. 1 ) THEN
                           a = 1. + kp(jv) / gbs(jv)
                           b = 0.
                           x1 = Vc2(iainia)
                           x2 = KmC(iainia)/KmO(iainia)
                           x3 = KmC(iainia)
                           ! Is J limiting the Assimilation
                        ELSE
                           a = 1.
                           b = VpJ2
                           x1 = (1.- fpsir(jv)) * J2 * z / 3.
                           x2 = 7. * low_gamma_star(iainia) / 3.
                           x3 = 0.
                        ENDIF

                        m=fvpd(iainia)-g0(jv)/gb(iainia)
                        d=g0(jv)*(Ca(iainia)-Cs_star) + fvpd(iainia)*Rd(iainia)
                        f=(b-Rm-low_gamma_star(iainia)*Oi*gbs(jv))*x1*d + a*gbs(jv)*x1*Ca(iainia)*d
                        j=(b-Rm+gbs(jv)*x3 + x2*gbs(jv)*Oi)*m + (alpha(jv)*x2/0.047-1.)*d &
                             + a*gbs(jv)*(Ca(iainia)*m - d/gb(iainia) - (Ca(iainia) - Cs_star ))

                        g=(b-Rm-low_gamma_star(iainia)*Oi*gbs(jv))*x1*m - (alpha(jv)*low_gamma_star(iainia)/0.047+1.)*x1*d &
                             + a*gbs(jv)*x1*(Ca(iainia)*m - d/gb(iainia) - (Ca(iainia)-Cs_star ))

                        h=-((alpha(jv)*low_gamma_star(iainia)/0.047+1.)*x1*m + (a*gbs(jv)*x1*(m-1.))/gb(iainia) )
                        i= ( b-Rm + gbs(jv)*x3 + x2*gbs(jv)*Oi )*d + a*gbs(jv)*Ca(iainia)*d
                        l= ( alpha(jv)*x2/0.047 - 1.)*m - (a*gbs(jv)*(m-1.))/gb(iainia)

                        p = (j-(h-l*Rd(iainia))) / l
                        q = (i+j*Rd(iainia)-g) / l
                        r = -(f-i*Rd(iainia)) / l 

                        ! See Yin et al. (2009) and  Baldocchi (1994)
                        QQ = ( (p**2._r_std) - 3._r_std * q) / 9._r_std
                        UU = ( 2._r_std* (p**3._r_std) - 9._r_std *p*q + 27._r_std *r) /54._r_std

                        IF (QQ .GE. 0._r_std) THEN
                           IF (ABS(UU/(QQ**1.5_r_std) ) .LE. 1._r_std) THEN
                              PSI = ACOS(UU/(QQ**1.5_r_std))
                              A_3_tmp = -2._r_std * SQRT(QQ) * COS(( PSI + 4._r_std * PI)/3._r_std ) - p / 3._r_std
                              IF (( A_3_tmp .LT. A_3 )) THEN
                                 A_3 = A_3_tmp
                              ELSE
                                 ! In case, J is not limiting the assimilation
                                 ! we have to re-initialise a, b, x1, x2 and x3 values
                                 ! in agreement with a Vc-limited assimilation 
                                 a = 1. + kp(jv) / gbs(jv)
                                 b = 0.
                                 x1 = Vc2(iainia)
                                 x2 = KmC(iainia)/KmO(iainia)
                                 x3 = KmC(iainia)
                              ENDIF
                           ENDIF
                        ELSE
                           WRITE(numout,*) 'WARNING: unexpected value for QQ (sechiba_hydrol_arch.f90)'
                        ENDIF

                        IF ( ( A_3 .EQ. 9999. ) .OR. ( A_3 .LT. (-Rd(iainia)) ) ) THEN
                           WRITE(numout,*) 'We have a problem in jdiffuco_trans_co2'
                           WRITE(numout,*) 'no real positive solution found for pft:',jv
                           WRITE(numout,*) 'temp_sol:',temp_sol(iainia)
                           WRITE(numout,*) 'vpd:',vpd(iainia)
                           A_3 = -Rd(iainia)
                        ENDIF
                        assimi(iainia) = A_3

                        !++++ TEMP +++++
                        IF(( x1 - (assimi(iainia) + Rd(iainia) )) == zero)THEN
                           
                           ! This causes a problem, since we really should not
                           ! be dividing by zero.  However, it seems to happen
                           ! fairly rarely, so all we'll do is cycle to the
                           ! next loop and keep track of this warning so we
                           ! can look at it afterwards.
                           warnings(iainia,jv,iwphoto)=warnings(iainia,jv,iwphoto)+un
                           
                           IF(ld_warn)THEN
                              WRITE(numout,*) 'jdiffuco, Getting ready to divide by zero! C4'
                              WRITE(numout,*) '( x1 - ( assimi(iainia) + Rd(iainia) ) ', &
                                   ( x1 - (assimi(iainia) + Rd(iainia) ))
                              WRITE(numout,*) 'x1,assimi(iainia),Rd(iainia): ', &
                                   x1,assimi(iainia),Rd(iainia)
                              WRITE(numout,*) 'jv,ilev,iainia: ', jv,ilev,iainia
                           ENDIF
                           
                           CYCLE
                           
                        ENDIF

                        ! Eq. 24 of Yin et al. (2009) 
                        Obs = ( alpha(jv) * assimi(iainia) ) / ( 0.047 * gbs(jv) ) + Oi
                        ! Eq. 23 of Yin et al. (2009)
                        Cc = ( ( assimi(iainia) + Rd(iainia) ) * ( x2 * Obs + x3 ) + low_gamma_star(iainia) &
                             * Obs * x1 ) &
                             / ( x1 - ( assimi(iainia) + Rd(iainia) ))
                        ! Eq. 22 of Yin et al. (2009)
                        new_leaf_ci(iainia,jv,ilev) = ( Cc - ( b - assimi(iainia) - Rm ) / gbs(jv) ) / a



                        ! JR %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

                        ! For the cases in which the supply term condition applies, we need
                        ! to work backwards and calculate gs, and hence assimi for the grid
                        ! square and PFT in question, from the value of vbeta3 derived in the
                        ! enerbil code.

                        ! This sequence is for the c4 vegetation types, and should be identical
                        ! to the c3 loop below, except for the definition of assimi

                        IF (hydrol_flag3(iainia, jv)) THEN

                           !WRITE(numout,*) '231113 in c4 loop ilev is: ', ilev, 'PFT is: ', jv

                           ! WRITE(numout,*) '151113 in jenerbil_trans_co2 hydrol_flag3 C4 plants'

                            speed = MAX(min_wind, jwind(iainia))

                            ! first case

                            IF (zqsvegrap(iainia) .lt. 1.0d0) THEN
                           
                            !cresist = vbeta3(iainia, jv) / &
                            !     &  ( veget_max(iainia, jv) * (1.0d0 - zqsvegrap(iainia)) + &
                            !     &  veget_max(iainia, jv) * zqsvegrap(iainia) )
                            
                            cresist = vbeta3(iainia, jv) / &
                                  & (veget_max(iainia, jv) * ( un - zqsvegrap(iainia)) + &
                                  &  veget(iainia,jv) * zqsvegrap(iainia) )     
                                 
                            
                            ! WRITE(numout,*) 'cresist condition a)'

                            ELSE

                            ! cresist = vbeta3(iainia, jv) / &
                            !      &  ( veget_max(iainia, jv) * zqsvegrap(iainia) )

                            cresist = 0.0d0

                            ! WRITE(numout,*) 'cresist condition b)'

                            END IF
                           
                            IF (vbeta23(iainia, jv) .le. &
                            &  (veget(iainia, jv) * zqsvegrap(iainia) * cresist) ) THEN
                               ! do nothing
                            ELSE

                               IF (zqsvegrap(iainia) .lt. 1.0d0) THEN
                               !cresist = (vbeta3(iainia, jv) - vbeta23(iainia, jv)  )  / &
                               !    & ( veget_max(iainia, jv) * (1.0d0 - zqsvegrap(iainia))  )
                               
                               cresist = vbeta3(iainia, jv) / &
                                  & (veget_max(iainia, jv) * ( un - zqsvegrap(iainia)) + &
                                  &  veget(iainia,jv) * zqsvegrap(iainia) )    

                               
                               ! WRITE(numout,*) 'cresist condition c)'
                            
                               ELSE

                               ! cresist = vbeta3(iainia, jv) / &
                               !      &  ( veget_max(iainia, jv) * zqsvegrap(iainia) )

                               cresist = 0.0d0

                               END IF

                            END IF !

                                   !     
                            IF (cresist .ne. 0.0d0) THEN
                                sum_rveget_rstruct(iainia,jv) = &
                                     & (1.0d0/cresist - 1.0d0) * (1.0d0 / (speed * q_cdrag(iainia) * rveg_pft(jv)))
                              ELSE
                                ! sum_rveget_rstruct(iainia,jv) = &
                                !      & (1.0d0 / (speed * q_cdrag(iainia) * rveg_pft(jv)))
                                  
                                sum_rveget_rstruct(iainia,jv) = 0.0d0

                            END IF

                            !WRITE(numout,*) '241113 sub_rveget_rstruct is: ', sum_rveget_rstruct(iainia,jv)

                            vbeta3pot(iainia,jv) = MAX(zero, veget_max(iainia,jv) * cresist)


                            ! calculate approximate gs, working backwards from vbeta3
                            IF (sum_rveget_rstruct(iainia,jv) .ne. 0.0d0) THEN
                                gstot(iainia) = 1.0d0 / sum_rveget_rstruct(iainia,jv)
                            ELSE
                               ! Need to convert the units of g0
                               gstot(iainia) = g0(jv)*mmol_to_m_1 *(temp_sol(iainia)/tp_00)*&
                                    (pb_std/pb(iainia))*ratio_H2O_to_CO2
                            END IF

                            !WRITE(numout,*) '241113 gstot is: ', gstot

                            IF (gstot(iainia) .gt. 0.0d0) THEN
                                ! nothing
                            ELSE
                                !WRITE(*,*) '121113 gstot .le. 0'
                            ENDIF


                            ! we now do a unit conversion, from m/s to mol/m^2/s, the reverse
                            !   of the calculation of section 2.5, below

                            gstot(iainia) =  gstot(iainia) / (mmol_to_m_1 *(temp_sol(iainia)/tp_00)* &
                                       (pb_std/pb(iainia))*ratio_H2O_to_CO2)


                            ! gs(iainia) = gstot(iainia) / lai(iainia, jv)
                            ! gs(iainia) = gstot(iainia) * gs_distribution(iainia, jv, ilev) !/ lai_total(iainia,jv)

!************************CHECK KIM: gs should not be lower than g0************************************
                            

                            gs(iainia) = gstot(iainia)*gstot_frac(iainia,jv,ilev) / lai_per_level(iainia,jv,ilev)

                           ! IF (gs(iainia) .gt. gstot(iainia)) THEN
                           !    gs(iainia) = gstot(iainia)
                           ! END IF
                            

                            IF (gs(iainia) .GE. g0(jv)) THEN
                               assimi(iainia) = (((gs(iainia) - g0(jv)) * (Ca(iainia) - Cs_star)) / fvpd(iainia)) &
                                  & - Rd(iainia)
                            ELSE
                               assimi(iainia) = -Rd(iainia)
                            ENDIF

                            assimi_store(iainia, jv, ilev) = assimi(iainia)

                            ! WRITE(numout,*) '281113 assimi is: ', assimi

                             IF (assimi(iainia) .lt. min_sechiba) THEN
                                 assimi(iainia) = 0.0d0
                             !    WRITE(numout,*) 'assimi(iainia) is negative ***************************************'
                             !    WRITE(numout,*) 'assimi(iainia) is: ', assimi(iainia)
                             !    WRITE(numout,*) 'gs(iainia) is: ', gs(iainia)
                             !    WRITE(numout,*) 'g0(jv) is: ', g0(jv)
                             !    WRITE(numout,*) 'new_leaf_ci(iainia,jv,ilev) is: ', new_leaf_ci(iainia,jv,ilev)
                             !    WRITE(numout,*) 'Ca(iainia) is: ', Ca(iainia)
                             !    WRITE(numout,*) 'Cs_star is: ', Cs_star
                             !    WRITE(numout,*) 'fvpd(iainia) is: ', fvpd(iainia)
                             !    WRITE(numout,*) 'Rd(iainia) is: ', Rd(iainia)
                             !    WRITE(numout,*) '*********************************************************'
                              ELSE IF (assimi(iainia) .gt. 500.0d0) THEN
                             !    WRITE(numout,*) 'assimi(iainia) is very large'
                             !    WRITE(numout,*) 'assimi(iainia) is: ', assimi(iainia)
                             !    WRITE(numout,*) 'temp_sol(iainia) is: ', temp_sol(iainia)
                             !    WRITE(numout,*) 'vbeta3(iainia, jv) is: ', vbeta3(iainia, jv)
                             !    WRITE(numout,*) 'gs(iainia) is: ', gs(iainia)
                             !    WRITE(numout,*) 'g0(jv) is: ', g0(jv)
                             !    WRITE(numout,*) 'new_leaf_ci(iainia,jv,ilev) is: ', new_leaf_ci(iainia,jv,ilev)
                             !    WRITE(numout,*) 'Ca(iainia) is: ', Ca(iainia)
                             !    WRITE(numout,*) 'Cs_star is: ', Cs_star
                             !    WRITE(numout,*) 'fvpd(iainia) is: ', fvpd(iainia)
                             !    WRITE(numout,*) 'Rd(iainia) is: ', Rd(iainia)
                             !    WRITE(numout,*) 'gstot(iainia) is: ', gstot(iainia)
                             !    WRITE(numout,*) 'sum_rveget_rstruct(iainia,jv) is: ', sum_rveget_rstruct(iainia,jv)
                             !    WRITE(numout,*) 'speed is: ', speed
                             !    WRITE(numout,*) 'q_cdrag(iainia) is: ',q_cdrag(iainia)
                             !    WRITE(numout,*) 'rveg_pft(jv) is: ', rveg_pft(jv)
                             !    WRITE(numout,*) 'gstot_frac(iainia,jv,ilev) is: ', gstot_frac(iainia,jv,ilev)
                             !    WRITE(numout,*) 'lai_per_level(iainia,jv,ilev) is: ', lai_per_level(iainia,jv,ilev)
                             !    WRITE(numout,*) '*********************************************************'                                
                              END IF       
                
                        ENDIF  ! (hydrol_flag3(iainia, jv))

                        ! with new assimilation rates for the grid squares and the PFTs for
                        ! which the supply term restriction replies, we let the rest of the
                        ! routine run its course from here, to calculate gs and gpp (vbeta3
                        ! remains the same as that calculated within enerbil)

                        ! JR %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


                        ! Eq. 25 of Yin et al. (2009)
                        ! It should be Cs instead of Ca but it seems that 
                        ! other equations in Appendix C make use of Ca
                       ! IF ( ABS( assimi(iainia) + Rd(iainia) ) .LT. min_sechiba ) THEN

!**************CHECK KIM: shouldn't this be done before the calculation of assimi? ***********************************
                        IF ( gs(iainia) .LT. min_sechiba ) THEN
                            gs(iainia) = g0(jv)
                        ENDIF
                        !      

                     ENDDO
                     !
                  ELSE
                     !
                     ! @addtogroup Photosynthesis
                     ! @{   
                     !
                     ! 2.4.3 Assimilation for C3 plants (Farqhuar et al., 1980)\n
                     !! \latexonly
                     !! \input{jdiffuco_trans_co2_2.4.3.tex}
                     !! \endlatexonly
                     ! @}           
                     !
                     !
                     !
                     A_1=9999.

                     ! See eq. right after eq. 18 of Yin et al. (2009)
                     DO limit_photo=1,2
                        ! Is Vc limiting the Assimilation
                        IF ( limit_photo .EQ. 1 ) THEN
                           x1 = vc2(iainia)
                           ! It should be O not Oi (comment from Vuichard)
                           x2 = KmC(iainia) * ( 1. + Oi / KmO(iainia) )
                           ! Is J limiting the Assimilation
                        ELSE
                           x1 = JJ(iainia)/4.
                           x2 = 2. * gamma_star(iainia)
                        ENDIF


                        ! See Appendix B of Yin et al. (2009)
                        a = g0(jv) * ( x2 + gamma_star(iainia) ) + ( fvpd(iainia) ) * ( x1 - Rd(iainia) )
                        b = Ca(iainia) * ( x1 - Rd(iainia) ) - gamma_star(iainia) * x1 - Rd(iainia) * x2
                        c = Ca(iainia) + x2 + ( 1./gb(iainia) ) * ( x1 - Rd(iainia) ) 
                        d = x2 + gamma_star(iainia)
                        m = fvpd(iainia) / gb(iainia)  

                        p = - ( d + a / gb(iainia) + fvpd(iainia) * c ) / m

                        q = ( d * ( x1 - Rd(iainia) ) + a*c + ( fvpd(iainia) ) * b ) / m
                        r = - a * b / m

                        ! See Yin et al. (2009) 
                        QQ = ( (p**2._r_std) - 3._r_std * q) / 9._r_std
                        UU = ( 2._r_std* (p**3._r_std) - 9._r_std *p*q + 27._r_std *r) /54._r_std

                        IF ( (QQ .GE. 0._r_std) .AND. (ABS(UU/(QQ**1.5_r_std) ) .LE. 1._r_std) ) THEN
                           PSI = ACOS(UU/(QQ**1.5_r_std))
                           A_1_tmp = -2._r_std * SQRT(QQ) * COS( PSI / 3._r_std ) - p / 3._r_std
                           IF (( A_1_tmp .LT. A_1 )) THEN
                              A_1 = A_1_tmp
                           ELSE
                              ! In case, J is not limiting the assimilation
                              ! we have to re-initialise x1 and x2 values
                              ! in agreement with a Vc-limited assimilation 
                              x1 = vc2(iainia)
                              ! It should be O not Oi (comment from Vuichard)
                              x2 = KmC(iainia) * ( 1. + Oi / KmO(iainia) )                           
                           ENDIF
                        ENDIF
                     ENDDO

                     IF ( (A_1 .EQ. 9999.) .OR. ( A_1 .LT. (-Rd(iainia)) ) ) THEN
                        WRITE(numout,*) 'We have a problem in jdiffuco_trans_co2'
                        WRITE(numout,*) 'no real positive solution found for pft:',jv
                        WRITE(numout,*) 'temp_sol:',temp_sol(iainia)
                        WRITE(numout,*) 'vpd:',vpd(iainia)
                        WRITE(numout,*) 'Setting the solution to -Rd(iainia):',-Rd(iainia)
                        A_1 = -Rd(iainia)
                     ENDIF
                     assimi(iainia) = A_1
                     ! Eq. 18 of Yin et al. (2009)

                     !++++++++ TEMP +++++++
                     IF(( x1 - (assimi(iainia) + Rd(iainia) )) == zero)THEN
                        ! This causes a problem, since we really should not
                        ! be dividing by zero.  However, it seems to happen
                        ! fairly rarely, so all we'll do is cycle to the
                        ! next loop and keep track of this warning so we
                        ! can look at it afterwards.
                        warnings(iainia,jv,iwphoto)=warnings(iainia,jv,iwphoto)+un

                        IF(ld_warn)THEN
                           WRITE(numout,*) 'jdiffuco, Getting ready to divide by zero! C3'
                           WRITE(numout,*) '( x1 - ( assimi(iainia) + Rd(iainia) ) ', &
                                ( x1 - (assimi(iainia) + Rd(iainia) ))
                           WRITE(numout,*) 'x1,assimi(iainia),Rd(iainia): ', &
                                x1,assimi(iainia),Rd(iainia)
                           WRITE(numout,*) 'jv,ilev,iainia: ', jv,ilev,iainia
                        ENDIF
                        
                        CYCLE

                     ENDIF
                     !++++++++++++++++++++++++++++++
 
                     Cc = ( gamma_star(iainia) * x1 + ( assimi(iainia) + Rd(iainia) ) * x2 )  &
                          / ( x1 - ( assimi(iainia) + Rd(iainia) ) )
                     ! Eq. 17 of Yin et al. (2009)
                     ! new_leaf_ci(iainia,jv,ilev) = Cc
                     new_leaf_ci(iainia,jv,ilev) = Cc  
                     ! See eq. right after eq. 15 of Yin et al. (2009)
                     ci_star = gamma_star(iainia) 
                     ! 


                        ! JR %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

                        ! For the cases in which the supply term condition applies, we need
                        ! to work backwards and calculate gs, and hence assimi for the grid
                        ! square and PFT in question, from the value of vbeta3 derived in the
                        ! enerbil code.

                        ! This sequence is for the c3 vegetation types, and should be identical
                        ! to the c4 loop above, except for the definition of assimi

                        IF (hydrol_flag3(iainia, jv)) THEN

                            !WRITE(numout,*) 'in jdiffuco_trans_co2'
                            !WRITE(numout,*) '231113 in c3 loop ilev is: ', ilev, 'PFT is: ', jv

                            speed = MAX(min_wind, jwind(iainia))

                            ! first case
                            ! WRITE(numout,*) '151113 cresist before: ', cresist

                            IF (zqsvegrap(iainia) .lt. 1.0d0) THEN
                            !calculation of cresist may need to be check 
                            ! Here may to to devided gradient of spacific
                            ! humidity, at least which need to consist with the
                            ! caculation in the diffuco_trans_co2.. 
                            !cresist = vbeta3(iainia, jv) / &
                            !     &  ( veget_max(iainia, jv) * (1.0d0 - zqsvegrap(iainia)) + &
                            !     &  veget_max(iainia, jv) * zqsvegrap(iainia) )
                             cresist = vbeta3(iainia, jv) / &
                                  & (veget_max(iainia, jv) * ( un - zqsvegrap(iainia)) + &
                                  &  veget(iainia,jv) * zqsvegrap(iainia) )        
                                 

                            ! WRITE(numout,*) 'cresist condition a)'
                            
                            ELSE

                            ! cresist = vbeta3(iainia, jv) / &
                            !      &  ( veget_max(iainia, jv) * zqsvegrap(iainia) )

                            cresist = 0.0d0

                            ! WRITE(numout,*) 'cresist condition b)'

                            END IF


                            IF (vbeta23(iainia, jv) .le. &
                            &  (veget(iainia, jv) * zqsvegrap(iainia) * cresist) ) THEN

                               ! do nothing
 
                            ELSE

                               IF (zqsvegrap(iainia) .lt. 1.0d0) THEN

                               !cresist = (vbeta3(iainia, jv) - vbeta23(iainia, jv)  )  / &
                               !    & ( veget_max(iainia, jv) * (1.0d0 - zqsvegrap(iainia))  )

                               cresist = vbeta3(iainia, jv) / &
                                  & (veget_max(iainia, jv) * ( un - zqsvegrap(iainia)) + &
                                  &  veget(iainia,jv) * zqsvegrap(iainia) )     
                               ! WRITE(numout,*) 'cresist condition c)'
                            
                               ELSE

                               ! cresist = vbeta3(iainia, jv) / &
                               !      &  ( veget_max(iainia, jv) * zqsvegrap(iainia) )

                               cresist = 0.0d0

                               ! WRITE(numout,*) 'cresist condition d)'

                               END IF

                            END IF !

                            !WRITE(numout,*) '241113 cresist is: ', cresist

                            !*****************************TEMP**************************
                            !WRITE(*,*) '151113 cresist (jdiffuco_trans_co2) is: ', cresist
                            !WRITE(*,*) '151113 speed: ', speed
                            !WRITE(*,*) '151113 cresist (jdiffuco_trans_co2) is: ', q_cdrag(iainia)
                            !WRITE(*,*) '151113 rveg_pft (jdiffuco_trans_co2) is: ', rveg_pft(jv)
                            !*****************************TEMP****************************

                            IF (cresist .ne. 0.0d0) THEN
                                sum_rveget_rstruct(iainia,jv) = &
                                     & (1.0d0/cresist - 1.0d0) * (1.0d0 / (speed * q_cdrag(iainia) * rveg_pft(jv)))
                            ELSE
                                sum_rveget_rstruct(iainia,jv) = &
                                     & (1.0d0 / (speed * q_cdrag(iainia) * rveg_pft(jv)))
                            END IF

                            IF (cresist .ne. 0.0d0) THEN
                                sum_rveget_rstruct(iainia,jv) = &
                                     & (1.0d0/cresist - 1.0d0) * (1.0d0 / (speed * q_cdrag(iainia) * rveg_pft(jv)))
                            ELSE
                                ! sum_rveget_rstruct(iainia,jv) = &
                                !      & (1.0d0 / (speed * q_cdrag(iainia) * rveg_pft(jv)))
                                  
                                sum_rveget_rstruct(iainia,jv) = 0.0d0

                            END IF

                            !WRITE(numout,*) '241113 sub_rveget_rstruct is: ', sum_rveget_rstruct(iainia,jv)

                            vbeta3pot(iainia,jv) = MAX(zero, veget_max(iainia,jv) * cresist)

                              
                            ! calculate approximate gs, working backwards from vbeta3
                            !
                            IF (sum_rveget_rstruct(iainia,jv) .ne. 0.0d0) THEN
                                gstot(iainia) = 1.0d0 / sum_rveget_rstruct(iainia,jv)
                            ELSE
                               ! Need to convert the units of g0
                               gstot(iainia) = g0(jv)*mmol_to_m_1 *(temp_sol(iainia)/tp_00)*&
                                    (pb_std/pb(iainia))*ratio_H2O_to_CO2
                            END IF
                            
    
              
                            !******CHECK KIM: this what I had for a divide by zero bug fix, for now I keep what's in James update
                            ! IF (cresist .NE. un .AND. speed .GT. min_sechiba .AND. &
                            !      & q_cdrag(iainia) .GT. min_sechiba .AND. rveg_pft(jv) .GT. min_sechiba) THEN
                            ! 
                            ! sum_rveget_rstruct(iainia,jv) = &
                            !       & (1.0d0/cresist - 1.0d0) * (1.0d0 / (speed * q_cdrag(iainia) * rveg_pft(jv)))
                            !ENDIF

                            !WRITE(numout,*) '241113 sub_rveget_rstruct is: ', sum_rveget_rstruct(iainia,jv)


                            IF (cresist .lt. min_sechiba) THEN
                                IF(ld_warn .OR. ld_wstress) THEN
                                !       WRITE(numout,*) 'cresist is very small or negative   **********************'
                                !       WRITE(numout,*) 'cresist is: ', cresist
                                !       WRITE(numout,*) 'vbeta3(iainia, jv) is: ', vbeta3(iainia, jv)
                                !       WRITE(numout,*) 'veget_max(iainia, jv) is: ', veget_max(iainia, jv)
                                !       WRITE(numout,*) 'zqsvegrap(iainia) is: ', zqsvegrap(iainia)
                                !       WRITE(numout,*) '*********************************************************'
                                ENDIF
                            ELSE IF (assimi(iainia) .gt. 100.0d0) THEN
                                WRITE(numout,*) 'assimi(iainia) is very large'
                            END IF


                            IF (gstot(iainia) .gt. 0.0d0) THEN
                                ! nothing
                            ELSE
                                !WRITE(*,*) '121113 gstot .le. 0'
                            ENDIF

                            ! we assume lai is the sum of lai_per_level over all of the levels

                            ! we now do a unit conversion, from m/s to mol/m^2/s, the reverse
                            !   of the calculation of section 2.5, below

                            gstot(iainia) =  gstot(iainia) / (mmol_to_m_1 *(temp_sol(iainia)/tp_00)* &
                                       (pb_std/pb(iainia))*ratio_H2O_to_CO2)




                            gs(iainia) = gstot(iainia)*gstot_frac(iainia,jv,ilev) / lai_per_level(iainia,jv,ilev)

                            IF (gs(iainia) .gt. gstot(iainia)) THEN
                                gs(iainia) = gstot(iainia)
                            END IF
                            
                            !write(*,*) 'gs_jdiffuco_pft',jv,'ilev',ilev,gs(iainia)

                            ! define gs, based on vbeta3

                            IF (gs(iainia) .GE. g0(jv)) THEN
                               assimi(iainia) = (((gs(iainia) - g0(jv)) * (new_leaf_ci(iainia,jv,ilev) - ci_star)) / fvpd(iainia)) &
                                    & - Rd(iainia)
                            ELSE
                               assimi(iainia) = -Rd(iainia)

                            ENDIF

                           ! assimi(iainia) = (gs(iainia) - g0(jv)) * (new_leaf_ci(iainia,jv,ilev) - ci_star) / fvpd(iainia) &
                           !       & - Rd(iainia)
 
                            assimi_store(iainia, jv, ilev) = assimi(iainia)


                            ! IF (assimi(iainia) .lt. min_sechiba) THEN
                            !     WRITE(numout,*) '281113 assimi is: ', assimi
                            ! END IF

                             IF (assimi(iainia) .lt. min_sechiba) THEN
                                 assimi(iainia) = 0.0d0
                             !    WRITE(numout,*) 'assimi(iainia) is negative ***************************************'
                             !    WRITE(numout,*) 'assimi(iainia) is: ', assimi(iainia)
                             !    WRITE(numout,*) 'gs(iainia) is: ', gs(iainia)
                             !    WRITE(numout,*) 'g0(jv) is: ', g0(jv)
                             !    WRITE(numout,*) 'new_leaf_ci(iainia,jv,ilev) is: ', new_leaf_ci(iainia,jv,ilev)
                             !    WRITE(numout,*) 'ci_star is: ', ci_star
                             !    WRITE(numout,*) 'fvpd(iainia) is: ', fvpd(iainia)
                             !    WRITE(numout,*) 'Rd(iainia) is: ', Rd(iainia)
                             !    WRITE(numout,*) '*********************************************************'
                              ELSE IF (assimi(iainia) .gt. 500.0d0) THEN
                             !    WRITE(numout,*) 'assimi(iainia) is very large'
                             !    WRITE(numout,*) 'assimi(iainia) is: ', assimi(iainia)
                             !    WRITE(numout,*) 'temp_sol(iainia) is: ', temp_sol(iainia)
                             !    WRITE(numout,*) 'vbeta3(iainia, jv) is: ', vbeta3(iainia, jv)
                             !    WRITE(numout,*) 'gs(iainia) is: ', gs(iainia)
                             !    WRITE(numout,*) 'g0(jv) is: ', g0(jv)
                             !    WRITE(numout,*) 'new_leaf_ci(iainia,jv,ilev) is: ', new_leaf_ci(iainia,jv,ilev)
                             !    WRITE(numout,*) 'ci_star is: ', ci_star
                             !    WRITE(numout,*) 'Ca(iainia) is: ', Ca(iainia)
                             !    WRITE(numout,*) 'fvpd(iainia) is: ', fvpd(iainia)
                             !    WRITE(numout,*) 'Rd(iainia) is: ', Rd(iainia)
                             !    WRITE(numout,*) 'gstot(iainia) is: ', gstot(iainia)
                             !    WRITE(numout,*) 'sum_rveget_rstruct(iainia,jv) is: ', sum_rveget_rstruct(iainia,jv)
                             !    WRITE(numout,*) 'speed is: ', speed
                             !    WRITE(numout,*) 'q_cdrag(iainia) is: ',q_cdrag(iainia)
                             !    WRITE(numout,*) 'rveg_pft(jv) is: ', rveg_pft(jv)
                             !    WRITE(numout,*) 'gstot_frac(iainia,jv,ilev) is: ', gstot_frac(iainia,jv,ilev)
                             !    WRITE(numout,*) 'lai_per_level(iainia,jv,ilev) is: ', lai_per_level(iainia,jv,ilev)
                             !    WRITE(numout,*) '*********************************************************'      
                              END IF




                            ! WRITE(numout,*) '151113 assimi(iainia) (jdiffuco_trans_co2) is: ', assimi(iainia)              

                        ENDIF  ! (hydrol_flag3(iainia, jv))
 
                        ! with new assimilation rates for the grid squares and the PFTs for
                        ! which the supply term restriction replies, we let the rest of the
                        ! routine run its course from here, to calculate gs and gpp (vbeta3
                        ! remains the same as that calculated within enerbil)

                        ! JR %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

                        ! Eq. 25 of Yin et al. (2009)
                        ! It should be Cs instead of Ca but it seems that 
                        ! other equations in Appendix C make use of Ca
                       ! IF ( ABS( assimi(iainia) + Rd(iainia) ) .LT. min_sechiba ) THEN
                        IF ( gs(iainia) .LT. min_sechiba ) THEN
                            gs(iainia) = g0(jv)
                        ELSE
                            ! gs(iainia) = g0(jv) + ( assimi(iainia) + Rd(iainia) ) / ( Ca(iainia) - Cs_star ) * fvpd(iainia)                    
                            gs(iainia) = gs(iainia) ! as calculated in loop
                        ENDIF



                  ENDIF
                  

                  !
                  ! @addtogroup Photosynthesis
                  ! @{   
                  !
                  !! 2.4.4 Estimatation of the stomatal conductance (Ball et al., 1987).\n
                  !! \latexonly
                  !! \input{jdiffuco_trans_co2_2.4.4.tex}
                  !! \endlatexonly
                  ! @}           
                  !
                  !
                  ! keep stomatal conductance of the levels which we decide
                  ! are the top levels.  Notice that we multiply by the LAI
                  ! in the level here, so this is no longer a per leaf quantity,
                  ! but the whole quantity.
                  IF ( top_level(iainia,ilev) ) THEN
                     gs_top(iainia) = gs_top(iainia)+gs(iainia)*lai_per_level(iainia,jv,ilev)
                     !
                  ENDIF
                  !
                  ! @addtogroup Photosynthesis
                  ! @{   
                  !
                  !! 2.4.5 Integration at the canopy level\n
                  !! \latexonly
                  !! \input{jdiffuco_trans_co2_2.4.5.tex}
                  !! \endlatexonly
                  ! @}           
                  ! total assimilation and conductance
                  !assimtot(iainia) = assimtot(iainia) + &
                  !     assimi(iainia) * (lai_per_level(ilev+1)-lai_per_level(ilev))
                  !Rdtot(iainia) = Rdtot(iainia) + &
                  !     Rd(iainia) * (lai_per_level(ilev+1)-lai_per_level(ilev))
                  !gstot(iainia) = gstot(iainia) + &
                  !     gs(iainia) * (lai_per_level(ilev+1)-lai_per_level(ilev))
                  ! 
                  !++++++++++++++++++++
                  ! The equations give the amount of carbon produced per m**2 if
                  ! leaf surface.  Therefore, since we want GPP in units of m**2 of land surface,
                  ! we have to multiply by the LAI.
                  assimtot(iainia) = assimtot(iainia) + &
                       assimi(iainia) * lai_per_level(iainia,jv,ilev)
!                       assimi(iainia) 
                  IF(test_pft == jv .AND. ld_photo)THEN
                     WRITE(numout,*) 'assimi ',ilev,iainia,assimi(iainia),lai_per_level(iainia,jv,ilev)
                  ENDIF
                  Rdtot(iainia) = Rdtot(iainia) + &
!                       Rd(iainia) 
                       Rd(iainia) * lai_per_level(iainia,jv,ilev)
                  gstot(iainia) = gstot(iainia) + &
                       gs(iainia) * lai_per_level(iainia,jv,ilev)
!                       gs(iainia) 
                  ! WRITE(numout,*) '151113 iainia is: ', iainia, 'gs(iainia) is: ', gs(iainia)

                  !
                 gstot_output(iainia,jv,ilev) = gstot(iainia)
                 gs_output(iainia,jv,ilev) = gs(iainia)
                  !

               ENDIF ! if there is absorbed light
            ENDDO  ! loop over grid points
         ENDDO gridloop1 ! loop over LAI steps



         IF (ld_warn .AND. assimtot(iainia) .gt. 20) THEN
             WRITE(numout,*) 'assimtot is very high'
             WRITE(numout,*) 'assimtot is: ', assimtot(iainia)
             DO ilev=1,nlevels_tot
                 WRITE (numout,*) 'level: ', ilev, ' pft: ', jv , ' assimi_store: ', assimi_store(iainia, jv, ilev), &
                                     &' lai_per_level: ', lai_per_level(iainia, jv, ilev)
             END DO
         END IF




         DO jij = 1, kjpindex
             IF (hydrol_flag2(jij)) THEN
                ! WRITE(*,*) '091113 new assimi(grid point) is: ', assimi(jij)
             END IF
         END DO !jij =1, nvm
  
     ! WRITE(numout,*) '151113b gstot is: ', gstot
     ! WRITE(numout,*) '151113b lai_per_level is: ', lai_per_level

      ! Due to the water limited by the transpiration, we nned to recalculated 
      ! the stomata conductance(resistance) for the GPP.
      ! In this section, the assimlation should be recalculated.
      
      !! 2.5 Calculate resistances

         gridloop2: DO inia=1,nia
            !
            iainia=index_assi(inia)
            !
            ! We hit a fringe case above where we could not
            ! calculate the GPP.  Skip this loop so we don't
            ! divide by zero.
            IF(lskip(iainia)) CYCLE

           ! DO inina=1,nina
                 IF (hydrol_flag3(iainia, jv)) THEN
                 !nothing              
                 ELSE
                    CYCLE gridloop2
                 END IF !(hydrol_flag3)
           ! END DO !inina=1,nina


            !++++++ CHECK ++++++
            ! We introduce ::coupled_lai to calculate the :: vbeta3 
            ! In an closed canopy not all the leaves fully interact with the
            ! atmosphere because leaves can shelter each other. In a more open
            ! canopy most leaves can interact with the atmosphere. We use the
            ! ratio of lai over ::Pgap as a proxy for the amount of canopy that
            ! can interact with the atmosphere. Clearly that amount of lai that
            ! interacts should never exceed the:: total_lai.
            coupled_lai(iainia, jv) = biomass_to_coupled_lai( biomass(iainia, &
                 jv, ileaf, icarbon), veget(iainia,jv), jv)
            
            total_lai(iainia, jv) = biomass_to_lai( biomass(iainia, jv, ileaf,&
                 icarbon), jv )
            
            gstot(iainia) = gstot(iainia)* (coupled_lai(iainia,jv)/total_lai(iainia,jv))
            
           
            ! WRITE(numout,*) '151113 inia is: ', inia, 'gstot is: ', gstot(iainia)
            !
            !! Mean stomatal conductance for CO2 (mol m-2 s-1)
            gsmean(iainia,jv) = gstot(iainia)
            !
            ! cimean is the "mean ci" calculated in such a way that assimilation 
            ! calculated in enerbil is equivalent to assimtot
            !
            IF((assimtot(iainia)+Rdtot(iainia)) .GT. min_sechiba)THEN
               cimean(iainia,jv) = (gsmean(iainia,jv)-g0(jv)) &
                    / (fvpd(iainia)*(assimtot(iainia)+Rdtot(iainia))) &
                    + gamma_star(iainia) 
            ELSE
               ! According to Nicolas, this variable is completely diagnostic and not
               ! used for anything.  If the analytical photosynthesis is unable to find
               ! a solution for the A_1 coefficients in any of the levels, assimtot will
               ! be equal to -Rd, which means we will be dividing by zero.  This loop
               ! is to prevent that, and since cimean is diagnostic is doesn't matter
               ! what the value is.
               cimean(iainia,jv) = val_exp
            ENDIF
                 
            ! conversion from umol m-2 (PFT) s-1 to gC m-2 (mesh area) tstep-1
            gpp(iainia,jv) = assimtot(iainia)*12e-6*veget_max(iainia,jv)*dtradia

            ! IF (gpp(iainia, jv) .lt. min_sechiba) THEN
            !    WRITE(numout,*) 'gpp is very small ***************************************'
            !    WRITE(numout,*) 'assimtot(iainia) is: ', assimtot(iainia)
            !    WRITE(numout,*) 'fvpd(iainia) is: ', fvpd(iainia)
            !    WRITE(numout,*) 'Rdtot(iainia) is: ', Rdtot(iainia)
            !    WRITE(numout,*) 'veget_max(iainia,jv) is: ', veget_max(iainia,jv)
            !    WRITE(numout,*) 'gsmean(iainia,jv) is: ', gsmean(iainia,jv)
            !    WRITE(numout,*) 'g0(jv) is: ', g0(jv)
            !    WRITE(numout,*) '*********************************************************'
            ! ELSE IF (gpp(iainia, jv) .gt. 100.0d0) THEN
            !    WRITE(numout,*) 'gpp is very large'
            ! END IF

            !IF(test_grid ==1 .AND. jv == test_pft)THEN
            !   istep=istep+1
            !   WRITE(numout,*) 'gpp jdiffuco: ',istep, gpp(iainia,jv), assimtot(iainia),veget_max(iainia,jv)
            !ENDIF

            ! conversion from (mol m-2 s-1) to (umol m-2 s-1)
            gsmean(iainia,jv) = gsmean(iainia,jv)*1e-6
            !
            ! conversion from mol/m^2/s to m/s
            !
            ! As in Pearcy, Schulze and Zimmermann
            ! Measurement of transpiration and leaf conductance
            ! Chapter 8 of Plant Physiological Ecology
            ! Field methods and instrumentation, 1991
            ! Editors:
            !
            !    Robert W. Pearcy,
            !    James R. Ehleringer,
            !    Harold A. Mooney,
            !    Philip W. Rundel
            !
            ! ISBN: 978-0-412-40730-7 (Print) 978-94-010-9013-1 (Online)
            !
            !
            !we have already do the unit convertoion in the assimilation loop (gridloop1) 
            ! 
            !gstot(iainia) =  mmol_to_m_1 *(temp_sol(iainia)/tp_00)*&
            !     (pb_std/pb(iainia))*gstot(iainia)*ratio_H2O_to_CO2
            !gstop(iainia) =  mmol_to_m_1 * (temp_sol(iainia)/tp_00)*&
            !     (pb_std/pb(iainia))*gs_top(iainia)*ratio_H2O_to_CO2
             
            
            !+++++++++Output some information regarding ::rveget and pft 
            !IF (jv == test_pft .AND. test_grid == 1) THEN
             !                  WRITE(numout, '(A20, ES15.5)' ) 'New_Vbeta3:', vbeta3(iainia,jv)
             !                  WRITE(numout, '(A20, I5)'    ) 'pft type is:    ', jv
             !                  WRITE(numout, '(A20, ES15.5)') 'New_Gs_total:', gstot(iainia)    
            !ENDIF
            !+++++++++++++++++++++++++++++++++++ 
            
            !rveget(iainia,jv) = un/gstop(iainia)
            
            !+++++CHECK+++++++++++++++++++++++++
            !For the grass land, we assume that there are still  
            !some stomata on the other side of its leaves.
            !IF (.NOT. is_tree(jv) ) THEN
            !    gstot(iainia) = 1.25_r_std * gstot(iainia)
            !ENDIF
            !we try to set rvegt as un/gstot 
            rveget(iainia,jv) = un/gstot(iainia)
            
            IF (lai(iainia, jv) .lt. 0.1d0) THEN
                rveget_min(iainia,jv) = (defc_plus / kzero(jv)) * (un / 0.1d0)
            ELSE
                rveget_min(iainia,jv) = (defc_plus / kzero(jv)) * (un / lai(iainia,jv))
            END IF

            !
            ! rstruct is the difference between rtot (=1./gstot) and rveget
            !
            ! Correction Nathalie - le 27 Mars 2006 - Interdire a rstruct d'etre negatif
            !rstruct(iainia,jv) = un/gstot(iainia) - &
            !     rveget(iainia,jv)
            !rstruct(iainia,jv) = MAX( un/gstot(iainia) - &
            !     rveget(iainia,jv), min_sechiba)
            !
            !
            !! wind is a global variable of the diffuco module.
            speed = MAX(min_wind, jwind(iainia))
            !
            ! beta for transpiration
            !
            ! Corrections Nathalie - 28 March 2006 - on advices of Fred Hourdin
            !! Introduction of a potentiometer rveg_pft to settle the rveg+rstruct sum problem in the coupled mode.
            !! rveg_pft=1 in the offline mode. rveg_pft is a global variable declared in the diffuco module.
            !vbeta3(iainia,jv) = veget_max(iainia,jv) * &
            !  (un - zqsvegrap(iainia)) * &
            !  (un / (un + speed * q_cdrag(iainia) * (rveget(iainia,jv) + &
            !   rstruct(iainia,jv))))


            !! Global resistance of the canopy to evaporation
            cresist=(un / (un + speed * q_cdrag(iainia) * &
                 (rveg_pft(jv)*(rveget(iainia,jv) ))))

           !WRITE(*,*) '051113 within jdiffuco_trans_co2 before defn. vbeta3(1,:) is', vbeta3(1,:)

           ! 051113 commenting out the calculation of vbeta3 (as this is already defined, either from 
           ! the first call to this module or as part of the new enerbil (when constrained by the supply
           ! term))

!            vbeta3(icinic,jv) = veget_max(icinic,jv) * &
!                 (un - zqsvegrap(icinic)) * cresist + &
!    !!                 $          ! Addition Nathalie - June 2006
!    !!            $          vbeta3(icinic,jv) = vbeta3(icinic,jv) + &
!                 ! Corrections Nathalie - 09 November 2009 : veget => veget_max
!    !                 MIN( vbeta23(icinic,jv), veget(icinic,jv) * &
!                 MIN( vbeta23(icinic,jv), veget_max(icinic,jv) * &
!     !                 zqsvegrap(icinic) * humrel(icinic,jv) * &
!                 zqsvegrap(icinic) * cresist )
            ! Fin ajout Nathalie

           !WRITE(*,*) '051113 within jdiffuco_trans_co2 after defn. vbeta3(1,:) is', vbeta3(1,:)




            ! vbeta3pot for computation of potential transpiration (needed for irrigation)
           ! vbeta3pot(iainia,jv) = MAX(zero, veget_max(iainia,jv) * cresist)




          ! 211013 - we have derived a new vbeta3 from the enerbil segment


       !   WRITE(*,*) '051113 2nd call: vbeta3(iainia, jv) is: ', vbeta3(icinic, jv) 
       !   WRITE(*,*) '051113 2nd call: veget_max(iainia, jv) is: ', veget_max(icinic, jv) 
       !   WRITE(*,*) '051113 2nd call: zqsvegrap(iainia) is: ', zqsvegrap(icinic) 
       !   WRITE(*,*) '051113 2nd call: vbeta23(iainia, jv) is: ', vbeta23(icinic, jv) 
       !   WRITE(*,*) '051113 2nd call: cresist is: ', cresist 






          ! first case
          !WRITE(*,*) '051113 previous cresist: ', cresist
          !cresist = vbeta3(iainia, jv) / &
          !      &  ( veget_max(iainia, jv) * (1.0d0 - zqsvegrap(iainia)) + &
          !      &  veget_max(iainia, jv) * zqsvegrap(iainia) )


          !IF (vbeta23(iainia, jv) .le. &
          !       &  (veget_max(iainia, jv) * zqsvegrap(iainia) * cresist) ) THEN
             ! do nothing
          ! ELSE
          ! cresist = vbeta3(iainia, jv) / &
          !       & ( veget_max(iainia, jv) * (1.0d0 - zqsvegrap(iainia)) + &
          !       & vbeta23(iainia, jv) )
          !cresist = (vbeta3(iainia, jv) - vbeta23(iainia, jv)  )  / &
          !      & ( veget_max(iainia, jv) * (1.0d0 - zqsvegrap(iainia))  )

          !END IF !







          !WRITE(*,*) '051113 new cresist: ', cresist


          !! Potentiometer to set vegetation resistance (unitless)

          !sum_rveget_rstruct(iainia,jv) = &
          !      & (1.0d0/cresist) * (1.0d0 / (speed * q_cdrag(iainia) * rveg_pft(jv)))








          !WRITE(*,*) '051113 previous vbeta3pot: ', vbeta3pot
          !vbeta3pot(iainia,jv) = MAX(zero, veget_max(iainia,jv) * cresist)
          !WRITE(*,*) '051113 new vbeta3pot: ', vbeta3pot







       ! vbetaco2 is not used anymore, replaced by gsmean, so I need to rethink the calculation
       !   of these co-efficients when restriction by the supply term applies

       !   WRITE(*,*) '211013c previous vbetaco2: ', vbetaco2
       !   vbetaco2(iainia,jv) = veget_max(iainia,jv) * &
       !      (un / (un + speed * q_cdrag(iainia) * &
       !      (sum_rveget_rstruct(iainia,jv)))) / O2toCO2_stoechio
       !   WRITE(*,*) '211013c new vbetaco2: ', vbetaco2

       !   cimean(iainia,jv) = ccanopy(iainia) - &
       !      assimtot(iainia) / &
       !      ( vbetaco2(iainia,jv)/veget_max(iainia,jv) * &
       !      rau(iainia) * speed * q_cdrag(iainia))




!          ! beta for transpiration
!          !
!          ! Corrections Nathalie - 28 March 2006 - on advices of Fred Hourdin
!          !! Introduction of a potentiometer rveg_pft to settle the rveg+rstruct sum problem in the coupled mode.
!          !! rveg_pft=1 in the offline mode. rveg_pft is a global variable declared in the diffuco module.
!          !vbeta3(iainia,jv) = veget_max(iainia,jv) * &
!          !  (un - zqsvegrap(iainia)) * &
!          !  (un / (un + speed * q_cdrag(iainia) * (rveget(iainia,jv) + &
!          !   rstruct(iainia,jv))))
!          !! Global resistance of the canopy to evaporation
!          cresist=(un / (un + speed * q_cdrag(iainia) * &
!               (rveg_pft(jv)*(rveget(iainia,jv) + rstruct(iainia,jv)))))


!          vbeta3(iainia,jv) = veget_max(iainia,jv) * &
!            (un - zqsvegrap(iainia)) * cresist + &
!!!$          ! Addition Nathalie - June 2006
!!!$          vbeta3(iainia,jv) = vbeta3(iainia,jv) + &
!             ! Corrections Nathalie - 09 November 2009 : veget => veget_max
!!               MIN( vbeta23(iainia,jv), veget(iainia,jv) * &
!               MIN( vbeta23(iainia,jv), veget_max(iainia,jv) * &
!!               zqsvegrap(iainia) * humrel(iainia,jv) * &
!               zqsvegrap(iainia) * cresist )
!          ! Fin ajout Nathalie

!          ! vbeta3pot for computation of potential transpiration (needed for irrigation)
!          vbeta3pot(iainia,jv) = MAX(zero, veget_max(iainia,jv) * cresist)
          !
          ! beta for assimilation. The difference is that surface 
          ! covered by rain (un - zqsvegrap(iainia)) is not taken into account
          ! The factor 1.6 is conversion for H2O to CO2 conductance.
          ! vbetaco2(iainia,jv) = veget_max(iainia,jv) * &
          !   (un / (un + q_cdrag(iainia) * &
          !   (rveget(iainia,jv))))/1.6
          !

!          !! Global resistance of the canopy to CO2 transfer
!          vbetaco2(iainia,jv) = veget_max(iainia,jv) * &
!             (un / (un + speed * q_cdrag(iainia) * &
!             (rveget(iainia,jv) + rstruct(iainia,jv)))) / O2toCO2_stoechio
          !
          ! cimean is the "mean ci" calculated in such a way that assimilation 
          ! calculated in enerbil is equivalent to assimtot
          !
!          cimean(iainia,jv) = ccanopy(iainia) - &
!             assimtot(iainia) / &
!             ( vbetaco2(iainia,jv)/veget_max(iainia,jv) * &
!             rau(iainia) * speed * q_cdrag(iainia))

            !
            !
         ENDDO gridloop2 !loop over grid points
         !
      ENDIF ! if nia LT zero
      !
   ENDDO ! loop over vegetation types
   !
   IF (long_print) WRITE (numout,*) ' jdiffuco_trans_co2 done '

   !WRITE (numout,*) 'calling jnetcdf_trans_co2'

    ! this writes canopy profile data from this routine to a seperate netCDF file every time step,
    !   though it does slow the runtime considerably, so is only for diagnostics

    !CALL jnetcdf_trans_co2(kjpindex, james_netcdf_flag, gs_distribution(1,:,:), gs_output(1,:,:), &
    !                      & lai_per_level(1,:,:), light_tran_to_level(1,:,:), gs_diffuco_output(1,:,:), &
    !                      & gstot_output(1,:,:))   
    
    
             
                          
    IF(ld_photo)THEN
       WRITE(numout,*) 'gpp at the end of jdiffuco_trans_co2 ',gpp
    ENDIF


END SUBROUTINE jdiffuco_trans_co2



 ! ---------------------------------------------------------------------------------------



  FUNCTION Arrhenius (kjpindex,temp,ref_temp,energy_act) RESULT ( val_arrhenius )
    !! 0.1 Input variables

    INTEGER(i_std),INTENT(in)                     :: kjpindex          !! Domain size (-)
    REAL(r_std),DIMENSION(kjpindex),INTENT(in)    :: temp              !! Temperature (K)
    REAL(r_std), INTENT(in)                       :: ref_temp          !! Temperature of reference (K)
    REAL(r_std),INTENT(in)                        :: energy_act        !! Activation Energy (J mol-1)
    
    !! 0.2 Result

    REAL(r_std), DIMENSION(kjpindex)              :: val_arrhenius     !! Temperature dependance based on
                                                                       !! a Arrhenius function (-)
    
    val_arrhenius(:)=EXP(((temp(:)-ref_temp)*energy_act)/(ref_temp*RR*(temp(:))))
  END FUNCTION Arrhenius

  FUNCTION Arrhenius_modified (kjpindex,temp,ref_temp,energy_act,energy_deact,entropy) RESULT ( val_arrhenius )
    !! 0.1 Input variables

    INTEGER(i_std),INTENT(in)                     :: kjpindex          !! Domain size (-)
    REAL(r_std),DIMENSION(kjpindex),INTENT(in)    :: temp              !! Temperature (K)
    REAL(r_std), INTENT(in)                       :: ref_temp          !! Temperature of reference (K)
    REAL(r_std),INTENT(in)                        :: energy_act        !! Activation Energy (J mol-1)
    REAL(r_std),INTENT(in)                        :: energy_deact      !! Deactivation Energy (J mol-1)
    REAL(r_std),DIMENSION(kjpindex),INTENT(in)    :: entropy           !! Entropy term (J K-1 mol-1)
        
    !! 0.2 Result

    REAL(r_std), DIMENSION(kjpindex)              :: val_arrhenius     !! Temperature dependance based on
                                                                       !! a Arrhenius function (-)
    
    val_arrhenius(:)=EXP(((temp(:)-ref_temp)*energy_act)/(ref_temp*RR*(temp(:))))  &
         * (1. + EXP( (ref_temp * entropy(:) - energy_deact) / (ref_temp * RR ))) &
         / (1. + EXP( (temp(:) * entropy(:) - energy_deact) / ( RR*temp(:))))
         
  END FUNCTION Arrhenius_modified


 ! ---------------------------------------------------------------------------------------


 SUBROUTINE jnetcdf_trans_co2(kjpindex, james_netcdf_flag, gs_distribution_in, gs_output_in, &
                               lai_per_level_in, light_tran_to_level_in, gs_diffuco_output_in, &
                               gstot_output_in) 
 
    USE netcdf

    IMPLICIT NONE

    !! 0.1 Input variables

    INTEGER(i_std), INTENT(in)                                         :: kjpindex         !! Domain size (unitless)

    CHARACTER(LEN=80)                                                  :: jamescdfname          
 
    REAL(r_std), DIMENSION (nvm, nlevels_tot), INTENT(in)              :: gs_distribution_in     
    REAL(r_std),DIMENSION (nvm, nlevels_tot), INTENT(in)               :: gs_output_in
    REAL(r_std),DIMENSION (nvm, nlevels_tot), INTENT(in)               :: gstot_output_in
    REAL(r_std),DIMENSION (nvm, nlevels_tot), INTENT(in)               :: lai_per_level_in
    REAL(r_std),DIMENSION (nvm, nlevels_tot), INTENT(in)               :: light_tran_to_level_in
    REAL(r_std),DIMENSION (nvm, nlevels_tot), INTENT(in)               :: gs_diffuco_output_in


    LOGICAL                                                            :: james_netcdf_flag    


    !! 0.2 Output variables

    !! 0.3 Modified variables

    !! 0.4 Local variables

    INTEGER(i_std), SAVE                     :: gsd_id
    INTEGER(i_std), SAVE                     :: gso_id
    INTEGER(i_std), SAVE                     :: gsto_id
    INTEGER(i_std), SAVE                     :: lpl_id
    INTEGER(i_std), SAVE                     :: lttl_id
    INTEGER(i_std), SAVE                     :: gsdo_id

    INTEGER(i_std)                           :: ii, jj
    INTEGER(i_std), SAVE                     :: james_step_count    

    INTEGER(i_std), SAVE                     :: iret, iret2, fid, fid2
    INTEGER(i_std)                           :: TimeDimID, jtid, ts_id, HeightDimID, i
    INTEGER(i_std)                           :: height_dim_id, height_dim_id2, time_dim_id
    INTEGER(i_std)                           :: pftno_dim_id
    INTEGER(i_std)                           :: dimids(3) 
    INTEGER(i_std), SAVE                     :: tap_id
    INTEGER, DIMENSION(3)                    :: jstartnc, jcountnc    


    jamescdfname = '/home/users/jryder/james.ryder/outputcdf.nc'
 
    IF (james_netcdf_flag) THEN

        james_netcdf_flag = .FALSE.
        
        ! james_step_count = 0
 
        ! WRITE(numout,*) 'james_netcdf_flag call here'

        ! … define the parameters here
 
        iret = nf90_create(jamescdfname, nf90_write, fid)
        
  
        ! define the dimensions

        iret = nf90_def_dim(fid, "pftno", nvm, pftno_dim_id)        
        iret = nf90_def_dim(fid, "height", nlevels_tot, height_dim_id)
        iret = nf90_def_dim(fid, "time", nf90_unlimited, time_dim_id)

        dimids = (/ pftno_dim_id, height_dim_id, time_dim_id /)

 
        ! define the variables
        iret = nf90_def_var (fid, "gs_distribution_in", nf90_real4, dimids, gsd_id)
        iret = nf90_def_var (fid, "gs_output_in", nf90_real4, dimids, gso_id)
        iret = nf90_def_var (fid, "gstot_output_in", nf90_real4, dimids, gsto_id)
        iret = nf90_def_var (fid, "lai_per_level_in", nf90_real4, dimids, lpl_id)
        iret = nf90_def_var (fid, "light_tran_to_level_in", nf90_real4, dimids, lttl_id)
        iret = nf90_def_var (fid, "gs_diffuco_output_in", nf90_real4, dimids, gsdo_id)

 
        iret = nf90_enddef (fid)
         
    END IF !(james_netcdf_flag)


    ! open the netCDF file at each step
    iret = nf90_open(jamescdfname, nf90_Write, fid) 

    jstartnc = (/ 1, 1, 1 /)  ! vector of integers specifying the index in the variable from 
                              !   which the first of the data values will be read
    jcountnc = (/ nvm, nlevels_tot, 1 /)  ! vector of integers specifying the number of indices 
                                     !   selected along each dimension

    james_step_count = james_step_count + 1    ! this is the time step counter
    
        
    jstartnc(3) = james_step_count   ! (2) refers to the time dimension at present (it 
                                     !   must always come last)
 

    iret = nf90_put_var(fid, gsd_id, gs_distribution_in, start = jstartnc, count = jcountnc) 
    iret = nf90_put_var(fid, gso_id, gs_output_in, start = jstartnc, count = jcountnc) 
    iret = nf90_put_var(fid, gsto_id, gstot_output_in, start = jstartnc, count = jcountnc) 
    iret = nf90_put_var(fid, lpl_id, lai_per_level_in, start = jstartnc, count = jcountnc) 
    iret = nf90_put_var(fid, lttl_id, light_tran_to_level_in, start = jstartnc, count = jcountnc) 
    iret = nf90_put_var(fid, gsdo_id, gs_diffuco_output_in, start = jstartnc, count = jcountnc) 



    ! close the netCDF file and write to disk                   
    iret = nf90_close(fid)

 
 END SUBROUTINE jnetcdf_trans_co2

 
 ! ------------------------------------------------------------------------------------------------------------------------------------- 



END MODULE sechiba_hydrol_arch
